Struct
GUPnPServiceActionArgInfo
Description [src]
struct GUPnPServiceActionArgInfo {
char* name;
GUPnPServiceActionArgDirection direction;
char* related_state_variable;
gboolean retval;
}
This structure contains information about the argument of service action.
Structure members
name:char*The name of the action argument.
direction:GUPnPServiceActionArgDirectionThe direction of the action argument.
related_state_variable:char*The name of the state variable associated with this argument.
retval:gbooleanWhether this argument is the return value of the action.