Enum fmt_macros::Count
[−]
[src]
pub enum Count<'a> {
CountIs(usize),
CountIsName(&'a str),
CountIsParam(usize),
CountImplied,
}🔬 This is a nightly-only experimental API. (
rustc_private)A count is used for the precision and width parameters of an integer, and can reference either an argument or a literal integer.
Variants
CountIs(usize)🔬 This is a nightly-only experimental API. (
rustc_private)The count is specified explicitly.
CountIsName(&'a str)🔬 This is a nightly-only experimental API. (
rustc_private)The count is specified by the argument with the given name.
CountIsParam(usize)🔬 This is a nightly-only experimental API. (
rustc_private)The count is specified by the argument at the given index.
CountImplied🔬 This is a nightly-only experimental API. (
rustc_private)The count is implied and cannot be explicitly specified.