Enum fmt_macros::Flag
[−]
[src]
pub enum Flag {
FlagSignPlus,
FlagSignMinus,
FlagAlternate,
FlagSignAwareZeroPad,
}🔬 This is a nightly-only experimental API. (
rustc_private)Various flags which can be applied to format strings. The meaning of these flags is defined by the formatters themselves.
Variants
FlagSignPlus🔬 This is a nightly-only experimental API. (
rustc_private)A + will be used to denote positive numbers.
FlagSignMinus🔬 This is a nightly-only experimental API. (
rustc_private)A - will be used to denote negative numbers. This is the default.
FlagAlternate🔬 This is a nightly-only experimental API. (
rustc_private)An alternate form will be used for the value. In the case of numbers, this means that the number will be prefixed with the supplied string.
FlagSignAwareZeroPad🔬 This is a nightly-only experimental API. (
rustc_private)For numbers, this means that the number will be padded with zeroes,
and the sign (+ or -) will precede them.