Function getopts::optmulti
[−]
[src]
pub fn optmulti(short_name: &str,
long_name: &str,
desc: &str,
hint: &str)
-> OptGroup
🔬 This is a nightly-only experimental API. (rustc_private)
use the crates.io getopts library instead
Create a long option that is optional, takes an argument, and may occur multiple times.
short_name- e.g."h"for a-hoption, or""for nonelong_name- e.g."help"for a--helpoption, or""for nonedesc- Description for usage helphint- Hint that is used in place of the argument in the usage help, e.g."FILE"for a-o FILEoption