Trait log::Logger
[−]
[src]
pub trait Logger {
fn log(&mut self, record: &LogRecord);
}🔬 This is a nightly-only experimental API. (rustc_private)
use the crates.io log library instead
A trait used to represent an interface to a thread-local logger. Each thread can have its own custom logger which can respond to logging messages however it likes.
Required Methods
fn log(&mut self, record: &LogRecord)
🔬 This is a nightly-only experimental API. (rustc_private)
use the crates.io log library instead
Logs a single message described by the record.