Enum rustc::hir::def::CtorKind
[−]
[src]
pub enum CtorKind {
Fn,
Const,
Fictive,
}🔬 This is a nightly-only experimental API. (
rustc_private)Variants
Fn🔬 This is a nightly-only experimental API. (
rustc_private)Const🔬 This is a nightly-only experimental API. (
rustc_private)Fictive🔬 This is a nightly-only experimental API. (
rustc_private)Methods
impl CtorKind[src]
fn from_ast(vdata: &VariantData) -> CtorKind
🔬 This is a nightly-only experimental API. (
rustc_private)fn from_hir(vdata: &VariantData) -> CtorKind
🔬 This is a nightly-only experimental API. (
rustc_private)Trait Implementations
impl Clone for CtorKind[src]
fn clone(&self) -> CtorKind
Returns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0
Performs copy-assignment from source. Read more
impl Copy for CtorKind[src]
impl PartialEq for CtorKind[src]
fn eq(&self, __arg_0: &CtorKind) -> bool
This method tests for self and other values to be equal, and is used by ==. Read more
fn ne(&self, other: &Rhs) -> bool1.0.0
This method tests for !=.
impl Eq for CtorKind[src]
impl Encodable for CtorKind[src]
fn encode<__S: Encoder>(&self, __arg_0: &mut __S) -> Result<(), __S::Error>
🔬 This is a nightly-only experimental API. (rustc_private)
deprecated in favor of rustc-serialize on crates.io
impl Decodable for CtorKind[src]
fn decode<__D: Decoder>(__arg_0: &mut __D) -> Result<CtorKind, __D::Error>
🔬 This is a nightly-only experimental API. (rustc_private)
deprecated in favor of rustc-serialize on crates.io
impl Hash for CtorKind[src]
fn hash<__H: Hasher>(&self, __arg_0: &mut __H)
Feeds this value into the state given, updating the hasher as necessary.
fn hash_slice<H>(data: &[Self], state: &mut H) where H: Hasher1.3.0
Feeds a slice of this type into the state provided.