Enum rustc::hir::ImplItemKind
[−]
[src]
pub enum ImplItemKind {
Const(P<Ty>, BodyId),
Method(MethodSig, BodyId),
Type(P<Ty>),
}🔬 This is a nightly-only experimental API. (
rustc_private)Represents different contents within impls
Variants
Const(P<Ty>, BodyId)🔬 This is a nightly-only experimental API. (
rustc_private)An associated constant of the given type, set to the constant result of the expression
Method(MethodSig, BodyId)🔬 This is a nightly-only experimental API. (
rustc_private)A method implementation with the given signature and body
Type(P<Ty>)🔬 This is a nightly-only experimental API. (
rustc_private)An associated type