Enum rustc::hir::PatKind
[−]
[src]
pub enum PatKind {
Wild,
Binding(BindingMode, DefId, Spanned<Name>, Option<P<Pat>>),
Struct(QPath, HirVec<Spanned<FieldPat>>, bool),
TupleStruct(QPath, HirVec<P<Pat>>, Option<usize>),
Path(QPath),
Tuple(HirVec<P<Pat>>, Option<usize>),
Box(P<Pat>),
Ref(P<Pat>, Mutability),
Lit(P<Expr>),
Range(P<Expr>, P<Expr>, RangeEnd),
Slice(HirVec<P<Pat>>, Option<P<Pat>>, HirVec<P<Pat>>),
}rustc_private)Variants
Wildrustc_private)Represents a wildcard pattern (_)
Binding(BindingMode, DefId, Spanned<Name>, Option<P<Pat>>)rustc_private)A fresh binding ref mut binding @ OPT_SUBPATTERN.
The DefId is for the definition of the variable being bound.
Struct(QPath, HirVec<Spanned<FieldPat>>, bool)rustc_private)A struct or struct variant pattern, e.g. Variant {x, y, ..}.
The bool is true in the presence of a ...
TupleStruct(QPath, HirVec<P<Pat>>, Option<usize>)rustc_private)A tuple struct/variant pattern Variant(x, y, .., z).
If the .. pattern fragment is present, then Option<usize> denotes its position.
0 <= position <= subpats.len()
Path(QPath)rustc_private)A path pattern for an unit struct/variant or a (maybe-associated) constant.
Tuple(HirVec<P<Pat>>, Option<usize>)rustc_private)A tuple pattern (a, b).
If the .. pattern fragment is present, then Option<usize> denotes its position.
0 <= position <= subpats.len()
Box(P<Pat>)rustc_private)A box pattern
Ref(P<Pat>, Mutability)rustc_private)A reference pattern, e.g. &mut (a, b)
Lit(P<Expr>)rustc_private)A literal
Range(P<Expr>, P<Expr>, RangeEnd)rustc_private)A range pattern, e.g. 1...2 or 1..2
Slice(HirVec<P<Pat>>, Option<P<Pat>>, HirVec<P<Pat>>)rustc_private)[a, b, ..i, y, z] is represented as:
PatKind::Slice(box [a, b], Some(i), box [y, z])