Enum rustc::hir::PathParameters
[−]
[src]
pub enum PathParameters {
AngleBracketedParameters(AngleBracketedParameterData),
ParenthesizedParameters(ParenthesizedParameterData),
}🔬 This is a nightly-only experimental API. (
rustc_private)Variants
AngleBracketedParameters(AngleBracketedParameterData)🔬 This is a nightly-only experimental API. (
rustc_private)The <'a, A,B,C> in foo::bar::baz::<'a, A,B,C>
ParenthesizedParameters(ParenthesizedParameterData)🔬 This is a nightly-only experimental API. (
rustc_private)The (A,B) and C in Foo(A,B) -> C
Methods
impl PathParameters[src]
fn none() -> PathParameters
🔬 This is a nightly-only experimental API. (
rustc_private)fn types(&self) -> HirVec<&P<Ty>>
🔬 This is a nightly-only experimental API. (
rustc_private)Returns the types that the user wrote. Note that these do not necessarily map to the type parameters in the parenthesized case.
fn lifetimes(&self) -> HirVec<&Lifetime>
🔬 This is a nightly-only experimental API. (
rustc_private)fn bindings(&self) -> HirVec<&TypeBinding>
🔬 This is a nightly-only experimental API. (
rustc_private)Trait Implementations
impl Clone for PathParameters[src]
fn clone(&self) -> PathParameters
Returns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0
Performs copy-assignment from source. Read more
impl PartialEq for PathParameters[src]
fn eq(&self, __arg_0: &PathParameters) -> bool
This method tests for self and other values to be equal, and is used by ==. Read more
fn ne(&self, __arg_0: &PathParameters) -> bool
This method tests for !=.
impl Eq for PathParameters[src]
impl Encodable for PathParameters[src]
fn encode<__S: Encoder>(&self, __arg_0: &mut __S) -> Result<(), __S::Error>
🔬 This is a nightly-only experimental API. (rustc_private)
deprecated in favor of rustc-serialize on crates.io
impl Decodable for PathParameters[src]
fn decode<__D: Decoder>(__arg_0: &mut __D) -> Result<PathParameters, __D::Error>
🔬 This is a nightly-only experimental API. (rustc_private)
deprecated in favor of rustc-serialize on crates.io
impl Hash for PathParameters[src]
fn hash<__H: Hasher>(&self, __arg_0: &mut __H)
Feeds this value into the state given, updating the hasher as necessary.
fn hash_slice<H>(data: &[Self], state: &mut H) where H: Hasher1.3.0
Feeds a slice of this type into the state provided.