Enum rustc::hir::map::definitions::DefPathData
[−]
[src]
pub enum DefPathData {
CrateRoot,
Misc,
Impl,
TypeNs(InternedString),
ValueNs(InternedString),
Module(InternedString),
MacroDef(InternedString),
ClosureExpr,
TypeParam(InternedString),
LifetimeDef(InternedString),
EnumVariant(InternedString),
Field(InternedString),
StructCtor,
Initializer,
Binding(InternedString),
ImplTrait,
Typeof,
}rustc_private)Variants
CrateRootrustc_private)The crate root (marker)
Miscrustc_private)Implrustc_private)An impl
TypeNs(InternedString)rustc_private)Something in the type NS
ValueNs(InternedString)rustc_private)Something in the value NS
Module(InternedString)rustc_private)A module declaration
MacroDef(InternedString)rustc_private)A macro rule
ClosureExprrustc_private)A closure expression
TypeParam(InternedString)rustc_private)A type parameter (generic parameter)
LifetimeDef(InternedString)rustc_private)A lifetime definition
EnumVariant(InternedString)rustc_private)A variant of a enum
Field(InternedString)rustc_private)A struct field
StructCtorrustc_private)Implicit ctor for a tuple-like struct
Initializerrustc_private)Initializer for a const
Binding(InternedString)rustc_private)Pattern binding
ImplTraitrustc_private)An impl Trait type node.
Typeofrustc_private)A typeof type node.
Methods
impl DefPathData[src]
fn get_opt_name(&self) -> Option<Name>
rustc_private)fn as_interned_str(&self) -> InternedString
rustc_private)fn to_string(&self) -> String
rustc_private)Trait Implementations
impl Clone for DefPathData[src]
fn clone(&self) -> DefPathData
Returns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0
Performs copy-assignment from source. Read more
impl Debug for DefPathData[src]
impl PartialEq for DefPathData[src]
fn eq(&self, __arg_0: &DefPathData) -> bool
This method tests for self and other values to be equal, and is used by ==. Read more
fn ne(&self, __arg_0: &DefPathData) -> bool
This method tests for !=.
impl Eq for DefPathData[src]
impl Hash for DefPathData[src]
fn hash<__H: Hasher>(&self, __arg_0: &mut __H)
Feeds this value into the state given, updating the hasher as necessary.
fn hash_slice<H>(data: &[Self], state: &mut H) where H: Hasher1.3.0
Feeds a slice of this type into the state provided.
impl Encodable for DefPathData[src]
fn encode<__S: Encoder>(&self, __arg_0: &mut __S) -> Result<(), __S::Error>
🔬 This is a nightly-only experimental API. (rustc_private)
deprecated in favor of rustc-serialize on crates.io
impl Decodable for DefPathData[src]
fn decode<__D: Decoder>(__arg_0: &mut __D) -> Result<DefPathData, __D::Error>
🔬 This is a nightly-only experimental API. (rustc_private)
deprecated in favor of rustc-serialize on crates.io