Struct rustc::hir::Arg
[−]
[src]
pub struct Arg {
pub pat: P<Pat>,
pub id: NodeId,
}🔬 This is a nightly-only experimental API. (
rustc_private)represents an argument in a function header
Fields
pat: P<Pat>
🔬 This is a nightly-only experimental API. (
rustc_private)id: NodeId
🔬 This is a nightly-only experimental API. (
rustc_private)Trait Implementations
impl Clone for Arg[src]
fn clone(&self) -> Arg
Returns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0
Performs copy-assignment from source. Read more
impl PartialEq for Arg[src]
fn eq(&self, __arg_0: &Arg) -> bool
This method tests for self and other values to be equal, and is used by ==. Read more
fn ne(&self, __arg_0: &Arg) -> bool
This method tests for !=.
impl Eq for Arg[src]
impl Encodable for Arg[src]
fn encode<__S: Encoder>(&self, __arg_0: &mut __S) -> Result<(), __S::Error>
🔬 This is a nightly-only experimental API. (rustc_private)
deprecated in favor of rustc-serialize on crates.io
impl Decodable for Arg[src]
fn decode<__D: Decoder>(__arg_0: &mut __D) -> Result<Arg, __D::Error>
🔬 This is a nightly-only experimental API. (rustc_private)
deprecated in favor of rustc-serialize on crates.io
impl Hash for Arg[src]
fn hash<__H: Hasher>(&self, __arg_0: &mut __H)
Feeds this value into the state given, updating the hasher as necessary.
fn hash_slice<H>(data: &[Self], state: &mut H) where H: Hasher1.3.0
Feeds a slice of this type into the state provided.