Struct rustc::hir::BodyId
[−]
[src]
pub struct BodyId {
pub node_id: NodeId,
}rustc_private)Fields
node_id: NodeId
rustc_private)Trait Implementations
impl DepGraphSafe for BodyId[src]
A BodyId on its own doesn't give access to any particular state.
You must fetch the state from the various maps or generate
on-demand queries, all of which create reads.
impl Copy for BodyId[src]
impl Clone for BodyId[src]
fn clone(&self) -> BodyId
Returns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0
Performs copy-assignment from source. Read more
impl PartialEq for BodyId[src]
fn eq(&self, __arg_0: &BodyId) -> bool
This method tests for self and other values to be equal, and is used by ==. Read more
fn ne(&self, __arg_0: &BodyId) -> bool
This method tests for !=.
impl Eq for BodyId[src]
impl PartialOrd for BodyId[src]
fn partial_cmp(&self, __arg_0: &BodyId) -> Option<Ordering>
This method returns an ordering between self and other values if one exists. Read more
fn lt(&self, __arg_0: &BodyId) -> bool
This method tests less than (for self and other) and is used by the < operator. Read more
fn le(&self, __arg_0: &BodyId) -> bool
This method tests less than or equal to (for self and other) and is used by the <= operator. Read more
fn gt(&self, __arg_0: &BodyId) -> bool
This method tests greater than (for self and other) and is used by the > operator. Read more
fn ge(&self, __arg_0: &BodyId) -> bool
This method tests greater than or equal to (for self and other) and is used by the >= operator. Read more
impl Ord for BodyId[src]
fn cmp(&self, __arg_0: &BodyId) -> Ordering
This method returns an Ordering between self and other. Read more
impl Encodable for BodyId[src]
fn encode<__S: Encoder>(&self, __arg_0: &mut __S) -> Result<(), __S::Error>
🔬 This is a nightly-only experimental API. (rustc_private)
deprecated in favor of rustc-serialize on crates.io
impl Decodable for BodyId[src]
fn decode<__D: Decoder>(__arg_0: &mut __D) -> Result<BodyId, __D::Error>
🔬 This is a nightly-only experimental API. (rustc_private)
deprecated in favor of rustc-serialize on crates.io
impl Hash for BodyId[src]
fn hash<__H: Hasher>(&self, __arg_0: &mut __H)
Feeds this value into the state given, updating the hasher as necessary.
fn hash_slice<H>(data: &[Self], state: &mut H) where H: Hasher1.3.0
Feeds a slice of this type into the state provided.
impl Debug for BodyId[src]
impl<'a, 'tcx> InferEnv<'a, 'tcx> for BodyId[src]
fn to_parts(self,
tcx: TyCtxt<'a, 'tcx, 'tcx>)
-> (Option<&'a TypeckTables<'tcx>>, Option<TypeckTables<'tcx>>, Option<ParameterEnvironment<'tcx>>)
tcx: TyCtxt<'a, 'tcx, 'tcx>)
-> (Option<&'a TypeckTables<'tcx>>, Option<TypeckTables<'tcx>>, Option<ParameterEnvironment<'tcx>>)
rustc_private)