Struct rustc::hir::InlineAsmOutput
[−]
[src]
pub struct InlineAsmOutput {
pub constraint: Symbol,
pub is_rw: bool,
pub is_indirect: bool,
}🔬 This is a nightly-only experimental API. (
rustc_private)Fields
constraint: Symbol
🔬 This is a nightly-only experimental API. (
rustc_private)is_rw: bool
🔬 This is a nightly-only experimental API. (
rustc_private)is_indirect: bool
🔬 This is a nightly-only experimental API. (
rustc_private)Trait Implementations
impl Clone for InlineAsmOutput[src]
fn clone(&self) -> InlineAsmOutput
Returns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0
Performs copy-assignment from source. Read more
impl PartialEq for InlineAsmOutput[src]
fn eq(&self, __arg_0: &InlineAsmOutput) -> bool
This method tests for self and other values to be equal, and is used by ==. Read more
fn ne(&self, __arg_0: &InlineAsmOutput) -> bool
This method tests for !=.
impl Eq for InlineAsmOutput[src]
impl Encodable for InlineAsmOutput[src]
fn encode<__S: Encoder>(&self, __arg_0: &mut __S) -> Result<(), __S::Error>
🔬 This is a nightly-only experimental API. (rustc_private)
deprecated in favor of rustc-serialize on crates.io
impl Decodable for InlineAsmOutput[src]
fn decode<__D: Decoder>(__arg_0: &mut __D)
-> Result<InlineAsmOutput, __D::Error>
-> Result<InlineAsmOutput, __D::Error>
🔬 This is a nightly-only experimental API. (rustc_private)
deprecated in favor of rustc-serialize on crates.io
impl Hash for InlineAsmOutput[src]
fn hash<__H: Hasher>(&self, __arg_0: &mut __H)
Feeds this value into the state given, updating the hasher as necessary.
fn hash_slice<H>(data: &[Self], state: &mut H) where H: Hasher1.3.0
Feeds a slice of this type into the state provided.