Struct rustc::hir::LifetimeDef
[−]
[src]
pub struct LifetimeDef {
pub lifetime: Lifetime,
pub bounds: HirVec<Lifetime>,
pub pure_wrt_drop: bool,
}🔬 This is a nightly-only experimental API. (
rustc_private)A lifetime definition, eg 'a: 'b+'c+'d
Fields
lifetime: Lifetime
🔬 This is a nightly-only experimental API. (
rustc_private)bounds: HirVec<Lifetime>
🔬 This is a nightly-only experimental API. (
rustc_private)pure_wrt_drop: bool
🔬 This is a nightly-only experimental API. (
rustc_private)Trait Implementations
impl Clone for LifetimeDef[src]
fn clone(&self) -> LifetimeDef
Returns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0
Performs copy-assignment from source. Read more
impl PartialEq for LifetimeDef[src]
fn eq(&self, __arg_0: &LifetimeDef) -> bool
This method tests for self and other values to be equal, and is used by ==. Read more
fn ne(&self, __arg_0: &LifetimeDef) -> bool
This method tests for !=.
impl Eq for LifetimeDef[src]
impl Encodable for LifetimeDef[src]
fn encode<__S: Encoder>(&self, __arg_0: &mut __S) -> Result<(), __S::Error>
🔬 This is a nightly-only experimental API. (rustc_private)
deprecated in favor of rustc-serialize on crates.io
impl Decodable for LifetimeDef[src]
fn decode<__D: Decoder>(__arg_0: &mut __D) -> Result<LifetimeDef, __D::Error>
🔬 This is a nightly-only experimental API. (rustc_private)
deprecated in favor of rustc-serialize on crates.io
impl Hash for LifetimeDef[src]
fn hash<__H: Hasher>(&self, __arg_0: &mut __H)
Feeds this value into the state given, updating the hasher as necessary.
fn hash_slice<H>(data: &[Self], state: &mut H) where H: Hasher1.3.0
Feeds a slice of this type into the state provided.