Struct rustc::hir::TraitRef
[−]
[src]
pub struct TraitRef {
pub path: Path,
pub ref_id: NodeId,
}🔬 This is a nightly-only experimental API. (
rustc_private)TraitRef's appear in impls.
resolve maps each TraitRef's ref_id to its defining trait; that's all that the ref_id is for. Note that ref_id's value is not the NodeId of the trait being referred to but just a unique NodeId that serves as a key within the DefMap.
Fields
path: Path
🔬 This is a nightly-only experimental API. (
rustc_private)ref_id: NodeId
🔬 This is a nightly-only experimental API. (
rustc_private)Trait Implementations
impl Clone for TraitRef[src]
fn clone(&self) -> TraitRef
Returns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0
Performs copy-assignment from source. Read more
impl PartialEq for TraitRef[src]
fn eq(&self, __arg_0: &TraitRef) -> bool
This method tests for self and other values to be equal, and is used by ==. Read more
fn ne(&self, __arg_0: &TraitRef) -> bool
This method tests for !=.
impl Eq for TraitRef[src]
impl Encodable for TraitRef[src]
fn encode<__S: Encoder>(&self, __arg_0: &mut __S) -> Result<(), __S::Error>
🔬 This is a nightly-only experimental API. (rustc_private)
deprecated in favor of rustc-serialize on crates.io
impl Decodable for TraitRef[src]
fn decode<__D: Decoder>(__arg_0: &mut __D) -> Result<TraitRef, __D::Error>
🔬 This is a nightly-only experimental API. (rustc_private)
deprecated in favor of rustc-serialize on crates.io
impl Hash for TraitRef[src]
fn hash<__H: Hasher>(&self, __arg_0: &mut __H)
Feeds this value into the state given, updating the hasher as necessary.
fn hash_slice<H>(data: &[Self], state: &mut H) where H: Hasher1.3.0
Feeds a slice of this type into the state provided.