Struct rustc::hir::TyParam
[−]
[src]
pub struct TyParam {
pub name: Name,
pub id: NodeId,
pub bounds: TyParamBounds,
pub default: Option<P<Ty>>,
pub span: Span,
pub pure_wrt_drop: bool,
}🔬 This is a nightly-only experimental API. (
rustc_private)Fields
name: Name
🔬 This is a nightly-only experimental API. (
rustc_private)id: NodeId
🔬 This is a nightly-only experimental API. (
rustc_private)bounds: TyParamBounds
🔬 This is a nightly-only experimental API. (
rustc_private)default: Option<P<Ty>>
🔬 This is a nightly-only experimental API. (
rustc_private)span: Span
🔬 This is a nightly-only experimental API. (
rustc_private)pure_wrt_drop: bool
🔬 This is a nightly-only experimental API. (
rustc_private)Trait Implementations
impl Clone for TyParam[src]
fn clone(&self) -> TyParam
Returns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0
Performs copy-assignment from source. Read more
impl PartialEq for TyParam[src]
fn eq(&self, __arg_0: &TyParam) -> bool
This method tests for self and other values to be equal, and is used by ==. Read more
fn ne(&self, __arg_0: &TyParam) -> bool
This method tests for !=.
impl Eq for TyParam[src]
impl Encodable for TyParam[src]
fn encode<__S: Encoder>(&self, __arg_0: &mut __S) -> Result<(), __S::Error>
🔬 This is a nightly-only experimental API. (rustc_private)
deprecated in favor of rustc-serialize on crates.io
impl Decodable for TyParam[src]
fn decode<__D: Decoder>(__arg_0: &mut __D) -> Result<TyParam, __D::Error>
🔬 This is a nightly-only experimental API. (rustc_private)
deprecated in favor of rustc-serialize on crates.io
impl Hash for TyParam[src]
fn hash<__H: Hasher>(&self, __arg_0: &mut __H)
Feeds this value into the state given, updating the hasher as necessary.
fn hash_slice<H>(data: &[Self], state: &mut H) where H: Hasher1.3.0
Feeds a slice of this type into the state provided.