Struct rustc::hir::WhereEqPredicate
[−]
[src]
pub struct WhereEqPredicate {
pub id: NodeId,
pub span: Span,
pub lhs_ty: P<Ty>,
pub rhs_ty: P<Ty>,
}🔬 This is a nightly-only experimental API. (
rustc_private)An equality predicate (unsupported), e.g. T=int
Fields
id: NodeId
🔬 This is a nightly-only experimental API. (
rustc_private)span: Span
🔬 This is a nightly-only experimental API. (
rustc_private)lhs_ty: P<Ty>
🔬 This is a nightly-only experimental API. (
rustc_private)rhs_ty: P<Ty>
🔬 This is a nightly-only experimental API. (
rustc_private)Trait Implementations
impl Clone for WhereEqPredicate[src]
fn clone(&self) -> WhereEqPredicate
Returns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0
Performs copy-assignment from source. Read more
impl PartialEq for WhereEqPredicate[src]
fn eq(&self, __arg_0: &WhereEqPredicate) -> bool
This method tests for self and other values to be equal, and is used by ==. Read more
fn ne(&self, __arg_0: &WhereEqPredicate) -> bool
This method tests for !=.
impl Eq for WhereEqPredicate[src]
impl Encodable for WhereEqPredicate[src]
fn encode<__S: Encoder>(&self, __arg_0: &mut __S) -> Result<(), __S::Error>
🔬 This is a nightly-only experimental API. (rustc_private)
deprecated in favor of rustc-serialize on crates.io
impl Decodable for WhereEqPredicate[src]
fn decode<__D: Decoder>(__arg_0: &mut __D)
-> Result<WhereEqPredicate, __D::Error>
-> Result<WhereEqPredicate, __D::Error>
🔬 This is a nightly-only experimental API. (rustc_private)
deprecated in favor of rustc-serialize on crates.io
impl Hash for WhereEqPredicate[src]
fn hash<__H: Hasher>(&self, __arg_0: &mut __H)
Feeds this value into the state given, updating the hasher as necessary.
fn hash_slice<H>(data: &[Self], state: &mut H) where H: Hasher1.3.0
Feeds a slice of this type into the state provided.