Enum rustc::infer::region_inference::RegionResolutionError
[−]
[src]
pub enum RegionResolutionError<'tcx> {
ConcreteFailure(SubregionOrigin<'tcx>, &'tcx Region, &'tcx Region),
GenericBoundFailure(SubregionOrigin<'tcx>, GenericKind<'tcx>, &'tcx Region),
SubSupConflict(RegionVariableOrigin, SubregionOrigin<'tcx>, &'tcx Region, SubregionOrigin<'tcx>, &'tcx Region),
}🔬 This is a nightly-only experimental API. (
rustc_private)Variants
ConcreteFailure(SubregionOrigin<'tcx>, &'tcx Region, &'tcx Region)🔬 This is a nightly-only experimental API. (
rustc_private)ConcreteFailure(o, a, b):
o requires that a <= b, but this does not hold
GenericBoundFailure(SubregionOrigin<'tcx>, GenericKind<'tcx>, &'tcx Region)🔬 This is a nightly-only experimental API. (
rustc_private)`GenericBoundFailure(p, s, a)
The parameter/associated-type p must be known to outlive the lifetime
a (but none of the known bounds are sufficient).
SubSupConflict(RegionVariableOrigin, SubregionOrigin<'tcx>, &'tcx Region, SubregionOrigin<'tcx>, &'tcx Region)🔬 This is a nightly-only experimental API. (
rustc_private)SubSupConflict(v, sub_origin, sub_r, sup_origin, sup_r):
Could not infer a value for v because sub_r <= v (due to
sub_origin) but v <= sup_r (due to sup_origin) and
sub_r <= sup_r does not hold.