Enum rustc::infer::region_inference::UndoLogEntry
[−]
[src]
pub enum UndoLogEntry<'tcx> {
OpenSnapshot,
CommitedSnapshot,
AddVar(RegionVid),
AddConstraint(Constraint<'tcx>),
AddVerify(usize),
AddGiven(FreeRegion, RegionVid),
AddCombination(CombineMapType, TwoRegions<'tcx>),
Purged,
}rustc_private)Variants
OpenSnapshotrustc_private)Pushed when we start a snapshot.
CommitedSnapshotrustc_private)Replaces an OpenSnapshot when a snapshot is committed, but
that snapshot is not the root. If the root snapshot is
unrolled, all nested snapshots must be committed.
AddVar(RegionVid)rustc_private)We added RegionVid
AddConstraint(Constraint<'tcx>)rustc_private)We added the given constraint
AddVerify(usize)rustc_private)We added the given verify
AddGiven(FreeRegion, RegionVid)rustc_private)We added the given given
AddCombination(CombineMapType, TwoRegions<'tcx>)rustc_private)We added a GLB/LUB "combinaton variable"
Purgedrustc_private)During skolemization, we sometimes purge entries from the undo
log in a kind of minisnapshot (unlike other snapshots, this
purging actually takes place on success). In that case, we
replace the corresponding entry with Noop so as to avoid the
need to do a bunch of swapping. (We can't use swap_remove as
the order of the vector is important.)