Struct rustc::infer::region_inference::TwoRegions
[−]
[src]
pub struct TwoRegions<'tcx> { /* fields omitted */ }🔬 This is a nightly-only experimental API. (
rustc_private)Trait Implementations
impl<'tcx> Copy for TwoRegions<'tcx>[src]
impl<'tcx> Clone for TwoRegions<'tcx>[src]
fn clone(&self) -> TwoRegions<'tcx>
Returns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0
Performs copy-assignment from source. Read more
impl<'tcx> PartialEq for TwoRegions<'tcx>[src]
fn eq(&self, __arg_0: &TwoRegions<'tcx>) -> bool
This method tests for self and other values to be equal, and is used by ==. Read more
fn ne(&self, __arg_0: &TwoRegions<'tcx>) -> bool
This method tests for !=.
impl<'tcx> Eq for TwoRegions<'tcx>[src]
impl<'tcx> Hash for TwoRegions<'tcx>[src]
fn hash<__H: Hasher>(&self, __arg_0: &mut __H)
Feeds this value into the state given, updating the hasher as necessary.
fn hash_slice<H>(data: &[Self], state: &mut H) where H: Hasher1.3.0
Feeds a slice of this type into the state provided.