Enum rustc::middle::cstore::DepKind
[−]
[src]
pub enum DepKind {
UnexportedMacrosOnly,
MacrosOnly,
Implicit,
Explicit,
}rustc_private)Variants
UnexportedMacrosOnlyrustc_private)A dependency that is only used for its macros, none of which are visible from other crates. These are included in the metadata only as placeholders and are ignored when decoding.
MacrosOnlyrustc_private)A dependency that is only used for its macros.
Implicitrustc_private)A dependency that is always injected into the dependency list and so doesn't need to be linked to an rlib, e.g. the injected allocator.
Explicitrustc_private)A dependency that is required by an rlib version of this crate.
Ordinary extern crates result in Explicit dependencies.
Methods
impl DepKind[src]
fn macros_only(self) -> bool
rustc_private)Trait Implementations
impl Encodable for DepKind[src]
fn encode<__S: Encoder>(&self, __arg_0: &mut __S) -> Result<(), __S::Error>
🔬 This is a nightly-only experimental API. (rustc_private)
deprecated in favor of rustc-serialize on crates.io
impl Decodable for DepKind[src]
fn decode<__D: Decoder>(__arg_0: &mut __D) -> Result<DepKind, __D::Error>
🔬 This is a nightly-only experimental API. (rustc_private)
deprecated in favor of rustc-serialize on crates.io
impl Copy for DepKind[src]
impl Clone for DepKind[src]
fn clone(&self) -> DepKind
Returns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0
Performs copy-assignment from source. Read more
impl Ord for DepKind[src]
fn cmp(&self, __arg_0: &DepKind) -> Ordering
This method returns an Ordering between self and other. Read more
impl PartialOrd for DepKind[src]
fn partial_cmp(&self, __arg_0: &DepKind) -> Option<Ordering>
This method returns an ordering between self and other values if one exists. Read more
fn lt(&self, other: &Rhs) -> bool1.0.0
This method tests less than (for self and other) and is used by the < operator. Read more
fn le(&self, other: &Rhs) -> bool1.0.0
This method tests less than or equal to (for self and other) and is used by the <= operator. Read more
fn gt(&self, other: &Rhs) -> bool1.0.0
This method tests greater than (for self and other) and is used by the > operator. Read more
fn ge(&self, other: &Rhs) -> bool1.0.0
This method tests greater than or equal to (for self and other) and is used by the >= operator. Read more
impl Eq for DepKind[src]
impl PartialEq for DepKind[src]
fn eq(&self, __arg_0: &DepKind) -> bool
This method tests for self and other values to be equal, and is used by ==. Read more
fn ne(&self, other: &Rhs) -> bool1.0.0
This method tests for !=.