Enum rustc::middle::privacy::AccessLevel
[−]
[src]
pub enum AccessLevel {
Reachable,
Exported,
Public,
}🔬 This is a nightly-only experimental API. (
rustc_private)Variants
Reachable🔬 This is a nightly-only experimental API. (
rustc_private)Exported🔬 This is a nightly-only experimental API. (
rustc_private)Public🔬 This is a nightly-only experimental API. (
rustc_private)Trait Implementations
impl Clone for AccessLevel[src]
fn clone(&self) -> AccessLevel
Returns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0
Performs copy-assignment from source. Read more
impl Copy for AccessLevel[src]
impl Debug for AccessLevel[src]
impl PartialEq for AccessLevel[src]
fn eq(&self, __arg_0: &AccessLevel) -> bool
This method tests for self and other values to be equal, and is used by ==. Read more
fn ne(&self, other: &Rhs) -> bool1.0.0
This method tests for !=.
impl Eq for AccessLevel[src]
impl PartialOrd for AccessLevel[src]
fn partial_cmp(&self, __arg_0: &AccessLevel) -> Option<Ordering>
This method returns an ordering between self and other values if one exists. Read more
fn lt(&self, other: &Rhs) -> bool1.0.0
This method tests less than (for self and other) and is used by the < operator. Read more
fn le(&self, other: &Rhs) -> bool1.0.0
This method tests less than or equal to (for self and other) and is used by the <= operator. Read more
fn gt(&self, other: &Rhs) -> bool1.0.0
This method tests greater than (for self and other) and is used by the > operator. Read more
fn ge(&self, other: &Rhs) -> bool1.0.0
This method tests greater than or equal to (for self and other) and is used by the >= operator. Read more
impl Ord for AccessLevel[src]
fn cmp(&self, __arg_0: &AccessLevel) -> Ordering
This method returns an Ordering between self and other. Read more