Enum rustc::mir::AggregateKind
[−]
[src]
pub enum AggregateKind<'tcx> {
Array(Ty<'tcx>),
Tuple,
Adt(&'tcx AdtDef, usize, &'tcx Substs<'tcx>, Option<usize>),
Closure(DefId, ClosureSubsts<'tcx>),
}🔬 This is a nightly-only experimental API. (
rustc_private)Variants
Array(Ty<'tcx>)🔬 This is a nightly-only experimental API. (
rustc_private)The type is of the element
Tuple🔬 This is a nightly-only experimental API. (
rustc_private)Adt(&'tcx AdtDef, usize, &'tcx Substs<'tcx>, Option<usize>)🔬 This is a nightly-only experimental API. (
rustc_private)The second field is variant number (discriminant), it's equal to 0 for struct and union expressions. The fourth field is active field number and is present only for union expressions.
Closure(DefId, ClosureSubsts<'tcx>)🔬 This is a nightly-only experimental API. (
rustc_private)Trait Implementations
impl<'tcx> Clone for AggregateKind<'tcx>[src]
fn clone(&self) -> AggregateKind<'tcx>
Returns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0
Performs copy-assignment from source. Read more
impl<'tcx> Debug for AggregateKind<'tcx>[src]
impl<'tcx> PartialEq for AggregateKind<'tcx>[src]
fn eq(&self, __arg_0: &AggregateKind<'tcx>) -> bool
This method tests for self and other values to be equal, and is used by ==. Read more
fn ne(&self, __arg_0: &AggregateKind<'tcx>) -> bool
This method tests for !=.
impl<'tcx> Eq for AggregateKind<'tcx>[src]
impl<'tcx> Encodable for AggregateKind<'tcx>[src]
fn encode<__S: Encoder>(&self, __arg_0: &mut __S) -> Result<(), __S::Error>
🔬 This is a nightly-only experimental API. (rustc_private)
deprecated in favor of rustc-serialize on crates.io
impl<'tcx> Decodable for AggregateKind<'tcx>[src]
fn decode<__D: Decoder>(__arg_0: &mut __D)
-> Result<AggregateKind<'tcx>, __D::Error>
-> Result<AggregateKind<'tcx>, __D::Error>
🔬 This is a nightly-only experimental API. (rustc_private)
deprecated in favor of rustc-serialize on crates.io