Struct rustc::mir::Location
[−]
[src]
pub struct Location {
pub block: BasicBlock,
pub statement_index: usize,
}rustc_private)Fields
block: BasicBlock
rustc_private)the location is within this block
statement_index: usize
rustc_private)the location is the start of the this statement; or, if statement_index
== num-statements, then the start of the terminator.
Methods
impl Location[src]
fn dominates(&self,
other: &Location,
dominators: &Dominators<BasicBlock>)
-> bool
other: &Location,
dominators: &Dominators<BasicBlock>)
-> bool
rustc_private)Trait Implementations
impl Copy for Location[src]
impl Clone for Location[src]
fn clone(&self) -> Location
Returns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0
Performs copy-assignment from source. Read more
impl PartialEq for Location[src]
fn eq(&self, __arg_0: &Location) -> bool
This method tests for self and other values to be equal, and is used by ==. Read more
fn ne(&self, __arg_0: &Location) -> bool
This method tests for !=.
impl Eq for Location[src]
impl Hash for Location[src]
fn hash<__H: Hasher>(&self, __arg_0: &mut __H)
Feeds this value into the state given, updating the hasher as necessary.
fn hash_slice<H>(data: &[Self], state: &mut H) where H: Hasher1.3.0
Feeds a slice of this type into the state provided.
impl Ord for Location[src]
fn cmp(&self, __arg_0: &Location) -> Ordering
This method returns an Ordering between self and other. Read more
impl PartialOrd for Location[src]
fn partial_cmp(&self, __arg_0: &Location) -> Option<Ordering>
This method returns an ordering between self and other values if one exists. Read more
fn lt(&self, __arg_0: &Location) -> bool
This method tests less than (for self and other) and is used by the < operator. Read more
fn le(&self, __arg_0: &Location) -> bool
This method tests less than or equal to (for self and other) and is used by the <= operator. Read more
fn gt(&self, __arg_0: &Location) -> bool
This method tests greater than (for self and other) and is used by the > operator. Read more
fn ge(&self, __arg_0: &Location) -> bool
This method tests greater than or equal to (for self and other) and is used by the >= operator. Read more