Struct rustc::mir::SourceInfo
[−]
[src]
pub struct SourceInfo {
pub span: Span,
pub scope: VisibilityScope,
}🔬 This is a nightly-only experimental API. (
rustc_private)Grouped information about the source code origin of a MIR entity. Intended to be inspected by diagnostics and debuginfo. Most passes can work with it as a whole, within a single function.
Fields
span: Span
🔬 This is a nightly-only experimental API. (
rustc_private)Source span for the AST pertaining to this MIR entity.
scope: VisibilityScope
🔬 This is a nightly-only experimental API. (
rustc_private)The lexical visibility scope, i.e. which bindings can be seen.