Struct rustc::mir::Static
[−]
[src]
pub struct Static<'tcx> {
pub def_id: DefId,
pub ty: Ty<'tcx>,
}🔬 This is a nightly-only experimental API. (
rustc_private)The def-id of a static, along with its normalized type (which is stored to avoid requiring normalization when reading MIR).
Fields
def_id: DefId
🔬 This is a nightly-only experimental API. (
rustc_private)ty: Ty<'tcx>
🔬 This is a nightly-only experimental API. (
rustc_private)Trait Implementations
impl<'tcx> Clone for Static<'tcx>[src]
fn clone(&self) -> Static<'tcx>
Returns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0
Performs copy-assignment from source. Read more
impl<'tcx> PartialEq for Static<'tcx>[src]
fn eq(&self, __arg_0: &Static<'tcx>) -> bool
This method tests for self and other values to be equal, and is used by ==. Read more
fn ne(&self, __arg_0: &Static<'tcx>) -> bool
This method tests for !=.
impl<'tcx> Encodable for Static<'tcx>[src]
fn encode<__S: Encoder>(&self, __arg_0: &mut __S) -> Result<(), __S::Error>
🔬 This is a nightly-only experimental API. (rustc_private)
deprecated in favor of rustc-serialize on crates.io