Enum rustc::mir::visit::LvalueContext
[−]
[src]
pub enum LvalueContext<'tcx> {
Store,
Call,
Drop,
Inspect,
Borrow {
region: &'tcx Region,
kind: BorrowKind,
},
Projection(Mutability),
Consume,
StorageLive,
StorageDead,
}🔬 This is a nightly-only experimental API. (
rustc_private)Variants
Store🔬 This is a nightly-only experimental API. (
rustc_private)Call🔬 This is a nightly-only experimental API. (
rustc_private)Drop🔬 This is a nightly-only experimental API. (
rustc_private)Inspect🔬 This is a nightly-only experimental API. (
rustc_private)Borrow🔬 This is a nightly-only experimental API. (
rustc_private)Fields of Borrow
region: &'tcx Region | 🔬 This is a nightly-only experimental API. ( rustc_private) |
kind: BorrowKind | 🔬 This is a nightly-only experimental API. ( rustc_private) |
Projection(Mutability)🔬 This is a nightly-only experimental API. (
rustc_private)Consume🔬 This is a nightly-only experimental API. (
rustc_private)StorageLive🔬 This is a nightly-only experimental API. (
rustc_private)StorageDead🔬 This is a nightly-only experimental API. (
rustc_private)Methods
impl<'tcx> LvalueContext<'tcx>[src]
fn is_drop(&self) -> bool
🔬 This is a nightly-only experimental API. (
rustc_private)Returns true if this lvalue context represents a drop.
fn is_storage_marker(&self) -> bool
🔬 This is a nightly-only experimental API. (
rustc_private)Returns true if this lvalue context represents a storage live or storage dead marker.
fn is_storage_live_marker(&self) -> bool
🔬 This is a nightly-only experimental API. (
rustc_private)Returns true if this lvalue context represents a storage live marker.
fn is_storage_dead_marker(&self) -> bool
🔬 This is a nightly-only experimental API. (
rustc_private)Returns true if this lvalue context represents a storage dead marker.
fn is_mutating_use(&self) -> bool
🔬 This is a nightly-only experimental API. (
rustc_private)Returns true if this lvalue context represents a use that potentially changes the value.
fn is_nonmutating_use(&self) -> bool
🔬 This is a nightly-only experimental API. (
rustc_private)Returns true if this lvalue context represents a use that does not change the value.
fn is_use(&self) -> bool
🔬 This is a nightly-only experimental API. (
rustc_private)Trait Implementations
impl<'tcx> Copy for LvalueContext<'tcx>[src]
impl<'tcx> Clone for LvalueContext<'tcx>[src]
fn clone(&self) -> LvalueContext<'tcx>
Returns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0
Performs copy-assignment from source. Read more
impl<'tcx> Debug for LvalueContext<'tcx>[src]
impl<'tcx> PartialEq for LvalueContext<'tcx>[src]
fn eq(&self, __arg_0: &LvalueContext<'tcx>) -> bool
This method tests for self and other values to be equal, and is used by ==. Read more
fn ne(&self, __arg_0: &LvalueContext<'tcx>) -> bool
This method tests for !=.