Enum rustc::session::DataTypeKind
[−]
[src]
pub enum DataTypeKind {
Struct,
Union,
Enum,
Closure,
}🔬 This is a nightly-only experimental API. (
rustc_private)Variants
Struct🔬 This is a nightly-only experimental API. (
rustc_private)Union🔬 This is a nightly-only experimental API. (
rustc_private)Enum🔬 This is a nightly-only experimental API. (
rustc_private)Closure🔬 This is a nightly-only experimental API. (
rustc_private)Trait Implementations
impl From<AdtKind> for DataTypeKind[src]
impl Copy for DataTypeKind[src]
impl Clone for DataTypeKind[src]
fn clone(&self) -> DataTypeKind
Returns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0
Performs copy-assignment from source. Read more
impl PartialEq for DataTypeKind[src]
fn eq(&self, __arg_0: &DataTypeKind) -> bool
This method tests for self and other values to be equal, and is used by ==. Read more
fn ne(&self, other: &Rhs) -> bool1.0.0
This method tests for !=.
impl Eq for DataTypeKind[src]
impl Hash for DataTypeKind[src]
fn hash<__H: Hasher>(&self, __arg_0: &mut __H)
Feeds this value into the state given, updating the hasher as necessary.
fn hash_slice<H>(data: &[Self], state: &mut H) where H: Hasher1.3.0
Feeds a slice of this type into the state provided.