Struct rustc::session::VariantInfo
[−]
[src]
pub struct VariantInfo {
pub name: Option<String>,
pub kind: SizeKind,
pub size: u64,
pub align: u64,
pub fields: Vec<FieldInfo>,
}🔬 This is a nightly-only experimental API. (
rustc_private)Fields
name: Option<String>
🔬 This is a nightly-only experimental API. (
rustc_private)kind: SizeKind
🔬 This is a nightly-only experimental API. (
rustc_private)size: u64
🔬 This is a nightly-only experimental API. (
rustc_private)align: u64
🔬 This is a nightly-only experimental API. (
rustc_private)fields: Vec<FieldInfo>
🔬 This is a nightly-only experimental API. (
rustc_private)Trait Implementations
impl Clone for VariantInfo[src]
fn clone(&self) -> VariantInfo
Returns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0
Performs copy-assignment from source. Read more
impl PartialEq for VariantInfo[src]
fn eq(&self, __arg_0: &VariantInfo) -> bool
This method tests for self and other values to be equal, and is used by ==. Read more
fn ne(&self, __arg_0: &VariantInfo) -> bool
This method tests for !=.
impl Eq for VariantInfo[src]
impl Hash for VariantInfo[src]
fn hash<__H: Hasher>(&self, __arg_0: &mut __H)
Feeds this value into the state given, updating the hasher as necessary.
fn hash_slice<H>(data: &[Self], state: &mut H) where H: Hasher1.3.0
Feeds a slice of this type into the state provided.