Enum rustc::ty::cast::CastTy
[−]
[src]
pub enum CastTy<'tcx> {
Int(IntTy),
Float,
FnPtr,
Ptr(&'tcx TypeAndMut<'tcx>),
RPtr(&'tcx TypeAndMut<'tcx>),
}🔬 This is a nightly-only experimental API. (
rustc_private)Variants
Int(IntTy)🔬 This is a nightly-only experimental API. (
rustc_private)Various types that are represented as ints and handled mostly in the same way, merged for easier matching.
Float🔬 This is a nightly-only experimental API. (
rustc_private)Floating-Point types
FnPtr🔬 This is a nightly-only experimental API. (
rustc_private)Function Pointers
Ptr(&'tcx TypeAndMut<'tcx>)🔬 This is a nightly-only experimental API. (
rustc_private)Raw pointers
RPtr(&'tcx TypeAndMut<'tcx>)🔬 This is a nightly-only experimental API. (
rustc_private)References
Methods
impl<'tcx> CastTy<'tcx>[src]
fn from_ty(t: Ty<'tcx>) -> Option<CastTy<'tcx>>
🔬 This is a nightly-only experimental API. (
rustc_private)Trait Implementations
impl<'tcx> Copy for CastTy<'tcx>[src]
impl<'tcx> Clone for CastTy<'tcx>[src]
fn clone(&self) -> CastTy<'tcx>
Returns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0
Performs copy-assignment from source. Read more
impl<'tcx> Debug for CastTy<'tcx>[src]
impl<'tcx> PartialEq for CastTy<'tcx>[src]
fn eq(&self, __arg_0: &CastTy<'tcx>) -> bool
This method tests for self and other values to be equal, and is used by ==. Read more
fn ne(&self, __arg_0: &CastTy<'tcx>) -> bool
This method tests for !=.