Enum rustc::ty::InferTy
[−]
[src]
pub enum InferTy {
TyVar(TyVid),
IntVar(IntVid),
FloatVar(FloatVid),
FreshTy(u32),
FreshIntTy(u32),
FreshFloatTy(u32),
}🔬 This is a nightly-only experimental API. (
rustc_private)Variants
TyVar(TyVid)🔬 This is a nightly-only experimental API. (
rustc_private)IntVar(IntVid)🔬 This is a nightly-only experimental API. (
rustc_private)FloatVar(FloatVid)🔬 This is a nightly-only experimental API. (
rustc_private)FreshTy(u32)🔬 This is a nightly-only experimental API. (
rustc_private)A FreshTy is one that is generated as a replacement for an
unbound type variable. This is convenient for caching etc. See
infer::freshen for more details.
FreshIntTy(u32)🔬 This is a nightly-only experimental API. (
rustc_private)FreshFloatTy(u32)🔬 This is a nightly-only experimental API. (
rustc_private)Trait Implementations
impl Clone for InferTy[src]
fn clone(&self) -> InferTy
Returns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0
Performs copy-assignment from source. Read more
impl Copy for InferTy[src]
impl PartialEq for InferTy[src]
fn eq(&self, __arg_0: &InferTy) -> bool
This method tests for self and other values to be equal, and is used by ==. Read more
fn ne(&self, __arg_0: &InferTy) -> bool
This method tests for !=.
impl Eq for InferTy[src]
impl Hash for InferTy[src]
fn hash<__H: Hasher>(&self, __arg_0: &mut __H)
Feeds this value into the state given, updating the hasher as necessary.
fn hash_slice<H>(data: &[Self], state: &mut H) where H: Hasher1.3.0
Feeds a slice of this type into the state provided.
impl Encodable for InferTy[src]
fn encode<__S: Encoder>(&self, __arg_0: &mut __S) -> Result<(), __S::Error>
🔬 This is a nightly-only experimental API. (rustc_private)
deprecated in favor of rustc-serialize on crates.io
impl Decodable for InferTy[src]
fn decode<__D: Decoder>(__arg_0: &mut __D) -> Result<InferTy, __D::Error>
🔬 This is a nightly-only experimental API. (rustc_private)
deprecated in favor of rustc-serialize on crates.io