Enum rustc::ty::error::TypeError
[−]
[src]
pub enum TypeError<'tcx> {
Mismatch,
UnsafetyMismatch(ExpectedFound<Unsafety>),
AbiMismatch(ExpectedFound<Abi>),
Mutability,
TupleSize(ExpectedFound<usize>),
FixedArraySize(ExpectedFound<usize>),
ArgCount,
RegionsDoesNotOutlive(&'tcx Region, &'tcx Region),
RegionsNotSame(&'tcx Region, &'tcx Region),
RegionsNoOverlap(&'tcx Region, &'tcx Region),
RegionsInsufficientlyPolymorphic(BoundRegion, &'tcx Region, Option<Box<Issue32330>>),
RegionsOverlyPolymorphic(BoundRegion, &'tcx Region, Option<Box<Issue32330>>),
Sorts(ExpectedFound<Ty<'tcx>>),
IntMismatch(ExpectedFound<IntVarValue>),
FloatMismatch(ExpectedFound<FloatTy>),
Traits(ExpectedFound<DefId>),
VariadicMismatch(ExpectedFound<bool>),
CyclicTy,
ProjectionNameMismatched(ExpectedFound<Name>),
ProjectionBoundsLength(ExpectedFound<usize>),
TyParamDefaultMismatch(ExpectedFound<Default<'tcx>>),
ExistentialMismatch(ExpectedFound<&'tcx Slice<ExistentialPredicate<'tcx>>>),
}🔬 This is a nightly-only experimental API. (
rustc_private)Variants
Mismatch🔬 This is a nightly-only experimental API. (
rustc_private)UnsafetyMismatch(ExpectedFound<Unsafety>)🔬 This is a nightly-only experimental API. (
rustc_private)AbiMismatch(ExpectedFound<Abi>)🔬 This is a nightly-only experimental API. (
rustc_private)Mutability🔬 This is a nightly-only experimental API. (
rustc_private)TupleSize(ExpectedFound<usize>)🔬 This is a nightly-only experimental API. (
rustc_private)FixedArraySize(ExpectedFound<usize>)🔬 This is a nightly-only experimental API. (
rustc_private)ArgCount🔬 This is a nightly-only experimental API. (
rustc_private)RegionsDoesNotOutlive(&'tcx Region, &'tcx Region)🔬 This is a nightly-only experimental API. (
rustc_private)RegionsNotSame(&'tcx Region, &'tcx Region)🔬 This is a nightly-only experimental API. (
rustc_private)RegionsNoOverlap(&'tcx Region, &'tcx Region)🔬 This is a nightly-only experimental API. (
rustc_private)RegionsInsufficientlyPolymorphic(BoundRegion, &'tcx Region, Option<Box<Issue32330>>)🔬 This is a nightly-only experimental API. (
rustc_private)RegionsOverlyPolymorphic(BoundRegion, &'tcx Region, Option<Box<Issue32330>>)🔬 This is a nightly-only experimental API. (
rustc_private)Sorts(ExpectedFound<Ty<'tcx>>)🔬 This is a nightly-only experimental API. (
rustc_private)IntMismatch(ExpectedFound<IntVarValue>)🔬 This is a nightly-only experimental API. (
rustc_private)FloatMismatch(ExpectedFound<FloatTy>)🔬 This is a nightly-only experimental API. (
rustc_private)Traits(ExpectedFound<DefId>)🔬 This is a nightly-only experimental API. (
rustc_private)VariadicMismatch(ExpectedFound<bool>)🔬 This is a nightly-only experimental API. (
rustc_private)CyclicTy🔬 This is a nightly-only experimental API. (
rustc_private)ProjectionNameMismatched(ExpectedFound<Name>)🔬 This is a nightly-only experimental API. (
rustc_private)ProjectionBoundsLength(ExpectedFound<usize>)🔬 This is a nightly-only experimental API. (
rustc_private)TyParamDefaultMismatch(ExpectedFound<Default<'tcx>>)🔬 This is a nightly-only experimental API. (
rustc_private)ExistentialMismatch(ExpectedFound<&'tcx Slice<ExistentialPredicate<'tcx>>>)🔬 This is a nightly-only experimental API. (
rustc_private)Trait Implementations
impl<'tcx> Clone for TypeError<'tcx>[src]
fn clone(&self) -> TypeError<'tcx>
Returns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0
Performs copy-assignment from source. Read more
impl<'tcx> Debug for TypeError<'tcx>[src]
impl<'tcx> Display for TypeError<'tcx>[src]
Explains the source of a type err in a short, human readable way. This is meant to be placed
in parentheses after some larger message. You should also invoke note_and_explain_type_err()
afterwards to present additional details, particularly when it comes to lifetime-related
errors.