Enum rustc::ty::layout::Integer
[−]
[src]
pub enum Integer {
I1,
I8,
I16,
I32,
I64,
I128,
}rustc_private)Integers, also used for enum discriminants.
Variants
I1rustc_private)I8rustc_private)I16rustc_private)I32rustc_private)I64rustc_private)I128rustc_private)Methods
impl Integer[src]
fn size(&self) -> Size
rustc_private)fn align(&self, dl: &TargetDataLayout) -> Align
rustc_private)fn to_ty<'a, 'tcx>(&self,
tcx: &TyCtxt<'a, 'tcx, 'tcx>,
signed: bool)
-> Ty<'tcx>
tcx: &TyCtxt<'a, 'tcx, 'tcx>,
signed: bool)
-> Ty<'tcx>
rustc_private)fn fit_signed(x: i64) -> Integer
rustc_private)Find the smallest Integer type which can represent the signed value.
fn fit_unsigned(x: u64) -> Integer
rustc_private)Find the smallest Integer type which can represent the unsigned value.
fn for_abi_align(dl: &TargetDataLayout, align: Align) -> Option<Integer>
rustc_private)Find the smallest integer with the given alignment.
fn from_attr(dl: &TargetDataLayout, ity: IntType) -> Integer
rustc_private)Get the Integer type from an attr::IntType.