Enum rustc::ty::layout::Primitive
[−]
[src]
pub enum Primitive {
Int(Integer),
F32,
F64,
Pointer,
}🔬 This is a nightly-only experimental API. (
rustc_private)Fundamental unit of memory access and layout.
Variants
Int(Integer)🔬 This is a nightly-only experimental API. (
rustc_private)F32🔬 This is a nightly-only experimental API. (
rustc_private)F64🔬 This is a nightly-only experimental API. (
rustc_private)Pointer🔬 This is a nightly-only experimental API. (
rustc_private)Methods
impl Primitive[src]
fn size(self, dl: &TargetDataLayout) -> Size
🔬 This is a nightly-only experimental API. (
rustc_private)fn align(self, dl: &TargetDataLayout) -> Align
🔬 This is a nightly-only experimental API. (
rustc_private)Trait Implementations
impl Copy for Primitive[src]
impl Clone for Primitive[src]
fn clone(&self) -> Primitive
Returns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0
Performs copy-assignment from source. Read more
impl PartialEq for Primitive[src]
fn eq(&self, __arg_0: &Primitive) -> bool
This method tests for self and other values to be equal, and is used by ==. Read more
fn ne(&self, __arg_0: &Primitive) -> bool
This method tests for !=.
impl Eq for Primitive[src]
impl Hash for Primitive[src]
fn hash<__H: Hasher>(&self, __arg_0: &mut __H)
Feeds this value into the state given, updating the hasher as necessary.
fn hash_slice<H>(data: &[Self], state: &mut H) where H: Hasher1.3.0
Feeds a slice of this type into the state provided.