Struct rustc::ty::layout::Size
[−]
[src]
pub struct Size { /* fields omitted */ }rustc_private)Size of a type in bytes.
Methods
impl Size[src]
fn from_bits(bits: u64) -> Size
rustc_private)fn from_bytes(bytes: u64) -> Size
rustc_private)fn bytes(self) -> u64
rustc_private)fn bits(self) -> u64
rustc_private)fn abi_align(self, align: Align) -> Size
rustc_private)fn checked_add(self, offset: Size, dl: &TargetDataLayout) -> Option<Size>
rustc_private)fn checked_mul(self, count: u64, dl: &TargetDataLayout) -> Option<Size>
rustc_private)Trait Implementations
impl Copy for Size[src]
impl Clone for Size[src]
fn clone(&self) -> Size
Returns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0
Performs copy-assignment from source. Read more
impl PartialEq for Size[src]
fn eq(&self, __arg_0: &Size) -> bool
This method tests for self and other values to be equal, and is used by ==. Read more
fn ne(&self, __arg_0: &Size) -> bool
This method tests for !=.
impl Eq for Size[src]
impl PartialOrd for Size[src]
fn partial_cmp(&self, __arg_0: &Size) -> Option<Ordering>
This method returns an ordering between self and other values if one exists. Read more
fn lt(&self, __arg_0: &Size) -> bool
This method tests less than (for self and other) and is used by the < operator. Read more
fn le(&self, __arg_0: &Size) -> bool
This method tests less than or equal to (for self and other) and is used by the <= operator. Read more
fn gt(&self, __arg_0: &Size) -> bool
This method tests greater than (for self and other) and is used by the > operator. Read more
fn ge(&self, __arg_0: &Size) -> bool
This method tests greater than or equal to (for self and other) and is used by the >= operator. Read more
impl Ord for Size[src]
fn cmp(&self, __arg_0: &Size) -> Ordering
This method returns an Ordering between self and other. Read more
impl Hash for Size[src]
fn hash<__H: Hasher>(&self, __arg_0: &mut __H)
Feeds this value into the state given, updating the hasher as necessary.
fn hash_slice<H>(data: &[Self], state: &mut H) where H: Hasher1.3.0
Feeds a slice of this type into the state provided.