Struct rustc::ty::Destructor
[−]
[src]
pub struct Destructor {
pub did: DefId,
pub is_dtorck: bool,
}🔬 This is a nightly-only experimental API. (
rustc_private)Fields
did: DefId
🔬 This is a nightly-only experimental API. (
rustc_private)The def-id of the destructor method
is_dtorck: bool
🔬 This is a nightly-only experimental API. (
rustc_private)Invoking the destructor of a dtorck type during usual cleanup
(e.g. the glue emitted for stack unwinding) requires all
lifetimes in the type-structure of adt to strictly outlive
the adt value itself.
If adt is not dtorck, then the adt's destructor can be
invoked even when there are lifetimes in the type-structure of
adt that do not strictly outlive the adt value itself.
(This allows programs to make cyclic structures without
resorting to unsafe means; see RFCs 769 and 1238).