Struct rustc::ty::Issue32330
[−]
[src]
pub struct Issue32330 {
pub fn_def_id: DefId,
pub region_name: Name,
}rustc_private)When a region changed from late-bound to early-bound when #32330
was fixed, its RegionParameterDef will have one of these
structures that we can use to give nicer errors.
Fields
fn_def_id: DefId
rustc_private)fn where is region declared
region_name: Name
rustc_private)name of region; duplicates the info in BrNamed but convenient to have it here, and this code is only temporary