Struct rustc::ty::RegionVid
[−]
[src]
pub struct RegionVid {
pub index: u32,
}🔬 This is a nightly-only experimental API. (
rustc_private)Fields
index: u32
🔬 This is a nightly-only experimental API. (
rustc_private)Trait Implementations
impl UnifyKey for RegionVid[src]
type Value = RegionVidKey
🔬 This is a nightly-only experimental API. (
rustc_private)fn index(&self) -> u32
🔬 This is a nightly-only experimental API. (
rustc_private)fn from_index(i: u32) -> RegionVid
🔬 This is a nightly-only experimental API. (
rustc_private)fn tag(_: Option<RegionVid>) -> &'static str
🔬 This is a nightly-only experimental API. (
rustc_private)impl Clone for RegionVid[src]
fn clone(&self) -> RegionVid
Returns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0
Performs copy-assignment from source. Read more
impl PartialEq for RegionVid[src]
fn eq(&self, __arg_0: &RegionVid) -> bool
This method tests for self and other values to be equal, and is used by ==. Read more
fn ne(&self, __arg_0: &RegionVid) -> bool
This method tests for !=.
impl Eq for RegionVid[src]
impl Encodable for RegionVid[src]
fn encode<__S: Encoder>(&self, __arg_0: &mut __S) -> Result<(), __S::Error>
🔬 This is a nightly-only experimental API. (rustc_private)
deprecated in favor of rustc-serialize on crates.io
impl Decodable for RegionVid[src]
fn decode<__D: Decoder>(__arg_0: &mut __D) -> Result<RegionVid, __D::Error>
🔬 This is a nightly-only experimental API. (rustc_private)
deprecated in favor of rustc-serialize on crates.io
impl Hash for RegionVid[src]
fn hash<__H: Hasher>(&self, __arg_0: &mut __H)
Feeds this value into the state given, updating the hasher as necessary.
fn hash_slice<H>(data: &[Self], state: &mut H) where H: Hasher1.3.0
Feeds a slice of this type into the state provided.