Struct rustc::ty::SkolemizedRegionVid
[−]
[src]
pub struct SkolemizedRegionVid {
pub index: u32,
}🔬 This is a nightly-only experimental API. (
rustc_private)Fields
index: u32
🔬 This is a nightly-only experimental API. (
rustc_private)Trait Implementations
impl Clone for SkolemizedRegionVid[src]
fn clone(&self) -> SkolemizedRegionVid
Returns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0
Performs copy-assignment from source. Read more
impl Copy for SkolemizedRegionVid[src]
impl PartialEq for SkolemizedRegionVid[src]
fn eq(&self, __arg_0: &SkolemizedRegionVid) -> bool
This method tests for self and other values to be equal, and is used by ==. Read more
fn ne(&self, __arg_0: &SkolemizedRegionVid) -> bool
This method tests for !=.
impl Eq for SkolemizedRegionVid[src]
impl Hash for SkolemizedRegionVid[src]
fn hash<__H: Hasher>(&self, __arg_0: &mut __H)
Feeds this value into the state given, updating the hasher as necessary.
fn hash_slice<H>(data: &[Self], state: &mut H) where H: Hasher1.3.0
Feeds a slice of this type into the state provided.
impl Encodable for SkolemizedRegionVid[src]
fn encode<__S: Encoder>(&self, __arg_0: &mut __S) -> Result<(), __S::Error>
🔬 This is a nightly-only experimental API. (rustc_private)
deprecated in favor of rustc-serialize on crates.io
impl Decodable for SkolemizedRegionVid[src]
fn decode<__D: Decoder>(__arg_0: &mut __D)
-> Result<SkolemizedRegionVid, __D::Error>
-> Result<SkolemizedRegionVid, __D::Error>
🔬 This is a nightly-only experimental API. (rustc_private)
deprecated in favor of rustc-serialize on crates.io