Struct rustc::ty::subst::Kind
[−]
[src]
pub struct Kind<'tcx> { /* fields omitted */ }rustc_private)An entity in the Rust typesystem, which can be one of
several kinds (only types and lifetimes for now).
To reduce memory usage, a Kind is a interned pointer,
with the lowest 2 bits being reserved for a tag to
indicate the type (Ty or Region) it points to.
Methods
impl<'tcx> Kind<'tcx>[src]
fn as_type(self) -> Option<Ty<'tcx>>
rustc_private)fn as_region(self) -> Option<&'tcx Region>
rustc_private)Trait Implementations
impl<'tcx> Copy for Kind<'tcx>[src]
impl<'tcx> Clone for Kind<'tcx>[src]
fn clone(&self) -> Kind<'tcx>
Returns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0
Performs copy-assignment from source. Read more
impl<'tcx> PartialEq for Kind<'tcx>[src]
fn eq(&self, __arg_0: &Kind<'tcx>) -> bool
This method tests for self and other values to be equal, and is used by ==. Read more
fn ne(&self, __arg_0: &Kind<'tcx>) -> bool
This method tests for !=.
impl<'tcx> Eq for Kind<'tcx>[src]
impl<'tcx> Hash for Kind<'tcx>[src]
fn hash<__H: Hasher>(&self, __arg_0: &mut __H)
Feeds this value into the state given, updating the hasher as necessary.
fn hash_slice<H>(data: &[Self], state: &mut H) where H: Hasher1.3.0
Feeds a slice of this type into the state provided.
impl<'tcx> From<Ty<'tcx>> for Kind<'tcx>[src]
impl<'tcx> From<&'tcx Region> for Kind<'tcx>[src]
impl<'tcx> Debug for Kind<'tcx>[src]
impl<'tcx> TypeFoldable<'tcx> for Kind<'tcx>[src]
fn super_fold_with<'gcx: 'tcx, F: TypeFolder<'gcx, 'tcx>>(&self,
folder: &mut F)
-> Self
folder: &mut F)
-> Self
rustc_private)fn super_visit_with<V: TypeVisitor<'tcx>>(&self, visitor: &mut V) -> bool
rustc_private)fn fold_with<'gcx: 'tcx, F: TypeFolder<'gcx, 'tcx>>(&self,
folder: &mut F)
-> Self
folder: &mut F)
-> Self
rustc_private)fn visit_with<V: TypeVisitor<'tcx>>(&self, visitor: &mut V) -> bool
rustc_private)fn has_regions_escaping_depth(&self, depth: u32) -> bool
rustc_private)fn has_escaping_regions(&self) -> bool
rustc_private)fn has_type_flags(&self, flags: TypeFlags) -> bool
rustc_private)fn has_projection_types(&self) -> bool
rustc_private)fn references_error(&self) -> bool
rustc_private)fn has_param_types(&self) -> bool
rustc_private)fn has_self_ty(&self) -> bool
rustc_private)fn has_infer_types(&self) -> bool
rustc_private)fn needs_infer(&self) -> bool
rustc_private)fn needs_subst(&self) -> bool
rustc_private)fn has_re_skol(&self) -> bool
rustc_private)fn has_closure_types(&self) -> bool
rustc_private)fn has_erasable_regions(&self) -> bool
rustc_private)fn is_normalized_for_trans(&self) -> bool
rustc_private)fn is_global(&self) -> bool
rustc_private)Indicates whether this value references only 'global' types/lifetimes that are the same regardless of what fn we are in. This is used for caching. Errs on the side of returning false. Read more
impl<'tcx> Encodable for Kind<'tcx>[src]
fn encode<E: Encoder>(&self, e: &mut E) -> Result<(), E::Error>
🔬 This is a nightly-only experimental API. (rustc_private)
deprecated in favor of rustc-serialize on crates.io