Struct rustc::ty::trait_def::TraitFlags
[−]
pub struct TraitFlags { /* fields omitted */ }rustc_private)Methods
impl TraitFlags
const NO_TRAIT_FLAGS: TraitFlags
rustc_private)NO_TRAIT_FLAGS: TraitFlagsAngleBracketed { lifetimes: [], types: [], bindings: [] } = TraitFlags{bits: 0,}
const HAS_DEFAULT_IMPL: TraitFlags
rustc_private)HAS_DEFAULT_IMPL: TraitFlagsAngleBracketed { lifetimes: [], types: [], bindings: [] } = TraitFlags{bits: 1 << 0,}
const IS_OBJECT_SAFE: TraitFlags
rustc_private)IS_OBJECT_SAFE: TraitFlagsAngleBracketed { lifetimes: [], types: [], bindings: [] } = TraitFlags{bits: 1 << 1,}
const OBJECT_SAFETY_VALID: TraitFlags
rustc_private)OBJECT_SAFETY_VALID: TraitFlagsAngleBracketed { lifetimes: [], types: [], bindings: [] } = TraitFlags{bits: 1 << 2,}
const HAS_REMOTE_IMPLS: TraitFlags
rustc_private)HAS_REMOTE_IMPLS: TraitFlagsAngleBracketed { lifetimes: [], types: [], bindings: [] } = TraitFlags{bits: 1 << 3,}
const HAS_LOCAL_IMPLS: TraitFlags
rustc_private)HAS_LOCAL_IMPLS: TraitFlagsAngleBracketed { lifetimes: [], types: [], bindings: [] } = TraitFlags{bits: 1 << 4,}
fn empty() -> TraitFlags
rustc_private)Returns an empty set of flags.
fn all() -> TraitFlags
rustc_private)Returns the set containing all flags.
fn bits(&self) -> u32
rustc_private)Returns the raw value of the flags currently stored.
fn from_bits(bits: u32) -> Option<TraitFlags>
rustc_private)Convert from underlying bit representation, unless that representation contains bits that do not correspond to a flag.
fn from_bits_truncate(bits: u32) -> TraitFlags
rustc_private)Convert from underlying bit representation, dropping any bits that do not correspond to flags.
fn is_empty(&self) -> bool
rustc_private)Returns true if no flags are currently stored.
fn is_all(&self) -> bool
rustc_private)Returns true if all flags are currently set.
fn intersects(&self, other: TraitFlags) -> bool
rustc_private)Returns true if there are flags common to both self and other.
fn contains(&self, other: TraitFlags) -> bool
rustc_private)Returns true if all of the flags in other are contained within self.
fn insert(&mut self, other: TraitFlags)
rustc_private)Inserts the specified flags in-place.
fn remove(&mut self, other: TraitFlags)
rustc_private)Removes the specified flags in-place.
fn toggle(&mut self, other: TraitFlags)
rustc_private)Toggles the specified flags in-place.