Enum rustc_const_math::ConstIsize
[−]
[src]
pub enum ConstIsize {
Is16(i16),
Is32(i32),
Is64(i64),
}🔬 This is a nightly-only experimental API. (
rustc_private)Depending on the target only one variant is ever used in a compilation. Anything else is an error. This invariant is checked at several locations
Variants
Is16(i16)🔬 This is a nightly-only experimental API. (
rustc_private)Is32(i32)🔬 This is a nightly-only experimental API. (
rustc_private)Is64(i64)🔬 This is a nightly-only experimental API. (
rustc_private)Methods
impl ConstIsize[src]
fn as_i64(self, target_int_ty: IntTy) -> i64
🔬 This is a nightly-only experimental API. (
rustc_private)fn new(i: i64, target_int_ty: IntTy) -> Result<Self, ConstMathErr>
🔬 This is a nightly-only experimental API. (
rustc_private)fn new_truncating(i: i128, target_int_ty: IntTy) -> Self
🔬 This is a nightly-only experimental API. (
rustc_private)Trait Implementations
impl Copy for ConstIsize[src]
impl Clone for ConstIsize[src]
fn clone(&self) -> ConstIsize
Returns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0
Performs copy-assignment from source. Read more
impl Debug for ConstIsize[src]
impl Encodable for ConstIsize[src]
fn encode<__S: Encoder>(&self, __arg_0: &mut __S) -> Result<(), __S::Error>
🔬 This is a nightly-only experimental API. (rustc_private)
deprecated in favor of rustc-serialize on crates.io
impl Decodable for ConstIsize[src]
fn decode<__D: Decoder>(__arg_0: &mut __D) -> Result<ConstIsize, __D::Error>
🔬 This is a nightly-only experimental API. (rustc_private)
deprecated in favor of rustc-serialize on crates.io
impl Hash for ConstIsize[src]
fn hash<__H: Hasher>(&self, __arg_0: &mut __H)
Feeds this value into the state given, updating the hasher as necessary.
fn hash_slice<H>(data: &[Self], state: &mut H) where H: Hasher1.3.0
Feeds a slice of this type into the state provided.
impl Eq for ConstIsize[src]
impl PartialEq for ConstIsize[src]
fn eq(&self, __arg_0: &ConstIsize) -> bool
This method tests for self and other values to be equal, and is used by ==. Read more
fn ne(&self, __arg_0: &ConstIsize) -> bool
This method tests for !=.