Enum rustc_const_math::ConstUsize
[−]
[src]
pub enum ConstUsize {
Us16(u16),
Us32(u32),
Us64(u64),
}🔬 This is a nightly-only experimental API. (
rustc_private)Depending on the target only one variant is ever used in a compilation. Anything else is an error. This invariant is checked at several locations
Variants
Us16(u16)🔬 This is a nightly-only experimental API. (
rustc_private)Us32(u32)🔬 This is a nightly-only experimental API. (
rustc_private)Us64(u64)🔬 This is a nightly-only experimental API. (
rustc_private)Methods
impl ConstUsize[src]
fn as_u64(self, target_uint_ty: UintTy) -> u64
🔬 This is a nightly-only experimental API. (
rustc_private)fn new(i: u64, target_uint_ty: UintTy) -> Result<Self, ConstMathErr>
🔬 This is a nightly-only experimental API. (
rustc_private)fn new_truncating(i: u128, target_uint_ty: UintTy) -> Self
🔬 This is a nightly-only experimental API. (
rustc_private)Trait Implementations
impl Copy for ConstUsize[src]
impl Clone for ConstUsize[src]
fn clone(&self) -> ConstUsize
Returns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0
Performs copy-assignment from source. Read more
impl Debug for ConstUsize[src]
impl Encodable for ConstUsize[src]
fn encode<__S: Encoder>(&self, __arg_0: &mut __S) -> Result<(), __S::Error>
🔬 This is a nightly-only experimental API. (rustc_private)
deprecated in favor of rustc-serialize on crates.io
impl Decodable for ConstUsize[src]
fn decode<__D: Decoder>(__arg_0: &mut __D) -> Result<ConstUsize, __D::Error>
🔬 This is a nightly-only experimental API. (rustc_private)
deprecated in favor of rustc-serialize on crates.io
impl Hash for ConstUsize[src]
fn hash<__H: Hasher>(&self, __arg_0: &mut __H)
Feeds this value into the state given, updating the hasher as necessary.
fn hash_slice<H>(data: &[Self], state: &mut H) where H: Hasher1.3.0
Feeds a slice of this type into the state provided.
impl Eq for ConstUsize[src]
impl PartialEq for ConstUsize[src]
fn eq(&self, __arg_0: &ConstUsize) -> bool
This method tests for self and other values to be equal, and is used by ==. Read more
fn ne(&self, __arg_0: &ConstUsize) -> bool
This method tests for !=.