Struct rustc_data_structures::indexed_set::IdxSetBuf
[−]
[src]
pub struct IdxSetBuf<T: Idx> { /* fields omitted */ }🔬 This is a nightly-only experimental API. (
rustc_private)Represents a set (or packed family of sets), of some element type
E, where each E is identified by some unique index type T.
In other words, T is the type used to index into the bitvector
this type uses to represent the set of object it holds.
Methods
impl<T: Idx> IdxSetBuf<T>[src]
fn new_filled(universe_size: usize) -> Self
🔬 This is a nightly-only experimental API. (
rustc_private)Creates set holding every element whose index falls in range 0..universe_size.
fn new_empty(universe_size: usize) -> Self
🔬 This is a nightly-only experimental API. (
rustc_private)Creates set holding no elements.
Methods from Deref<Target=IdxSet<T>>
fn to_owned(&self) -> IdxSetBuf<T>
🔬 This is a nightly-only experimental API. (
rustc_private)fn remove(&mut self, elem: &T) -> bool
🔬 This is a nightly-only experimental API. (
rustc_private)Removes elem from the set self; returns true iff this changed self.
fn add(&mut self, elem: &T) -> bool
🔬 This is a nightly-only experimental API. (
rustc_private)Adds elem to the set self; returns true iff this changed self.
fn range(&self, elems: &Range<T>) -> &Self
🔬 This is a nightly-only experimental API. (
rustc_private)fn range_mut(&mut self, elems: &Range<T>) -> &mut Self
🔬 This is a nightly-only experimental API. (
rustc_private)fn contains(&self, elem: &T) -> bool
🔬 This is a nightly-only experimental API. (
rustc_private)Returns true iff set self contains elem.
fn words(&self) -> &[Word]
🔬 This is a nightly-only experimental API. (
rustc_private)fn words_mut(&mut self) -> &mut [Word]
🔬 This is a nightly-only experimental API. (
rustc_private)fn clone_from(&mut self, other: &IdxSet<T>)
🔬 This is a nightly-only experimental API. (
rustc_private)fn union(&mut self, other: &IdxSet<T>) -> bool
🔬 This is a nightly-only experimental API. (
rustc_private)fn subtract(&mut self, other: &IdxSet<T>) -> bool
🔬 This is a nightly-only experimental API. (
rustc_private)Trait Implementations
impl<T: Idx> Clone for IdxSetBuf<T>[src]
fn clone(&self) -> Self
Returns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0
Performs copy-assignment from source. Read more
impl<T: Idx> Debug for IdxSetBuf<T>[src]
impl<T: Idx> Deref for IdxSetBuf<T>[src]
type Target = IdxSet<T>
The resulting type after dereferencing
fn deref(&self) -> &IdxSet<T>
The method called to dereference a value