Struct rustc_data_structures::unify::Snapshot
[−]
[src]
pub struct Snapshot<K: UnifyKey> { /* fields omitted */ }🔬 This is a nightly-only experimental API. (
rustc_private)At any time, users may snapshot a unification table. The changes made during the snapshot may either be committed or rolled back.