Function rustc_driver::in_rustc_thread
[−]
[src]
pub fn in_rustc_thread<F, R>(f: F) -> Result<R, Box<Any + Send>> where F: FnOnce() -> R + Send + 'static, R: Send + 'static🔬 This is a nightly-only experimental API. (
rustc_private)Runs f in a suitable thread for running rustc; returns a
Result with either the return value of f or -- if a panic
occurs -- the panic value.