Enum rustc_errors::RenderSpan
[−]
[src]
pub enum RenderSpan {
FullSpan(MultiSpan),
Suggestion(CodeSuggestion),
}🔬 This is a nightly-only experimental API. (
rustc_private)Variants
FullSpan(MultiSpan)🔬 This is a nightly-only experimental API. (
rustc_private)A FullSpan renders with both with an initial line for the message, prefixed by file:linenum, followed by a summary of the source code covered by the span.
Suggestion(CodeSuggestion)🔬 This is a nightly-only experimental API. (
rustc_private)A suggestion renders with both with an initial line for the
message, prefixed by file:linenum, followed by a summary
of hypothetical source code, where each String is spliced
into the lines in place of the code covered by each span.