Struct rustc_errors::snippet::MultilineAnnotation
[−]
[src]
pub struct MultilineAnnotation {
pub depth: usize,
pub line_start: usize,
pub line_end: usize,
pub start_col: usize,
pub end_col: usize,
pub is_primary: bool,
pub label: Option<String>,
}🔬 This is a nightly-only experimental API. (
rustc_private)Fields
depth: usize
🔬 This is a nightly-only experimental API. (
rustc_private)line_start: usize
🔬 This is a nightly-only experimental API. (
rustc_private)line_end: usize
🔬 This is a nightly-only experimental API. (
rustc_private)start_col: usize
🔬 This is a nightly-only experimental API. (
rustc_private)end_col: usize
🔬 This is a nightly-only experimental API. (
rustc_private)is_primary: bool
🔬 This is a nightly-only experimental API. (
rustc_private)label: Option<String>
🔬 This is a nightly-only experimental API. (
rustc_private)Methods
impl MultilineAnnotation[src]
fn increase_depth(&mut self)
🔬 This is a nightly-only experimental API. (
rustc_private)fn as_start(&self) -> Annotation
🔬 This is a nightly-only experimental API. (
rustc_private)fn as_end(&self) -> Annotation
🔬 This is a nightly-only experimental API. (
rustc_private)fn as_line(&self) -> Annotation
🔬 This is a nightly-only experimental API. (
rustc_private)Trait Implementations
impl Clone for MultilineAnnotation[src]
fn clone(&self) -> MultilineAnnotation
Returns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0
Performs copy-assignment from source. Read more
impl Debug for MultilineAnnotation[src]
impl PartialOrd for MultilineAnnotation[src]
fn partial_cmp(&self, __arg_0: &MultilineAnnotation) -> Option<Ordering>
This method returns an ordering between self and other values if one exists. Read more
fn lt(&self, __arg_0: &MultilineAnnotation) -> bool
This method tests less than (for self and other) and is used by the < operator. Read more
fn le(&self, __arg_0: &MultilineAnnotation) -> bool
This method tests less than or equal to (for self and other) and is used by the <= operator. Read more
fn gt(&self, __arg_0: &MultilineAnnotation) -> bool
This method tests greater than (for self and other) and is used by the > operator. Read more
fn ge(&self, __arg_0: &MultilineAnnotation) -> bool
This method tests greater than or equal to (for self and other) and is used by the >= operator. Read more
impl Ord for MultilineAnnotation[src]
fn cmp(&self, __arg_0: &MultilineAnnotation) -> Ordering
This method returns an Ordering between self and other. Read more
impl PartialEq for MultilineAnnotation[src]
fn eq(&self, __arg_0: &MultilineAnnotation) -> bool
This method tests for self and other values to be equal, and is used by ==. Read more
fn ne(&self, __arg_0: &MultilineAnnotation) -> bool
This method tests for !=.