Struct rustc_lint::middle::region::BlockRemainder
[−]
[src]
pub struct BlockRemainder {
pub block: NodeId,
pub first_statement_index: u32,
}rustc_private)Represents a subscope of block for a binding that is introduced
by block.stmts[first_statement_index]. Such subscopes represent
a suffix of the block. Note that each subscope does not include
the initializer expression, if any, for the statement indexed by
first_statement_index.
For example, given { let (a, b) = EXPR_1; let c = EXPR_2; ... }:
the subscope with
first_statement_index == 0is scope of bothaandb; it does not include EXPR_1, but does include everything after that firstlet. (If you want a scope that includes EXPR_1 as well, then do not useCodeExtentData::Remainder, but instead anotherCodeExtentthat encompasses the whole block, e.g.CodeExtentData::Misc.the subscope with
first_statement_index == 1is scope ofc, and thus does not include EXPR_2, but covers the....
Fields
block: NodeId
rustc_private)first_statement_index: u32
rustc_private)Trait Implementations
impl Decodable for BlockRemainder[src]
fn decode<__D>(__arg_0: &mut __D) -> Result<BlockRemainder, __D::Error> where __D: Decoder
rustc_private)impl PartialOrd<BlockRemainder> for BlockRemainder[src]
fn partial_cmp(&self, __arg_0: &BlockRemainder) -> Option<Ordering>
rustc_private)fn lt(&self, __arg_0: &BlockRemainder) -> bool
rustc_private)fn le(&self, __arg_0: &BlockRemainder) -> bool
rustc_private)fn gt(&self, __arg_0: &BlockRemainder) -> bool
rustc_private)fn ge(&self, __arg_0: &BlockRemainder) -> bool
rustc_private)impl PartialEq<BlockRemainder> for BlockRemainder[src]
fn eq(&self, __arg_0: &BlockRemainder) -> bool
This method tests for self and other values to be equal, and is used by ==. Read more
fn ne(&self, __arg_0: &BlockRemainder) -> bool
This method tests for !=.
impl Hash for BlockRemainder[src]
fn hash<__H>(&self, __arg_0: &mut __H) where __H: Hasher
rustc_private)impl Clone for BlockRemainder[src]
fn clone(&self) -> BlockRemainder
Returns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0
Performs copy-assignment from source. Read more
impl Eq for BlockRemainder[src]
impl Debug for BlockRemainder[src]
fn fmt(&self, __arg_0: &mut Formatter) -> Result<(), Error>
rustc_private)impl Encodable for BlockRemainder[src]
fn encode<__S>(&self, __arg_0: &mut __S) -> Result<(), __S::Error> where __S: Encoder
rustc_private)impl Copy for BlockRemainder[src]
impl Ord for BlockRemainder[src]
fn cmp(&self, __arg_0: &BlockRemainder) -> Ordering
rustc_private)