Struct rustc_llvm::ffi::debuginfo::DIFlags
[−]
#[repr(C)]pub struct DIFlags { /* fields omitted */ }
rustc_private)Methods
impl DIFlags
const FlagZero: DIFlags
rustc_private)FlagZero: DIFlagsAngleBracketed { lifetimes: [], types: [], bindings: [] } = DIFlags{bits: 0,}
const FlagPrivate: DIFlags
rustc_private)FlagPrivate: DIFlagsAngleBracketed { lifetimes: [], types: [], bindings: [] } = DIFlags{bits: 1,}
const FlagProtected: DIFlags
rustc_private)FlagProtected: DIFlagsAngleBracketed { lifetimes: [], types: [], bindings: [] } = DIFlags{bits: 2,}
const FlagPublic: DIFlags
rustc_private)FlagPublic: DIFlagsAngleBracketed { lifetimes: [], types: [], bindings: [] } = DIFlags{bits: 3,}
const FlagFwdDecl: DIFlags
rustc_private)FlagFwdDecl: DIFlagsAngleBracketed { lifetimes: [], types: [], bindings: [] } = DIFlags{bits: 1 << 2,}
const FlagAppleBlock: DIFlags
rustc_private)FlagAppleBlock: DIFlagsAngleBracketed { lifetimes: [], types: [], bindings: [] } = DIFlags{bits: 1 << 3,}
const FlagBlockByrefStruct: DIFlags
rustc_private)FlagBlockByrefStruct: DIFlagsAngleBracketed { lifetimes: [], types: [], bindings: [] } = DIFlags{bits: 1 << 4,}
const FlagVirtual: DIFlags
rustc_private)FlagVirtual: DIFlagsAngleBracketed { lifetimes: [], types: [], bindings: [] } = DIFlags{bits: 1 << 5,}
const FlagArtificial: DIFlags
rustc_private)FlagArtificial: DIFlagsAngleBracketed { lifetimes: [], types: [], bindings: [] } = DIFlags{bits: 1 << 6,}
const FlagExplicit: DIFlags
rustc_private)FlagExplicit: DIFlagsAngleBracketed { lifetimes: [], types: [], bindings: [] } = DIFlags{bits: 1 << 7,}
const FlagPrototyped: DIFlags
rustc_private)FlagPrototyped: DIFlagsAngleBracketed { lifetimes: [], types: [], bindings: [] } = DIFlags{bits: 1 << 8,}
const FlagObjcClassComplete: DIFlags
rustc_private)FlagObjcClassComplete: DIFlagsAngleBracketed { lifetimes: [], types: [], bindings: [] } = DIFlags{bits: 1 << 9,}
const FlagObjectPointer: DIFlags
rustc_private)FlagObjectPointer: DIFlagsAngleBracketed { lifetimes: [], types: [], bindings: [] } = DIFlags{bits: 1 << 10,}
const FlagVector: DIFlags
rustc_private)FlagVector: DIFlagsAngleBracketed { lifetimes: [], types: [], bindings: [] } = DIFlags{bits: 1 << 11,}
const FlagStaticMember: DIFlags
rustc_private)FlagStaticMember: DIFlagsAngleBracketed { lifetimes: [], types: [], bindings: [] } = DIFlags{bits: 1 << 12,}
const FlagLValueReference: DIFlags
rustc_private)FlagLValueReference: DIFlagsAngleBracketed { lifetimes: [], types: [], bindings: [] } = DIFlags{bits: 1 << 13,}
const FlagRValueReference: DIFlags
rustc_private)FlagRValueReference: DIFlagsAngleBracketed { lifetimes: [], types: [], bindings: [] } = DIFlags{bits: 1 << 14,}
const FlagMainSubprogram: DIFlags
rustc_private)FlagMainSubprogram: DIFlagsAngleBracketed { lifetimes: [], types: [], bindings: [] } = DIFlags{bits: 1 << 21,}
fn empty() -> DIFlags
rustc_private)Returns an empty set of flags.
fn all() -> DIFlags
rustc_private)Returns the set containing all flags.
fn bits(&self) -> uint32_t
rustc_private)Returns the raw value of the flags currently stored.
fn from_bits(bits: uint32_t) -> Option<DIFlags>
rustc_private)Convert from underlying bit representation, unless that representation contains bits that do not correspond to a flag.
fn from_bits_truncate(bits: uint32_t) -> DIFlags
rustc_private)Convert from underlying bit representation, dropping any bits that do not correspond to flags.
fn is_empty(&self) -> bool
rustc_private)Returns true if no flags are currently stored.
fn is_all(&self) -> bool
rustc_private)Returns true if all flags are currently set.
fn intersects(&self, other: DIFlags) -> bool
rustc_private)Returns true if there are flags common to both self and other.
fn contains(&self, other: DIFlags) -> bool
rustc_private)Returns true if all of the flags in other are contained within self.
fn insert(&mut self, other: DIFlags)
rustc_private)Inserts the specified flags in-place.
fn remove(&mut self, other: DIFlags)
rustc_private)Removes the specified flags in-place.
fn toggle(&mut self, other: DIFlags)
rustc_private)Toggles the specified flags in-place.