Enum rustc_llvm::ffi::Visibility
[−]
[src]
#[repr(C)]pub enum Visibility { Default, Hidden, Protected, }
🔬 This is a nightly-only experimental API. (
rustc_private)Variants
Default🔬 This is a nightly-only experimental API. (
rustc_private)Hidden🔬 This is a nightly-only experimental API. (
rustc_private)Protected🔬 This is a nightly-only experimental API. (
rustc_private)Trait Implementations
impl Copy for Visibility[src]
impl Clone for Visibility[src]
fn clone(&self) -> Visibility
Returns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0
Performs copy-assignment from source. Read more
impl PartialEq for Visibility[src]
fn eq(&self, __arg_0: &Visibility) -> bool
This method tests for self and other values to be equal, and is used by ==. Read more
fn ne(&self, other: &Rhs) -> bool1.0.0
This method tests for !=.
impl Eq for Visibility[src]
impl Hash for Visibility[src]
fn hash<__H: Hasher>(&self, __arg_0: &mut __H)
Feeds this value into the state given, updating the hasher as necessary.
fn hash_slice<H>(data: &[Self], state: &mut H) where H: Hasher1.3.0
Feeds a slice of this type into the state provided.