Enum rustc_metadata::middle::mem_categorization::FieldName
[−]
[src]
pub enum FieldName {
NamedField(Symbol),
PositionalField(usize),
}🔬 This is a nightly-only experimental API. (
rustc_private)Variants
NamedField(Symbol)🔬 This is a nightly-only experimental API. (
rustc_private)PositionalField(usize)🔬 This is a nightly-only experimental API. (
rustc_private)Trait Implementations
impl PartialEq<FieldName> for FieldName[src]
fn eq(&self, __arg_0: &FieldName) -> bool
This method tests for self and other values to be equal, and is used by ==. Read more
fn ne(&self, __arg_0: &FieldName) -> bool
This method tests for !=.
impl Hash for FieldName[src]
fn hash<__H>(&self, __arg_0: &mut __H) where __H: Hasher
Feeds this value into the state given, updating the hasher as necessary.
fn hash_slice<H>(data: &[Self], state: &mut H) where H: Hasher1.3.0
Feeds a slice of this type into the state provided.
impl Clone for FieldName[src]
fn clone(&self) -> FieldName
Returns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0
Performs copy-assignment from source. Read more
impl Eq for FieldName[src]
impl Debug for FieldName[src]
fn fmt(&self, __arg_0: &mut Formatter) -> Result<(), Error>
Formats the value using the given formatter.