Function rustc_mir::pretty::dump_mir
[−]
[src]
pub fn dump_mir<'a, 'tcx>(tcx: TyCtxt<'a, 'tcx, 'tcx>,
pass_name: &str,
disambiguator: &Display,
src: MirSource,
mir: &Mir<'tcx>)
🔬 This is a nightly-only experimental API. (
rustc_private)If the session is properly configured, dumps a human-readable representation of the mir into:
rustc.node<node_id>.<pass_name>.<disambiguator>
Output from this function is controlled by passing -Z dump-mir=<filter>,
where <filter> takes the following forms:
all-- dump MIR for all fns, all passes, all everythingsubstring1&substring2,...--&-separated list of substrings that can appear in the pass-name or theitem_path_strfor the given node-id. If any one of the substrings match, the data is dumped out.