Enum rustc_mir::transform::promote_consts::TempState
[−]
[src]
pub enum TempState {
Undefined,
Defined {
location: Location,
uses: usize,
},
Unpromotable,
PromotedOut,
}🔬 This is a nightly-only experimental API. (
rustc_private)State of a temporary during collection and promotion.
Variants
Undefined🔬 This is a nightly-only experimental API. (
rustc_private)No references to this temp.
Defined🔬 This is a nightly-only experimental API. (
rustc_private)One direct assignment and any number of direct uses. A borrow of this temp is promotable if the assigned value is qualified as constant.
Fields of Defined
location: Location | 🔬 This is a nightly-only experimental API. ( rustc_private) |
uses: usize | 🔬 This is a nightly-only experimental API. ( rustc_private) |
Unpromotable🔬 This is a nightly-only experimental API. (
rustc_private)Any other combination of assignments/uses.
PromotedOut🔬 This is a nightly-only experimental API. (
rustc_private)This temp was part of an rvalue which got extracted during promotion and needs cleanup.
Methods
impl TempState[src]
fn is_promotable(&self) -> bool
🔬 This is a nightly-only experimental API. (
rustc_private)Trait Implementations
impl Copy for TempState[src]
impl Clone for TempState[src]
fn clone(&self) -> TempState
Returns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0
Performs copy-assignment from source. Read more
impl PartialEq for TempState[src]
fn eq(&self, __arg_0: &TempState) -> bool
This method tests for self and other values to be equal, and is used by ==. Read more
fn ne(&self, __arg_0: &TempState) -> bool
This method tests for !=.