Enum rustc_platform_intrinsics::Type
[−]
[src]
pub enum Type {
Void,
Integer(bool, u8, u8),
Float(u8),
Pointer(&'static Type, Option<&'static Type>, bool),
Vector(&'static Type, Option<&'static Type>, u8),
Aggregate(bool, &'static [&'static Type]),
}🔬 This is a nightly-only experimental API. (
rustc_private)Variants
Void🔬 This is a nightly-only experimental API. (
rustc_private)Integer(bool, u8, u8)🔬 This is a nightly-only experimental API. (
rustc_private)Float(u8)🔬 This is a nightly-only experimental API. (
rustc_private)Pointer(&'static Type, Option<&'static Type>, bool)🔬 This is a nightly-only experimental API. (
rustc_private)Vector(&'static Type, Option<&'static Type>, u8)🔬 This is a nightly-only experimental API. (
rustc_private)Aggregate(bool, &'static [&'static Type])🔬 This is a nightly-only experimental API. (
rustc_private)Trait Implementations
impl Clone for Type[src]
fn clone(&self) -> Type
Returns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0
Performs copy-assignment from source. Read more
impl Hash for Type[src]
fn hash<__H: Hasher>(&self, __arg_0: &mut __H)
Feeds this value into the state given, updating the hasher as necessary.
fn hash_slice<H>(data: &[Self], state: &mut H) where H: Hasher1.3.0
Feeds a slice of this type into the state provided.