Struct rustc_trans::back::svh::Svh
[−]
[src]
pub struct Svh { /* fields omitted */ }🔬 This is a nightly-only experimental API. (
rustc_private)Methods
impl Svh[src]
fn new(hash: u64) -> Svh
🔬 This is a nightly-only experimental API. (
rustc_private)Create a new Svh given the hash. If you actually want to
compute the SVH from some HIR, you want the calculate_svh
function found in librustc_incremental.
fn as_u64(&self) -> u64
🔬 This is a nightly-only experimental API. (
rustc_private)fn to_string(&self) -> String
🔬 This is a nightly-only experimental API. (
rustc_private)Trait Implementations
impl Decodable for Svh[src]
fn decode<D>(d: &mut D) -> Result<Svh, D::Error> where D: Decoder
🔬 This is a nightly-only experimental API. (
rustc_private)impl Display for Svh[src]
fn fmt(&self, f: &mut Formatter) -> Result<(), Error>
Formats the value using the given formatter. Read more
impl PartialEq<Svh> for Svh[src]
fn eq(&self, __arg_0: &Svh) -> bool
This method tests for self and other values to be equal, and is used by ==. Read more
fn ne(&self, __arg_0: &Svh) -> bool
This method tests for !=.
impl Hash for Svh[src]
fn hash<H>(&self, state: &mut H) where H: Hasher
Feeds this value into the state given, updating the hasher as necessary.
fn hash_slice<H>(data: &[Self], state: &mut H) where H: Hasher1.3.0
Feeds a slice of this type into the state provided.
impl Clone for Svh[src]
fn clone(&self) -> Svh
Returns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0
Performs copy-assignment from source. Read more
impl Eq for Svh[src]
impl Debug for Svh[src]
fn fmt(&self, __arg_0: &mut Formatter) -> Result<(), Error>
Formats the value using the given formatter.
impl Encodable for Svh[src]
fn encode<S>(&self, s: &mut S) -> Result<(), S::Error> where S: Encoder
🔬 This is a nightly-only experimental API. (
rustc_private)