Enum rustc_trans::back::symbol_export::SymbolExportLevel
[−]
[src]
pub enum SymbolExportLevel {
C,
Rust,
}🔬 This is a nightly-only experimental API. (
rustc_private)The SymbolExportLevel of a symbols specifies from which kinds of crates
the symbol will be exported. C symbols will be exported from any
kind of crate, including cdylibs which export very few things.
Rust will only be exported if the crate produced is a Rust
dylib.
Variants
C🔬 This is a nightly-only experimental API. (
rustc_private)Rust🔬 This is a nightly-only experimental API. (
rustc_private)Trait Implementations
impl Eq for SymbolExportLevel[src]
impl PartialEq for SymbolExportLevel[src]
fn eq(&self, __arg_0: &SymbolExportLevel) -> bool
This method tests for self and other values to be equal, and is used by ==. Read more
fn ne(&self, other: &Rhs) -> bool1.0.0
This method tests for !=.
impl Debug for SymbolExportLevel[src]
impl Copy for SymbolExportLevel[src]
impl Clone for SymbolExportLevel[src]
fn clone(&self) -> SymbolExportLevel
Returns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0
Performs copy-assignment from source. Read more