Struct rustc_trans::middle::cstore::NativeLibrary
[−]
[src]
pub struct NativeLibrary {
pub kind: NativeLibraryKind,
pub name: Symbol,
pub cfg: Option<MetaItem>,
pub foreign_items: Vec<DefIndex>,
}🔬 This is a nightly-only experimental API. (
rustc_private)Fields
kind: NativeLibraryKind
🔬 This is a nightly-only experimental API. (
rustc_private)name: Symbol
🔬 This is a nightly-only experimental API. (
rustc_private)cfg: Option<MetaItem>
🔬 This is a nightly-only experimental API. (
rustc_private)foreign_items: Vec<DefIndex>
🔬 This is a nightly-only experimental API. (
rustc_private)Trait Implementations
impl Decodable for NativeLibrary[src]
fn decode<__D>(__arg_0: &mut __D) -> Result<NativeLibrary, __D::Error> where __D: Decoder
🔬 This is a nightly-only experimental API. (
rustc_private)impl Hash for NativeLibrary[src]
fn hash<__H>(&self, __arg_0: &mut __H) where __H: Hasher
Feeds this value into the state given, updating the hasher as necessary.
fn hash_slice<H>(data: &[Self], state: &mut H) where H: Hasher1.3.0
Feeds a slice of this type into the state provided.
impl Clone for NativeLibrary[src]
fn clone(&self) -> NativeLibrary
Returns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0
Performs copy-assignment from source. Read more