Enum rustc_trans::middle::mem_categorization::MutabilityCategory
[−]
[src]
pub enum MutabilityCategory {
McImmutable,
McDeclared,
McInherited,
}🔬 This is a nightly-only experimental API. (
rustc_private)Variants
McImmutable🔬 This is a nightly-only experimental API. (
rustc_private)McDeclared🔬 This is a nightly-only experimental API. (
rustc_private)McInherited🔬 This is a nightly-only experimental API. (
rustc_private)Methods
impl MutabilityCategory[src]
fn from_mutbl(m: Mutability) -> MutabilityCategory
🔬 This is a nightly-only experimental API. (
rustc_private)fn from_borrow_kind(borrow_kind: BorrowKind) -> MutabilityCategory
🔬 This is a nightly-only experimental API. (
rustc_private)fn inherit(&self) -> MutabilityCategory
🔬 This is a nightly-only experimental API. (
rustc_private)fn is_mutable(&self) -> bool
🔬 This is a nightly-only experimental API. (
rustc_private)fn is_immutable(&self) -> bool
🔬 This is a nightly-only experimental API. (
rustc_private)fn to_user_str(&self) -> &'static str
🔬 This is a nightly-only experimental API. (
rustc_private)Trait Implementations
impl PartialEq<MutabilityCategory> for MutabilityCategory[src]
fn eq(&self, __arg_0: &MutabilityCategory) -> bool
This method tests for self and other values to be equal, and is used by ==. Read more
fn ne(&self, other: &Rhs) -> bool1.0.0
This method tests for !=.
impl Hash for MutabilityCategory[src]
fn hash<__H>(&self, __arg_0: &mut __H) where __H: Hasher
Feeds this value into the state given, updating the hasher as necessary.
fn hash_slice<H>(data: &[Self], state: &mut H) where H: Hasher1.3.0
Feeds a slice of this type into the state provided.
impl Clone for MutabilityCategory[src]
fn clone(&self) -> MutabilityCategory
Returns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0
Performs copy-assignment from source. Read more
impl Eq for MutabilityCategory[src]
impl Debug for MutabilityCategory[src]
fn fmt(&self, __arg_0: &mut Formatter) -> Result<(), Error>
Formats the value using the given formatter.