Enum rustc_trans::middle::resolve_lifetime::Region
[−]
[src]
pub enum Region {
Static,
EarlyBound(u32, NodeId),
LateBound(DebruijnIndex, NodeId),
LateBoundAnon(DebruijnIndex, u32),
Free(CallSiteScopeData, NodeId),
}🔬 This is a nightly-only experimental API. (
rustc_private)Variants
Static🔬 This is a nightly-only experimental API. (
rustc_private)EarlyBound(u32, NodeId)🔬 This is a nightly-only experimental API. (
rustc_private)LateBound(DebruijnIndex, NodeId)🔬 This is a nightly-only experimental API. (
rustc_private)LateBoundAnon(DebruijnIndex, u32)🔬 This is a nightly-only experimental API. (
rustc_private)Free(CallSiteScopeData, NodeId)🔬 This is a nightly-only experimental API. (
rustc_private)Trait Implementations
impl Decodable for Region[src]
fn decode<__D>(__arg_0: &mut __D) -> Result<Region, __D::Error> where __D: Decoder
🔬 This is a nightly-only experimental API. (
rustc_private)impl PartialEq<Region> for Region[src]
fn eq(&self, __arg_0: &Region) -> bool
This method tests for self and other values to be equal, and is used by ==. Read more
fn ne(&self, __arg_0: &Region) -> bool
This method tests for !=.
impl Hash for Region[src]
fn hash<__H>(&self, __arg_0: &mut __H) where __H: Hasher
Feeds this value into the state given, updating the hasher as necessary.
fn hash_slice<H>(data: &[Self], state: &mut H) where H: Hasher1.3.0
Feeds a slice of this type into the state provided.
impl Clone for Region[src]
fn clone(&self) -> Region
Returns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0
Performs copy-assignment from source. Read more
impl Eq for Region[src]
impl Debug for Region[src]
fn fmt(&self, __arg_0: &mut Formatter) -> Result<(), Error>
Formats the value using the given formatter.
impl Encodable for Region[src]
fn encode<__S>(&self, __arg_0: &mut __S) -> Result<(), __S::Error> where __S: Encoder
🔬 This is a nightly-only experimental API. (
rustc_private)