Struct rustc_trans::session::config::OutputFilenames
[−]
[src]
pub struct OutputFilenames {
pub out_directory: PathBuf,
pub out_filestem: String,
pub single_output_file: Option<PathBuf>,
pub extra: String,
pub outputs: OutputTypes,
}🔬 This is a nightly-only experimental API. (
rustc_private)Fields
out_directory: PathBuf
🔬 This is a nightly-only experimental API. (
rustc_private)out_filestem: String
🔬 This is a nightly-only experimental API. (
rustc_private)single_output_file: Option<PathBuf>
🔬 This is a nightly-only experimental API. (
rustc_private)extra: String
🔬 This is a nightly-only experimental API. (
rustc_private)outputs: OutputTypes
🔬 This is a nightly-only experimental API. (
rustc_private)Methods
impl OutputFilenames[src]
fn path(&self, flavor: OutputType) -> PathBuf
🔬 This is a nightly-only experimental API. (
rustc_private)fn temp_path(&self,
flavor: OutputType,
codegen_unit_name: Option<&str>)
-> PathBuf
flavor: OutputType,
codegen_unit_name: Option<&str>)
-> PathBuf
🔬 This is a nightly-only experimental API. (
rustc_private)Get the path where a compilation artifact of the given type for the given codegen unit should be placed on disk. If codegen_unit_name is None, a path distinct from those of any codegen unit will be generated.
fn temp_path_ext(&self, ext: &str, codegen_unit_name: Option<&str>) -> PathBuf
🔬 This is a nightly-only experimental API. (
rustc_private)Like temp_path, but also supports things where there is no corresponding OutputType, like no-opt-bitcode or lto-bitcode.
fn with_extension(&self, extension: &str) -> PathBuf
🔬 This is a nightly-only experimental API. (
rustc_private)fn filestem(&self) -> String
🔬 This is a nightly-only experimental API. (
rustc_private)Trait Implementations
impl Clone for OutputFilenames[src]
fn clone(&self) -> OutputFilenames
Returns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0
Performs copy-assignment from source. Read more