Enum rustc_typeck::dep_graph::DepNode
[−]
[src]
pub enum DepNode<D> where D: Clone + Debug {
Krate,
Hir(D),
HirBody(D),
MetaData(D),
WorkProduct(Arc<WorkProductId>),
CollectLanguageItems,
CheckStaticRecursion,
ResolveLifetimes,
RegionResolveCrate,
CheckLoops,
PluginRegistrar,
StabilityIndex,
CollectItem(D),
CollectItemSig(D),
Coherence,
EffectCheck,
Liveness,
Resolve,
EntryPoint,
CheckEntryFn,
CoherenceCheckTrait(D),
CoherenceCheckImpl(D),
CoherenceOverlapCheck(D),
CoherenceOverlapCheckSpecial(D),
CoherenceOverlapInherentCheck(D),
CoherenceOrphanCheck(D),
Variance,
WfCheck(D),
TypeckItemType(D),
UnusedTraitCheck,
CheckConst(D),
Privacy,
IntrinsicCheck(D),
MatchCheck(D),
MirKrate,
Mir(D),
BorrowCheckKrate,
BorrowCheck(D),
RvalueCheck(D),
Reachability,
DeadCheck,
StabilityCheck(D),
LateLintCheck,
TransCrate,
TransCrateItem(D),
TransInlinedItem(D),
TransWriteMetadata,
LinkBinary,
AssociatedItems(D),
ItemSignature(D),
TypeParamPredicates((D, D)),
SizedConstraint(D),
AdtDestructor(D),
AssociatedItemDefIds(D),
InherentImpls(D),
TypeckBodiesKrate,
TypeckTables(D),
UsedTraitImports(D),
MonomorphicConstEval(D),
TraitImpls(D),
TraitItems(D),
ReprHints(D),
TraitSelect {
trait_def_id: D,
input_def_id: D,
},
ProjectionCache {
def_ids: Vec<D>,
},
}rustc_private)Variants
Kraterustc_private)Hir(D)rustc_private)HirBody(D)rustc_private)MetaData(D)rustc_private)WorkProduct(Arc<WorkProductId>)rustc_private)CollectLanguageItemsrustc_private)CheckStaticRecursionrustc_private)ResolveLifetimesrustc_private)RegionResolveCraterustc_private)CheckLoopsrustc_private)PluginRegistrarrustc_private)StabilityIndexrustc_private)CollectItem(D)rustc_private)CollectItemSig(D)rustc_private)Coherencerustc_private)EffectCheckrustc_private)Livenessrustc_private)Resolverustc_private)EntryPointrustc_private)CheckEntryFnrustc_private)CoherenceCheckTrait(D)rustc_private)CoherenceCheckImpl(D)rustc_private)CoherenceOverlapCheck(D)rustc_private)CoherenceOverlapCheckSpecial(D)rustc_private)CoherenceOverlapInherentCheck(D)rustc_private)CoherenceOrphanCheck(D)rustc_private)Variancerustc_private)WfCheck(D)rustc_private)TypeckItemType(D)rustc_private)UnusedTraitCheckrustc_private)CheckConst(D)rustc_private)Privacyrustc_private)IntrinsicCheck(D)rustc_private)MatchCheck(D)rustc_private)MirKraterustc_private)Mir(D)rustc_private)BorrowCheckKraterustc_private)BorrowCheck(D)rustc_private)RvalueCheck(D)rustc_private)Reachabilityrustc_private)DeadCheckrustc_private)StabilityCheck(D)rustc_private)LateLintCheckrustc_private)TransCraterustc_private)TransCrateItem(D)rustc_private)TransInlinedItem(D)rustc_private)TransWriteMetadatarustc_private)LinkBinaryrustc_private)AssociatedItems(D)rustc_private)ItemSignature(D)rustc_private)TypeParamPredicates((D, D))rustc_private)SizedConstraint(D)rustc_private)AdtDestructor(D)rustc_private)AssociatedItemDefIds(D)rustc_private)InherentImpls(D)rustc_private)TypeckBodiesKraterustc_private)TypeckTables(D)rustc_private)UsedTraitImports(D)rustc_private)MonomorphicConstEval(D)rustc_private)TraitImpls(D)rustc_private)TraitItems(D)rustc_private)ReprHints(D)rustc_private)TraitSelectrustc_private)Fields of TraitSelect
trait_def_id: D | 🔬 This is a nightly-only experimental API. ( rustc_private) |
input_def_id: D | 🔬 This is a nightly-only experimental API. ( rustc_private) |
ProjectionCacherustc_private)Fields of ProjectionCache
def_ids: Vec<D> | 🔬 This is a nightly-only experimental API. ( rustc_private) |
Methods
impl<D> DepNode<D> where D: Clone + Debug[src]
fn from_label_string(label: &str, data: D) -> Result<DepNode<D>, ()>
rustc_private)Used in testing
fn map_def<E, OP>(&self, op: OP) -> Option<DepNode<E>> where E: Clone + Debug, OP: FnMut(&D) -> Option<E>
rustc_private)Trait Implementations
impl<D> Decodable for DepNode<D> where D: Clone + Debug + Decodable[src]
fn decode<__DD>(__arg_0: &mut __DD) -> Result<DepNode<D>, __DD::Error> where __DD: Decoder
rustc_private)impl<D> PartialOrd<DepNode<D>> for DepNode<D> where D: PartialOrd<D> + Clone + Debug[src]
fn partial_cmp(&self, __arg_0: &DepNode<D>) -> Option<Ordering>
This method returns an ordering between self and other values if one exists. Read more
fn lt(&self, __arg_0: &DepNode<D>) -> bool
This method tests less than (for self and other) and is used by the < operator. Read more
fn le(&self, __arg_0: &DepNode<D>) -> bool
This method tests less than or equal to (for self and other) and is used by the <= operator. Read more
fn gt(&self, __arg_0: &DepNode<D>) -> bool
This method tests greater than (for self and other) and is used by the > operator. Read more
fn ge(&self, __arg_0: &DepNode<D>) -> bool
This method tests greater than or equal to (for self and other) and is used by the >= operator. Read more
impl<D> PartialEq<DepNode<D>> for DepNode<D> where D: PartialEq<D> + Clone + Debug[src]
fn eq(&self, __arg_0: &DepNode<D>) -> bool
This method tests for self and other values to be equal, and is used by ==. Read more
fn ne(&self, __arg_0: &DepNode<D>) -> bool
This method tests for !=.
impl<D> Hash for DepNode<D> where D: Clone + Hash + Debug[src]
fn hash<__HD>(&self, __arg_0: &mut __HD) where __HD: Hasher
Feeds this value into the state given, updating the hasher as necessary.
fn hash_slice<H>(data: &[Self], state: &mut H) where H: Hasher1.3.0
Feeds a slice of this type into the state provided.
impl<D> Clone for DepNode<D> where D: Clone + Clone + Debug[src]
fn clone(&self) -> DepNode<D>
Returns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0
Performs copy-assignment from source. Read more
impl<D> Eq for DepNode<D> where D: Eq + Clone + Debug[src]
impl<D> Debug for DepNode<D> where D: Clone + Debug + Debug[src]
fn fmt(&self, __arg_0: &mut Formatter) -> Result<(), Error>
Formats the value using the given formatter.
impl<D> Encodable for DepNode<D> where D: Clone + Debug + Encodable[src]
fn encode<__SD>(&self, __arg_0: &mut __SD) -> Result<(), __SD::Error> where __SD: Encoder
rustc_private)