Enum rustc_typeck::hir::def::CtorKind
[−]
[src]
pub enum CtorKind {
Fn,
Const,
Fictive,
}🔬 This is a nightly-only experimental API. (
rustc_private)Variants
Fn🔬 This is a nightly-only experimental API. (
rustc_private)Const🔬 This is a nightly-only experimental API. (
rustc_private)Fictive🔬 This is a nightly-only experimental API. (
rustc_private)Methods
impl CtorKind[src]
fn from_ast(vdata: &VariantData) -> CtorKind
🔬 This is a nightly-only experimental API. (
rustc_private)fn from_hir(vdata: &VariantData) -> CtorKind
🔬 This is a nightly-only experimental API. (
rustc_private)Trait Implementations
impl Decodable for CtorKind[src]
fn decode<__D>(__arg_0: &mut __D) -> Result<CtorKind, __D::Error> where __D: Decoder
🔬 This is a nightly-only experimental API. (
rustc_private)impl PartialEq<CtorKind> for CtorKind[src]
fn eq(&self, __arg_0: &CtorKind) -> bool
This method tests for self and other values to be equal, and is used by ==. Read more
fn ne(&self, other: &Rhs) -> bool1.0.0
This method tests for !=.
impl Hash for CtorKind[src]
fn hash<__H>(&self, __arg_0: &mut __H) where __H: Hasher
Feeds this value into the state given, updating the hasher as necessary.
fn hash_slice<H>(data: &[Self], state: &mut H) where H: Hasher1.3.0
Feeds a slice of this type into the state provided.
impl Clone for CtorKind[src]
fn clone(&self) -> CtorKind
Returns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0
Performs copy-assignment from source. Read more
impl Eq for CtorKind[src]
impl Debug for CtorKind[src]
fn fmt(&self, __arg_0: &mut Formatter) -> Result<(), Error>
Formats the value using the given formatter.
impl Encodable for CtorKind[src]
fn encode<__S>(&self, __arg_0: &mut __S) -> Result<(), __S::Error> where __S: Encoder
🔬 This is a nightly-only experimental API. (
rustc_private)