Struct rustc_typeck::hir::def_id::CrateNum
[−]
[src]
pub struct CrateNum(_);
rustc_private)Methods
impl CrateNum[src]
fn new(x: usize) -> CrateNum
rustc_private)fn from_u32(x: u32) -> CrateNum
rustc_private)fn as_usize(&self) -> usize
rustc_private)fn as_u32(&self) -> u32
rustc_private)Trait Implementations
impl PartialOrd<CrateNum> for CrateNum[src]
fn partial_cmp(&self, __arg_0: &CrateNum) -> Option<Ordering>
This method returns an ordering between self and other values if one exists. Read more
fn lt(&self, __arg_0: &CrateNum) -> bool
This method tests less than (for self and other) and is used by the < operator. Read more
fn le(&self, __arg_0: &CrateNum) -> bool
This method tests less than or equal to (for self and other) and is used by the <= operator. Read more
fn gt(&self, __arg_0: &CrateNum) -> bool
This method tests greater than (for self and other) and is used by the > operator. Read more
fn ge(&self, __arg_0: &CrateNum) -> bool
This method tests greater than or equal to (for self and other) and is used by the >= operator. Read more
impl Display for CrateNum[src]
fn fmt(&self, f: &mut Formatter) -> Result<(), Error>
rustc_private)impl PartialEq<CrateNum> for CrateNum[src]
fn eq(&self, __arg_0: &CrateNum) -> bool
This method tests for self and other values to be equal, and is used by ==. Read more
fn ne(&self, __arg_0: &CrateNum) -> bool
This method tests for !=.
impl Idx for CrateNum[src]
fn new(value: usize) -> CrateNum
rustc_private)fn index(self) -> usize
rustc_private)impl Hash for CrateNum[src]
fn hash<__H>(&self, __arg_0: &mut __H) where __H: Hasher
Feeds this value into the state given, updating the hasher as necessary.
fn hash_slice<H>(data: &[Self], state: &mut H) where H: Hasher1.3.0
Feeds a slice of this type into the state provided.
impl UseSpecializedEncodable for CrateNum[src]
fn default_encode<S>(&self, s: &mut S) -> Result<(), S::Error> where S: Encoder
rustc_private)impl Clone for CrateNum[src]
fn clone(&self) -> CrateNum
Returns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0
Performs copy-assignment from source. Read more
impl UseSpecializedDecodable for CrateNum[src]
fn default_decode<D>(d: &mut D) -> Result<CrateNum, D::Error> where D: Decoder
rustc_private)impl Eq for CrateNum[src]
impl Debug for CrateNum[src]
fn fmt(&self, __arg_0: &mut Formatter) -> Result<(), Error>
Formats the value using the given formatter.