Struct rustc_typeck::hir::def_id::DefId
[−]
[src]
pub struct DefId {
pub krate: CrateNum,
pub index: DefIndex,
}rustc_private)A DefId identifies a particular definition, by combining a crate index and a def index.
Fields
krate: CrateNum
rustc_private)index: DefIndex
rustc_private)Methods
impl DefId[src]
fn local(index: DefIndex) -> DefId
rustc_private)fn is_local(&self) -> bool
rustc_private)Trait Implementations
impl Decodable for DefId[src]
fn decode<__D>(__arg_0: &mut __D) -> Result<DefId, __D::Error> where __D: Decoder
rustc_private)impl PartialOrd<DefId> for DefId[src]
fn partial_cmp(&self, __arg_0: &DefId) -> Option<Ordering>
This method returns an ordering between self and other values if one exists. Read more
fn lt(&self, __arg_0: &DefId) -> bool
This method tests less than (for self and other) and is used by the < operator. Read more
fn le(&self, __arg_0: &DefId) -> bool
This method tests less than or equal to (for self and other) and is used by the <= operator. Read more
fn gt(&self, __arg_0: &DefId) -> bool
This method tests greater than (for self and other) and is used by the > operator. Read more
fn ge(&self, __arg_0: &DefId) -> bool
This method tests greater than or equal to (for self and other) and is used by the >= operator. Read more
impl PartialEq<DefId> for DefId[src]
fn eq(&self, __arg_0: &DefId) -> bool
This method tests for self and other values to be equal, and is used by ==. Read more
fn ne(&self, __arg_0: &DefId) -> bool
This method tests for !=.
impl Hash for DefId[src]
fn hash<__H>(&self, __arg_0: &mut __H) where __H: Hasher
Feeds this value into the state given, updating the hasher as necessary.
fn hash_slice<H>(data: &[Self], state: &mut H) where H: Hasher1.3.0
Feeds a slice of this type into the state provided.
impl DepGraphSafe for DefId[src]
A DefId on its own doesn't give access to any particular state.
You must fetch the state from the various maps or generate
on-demand queries, all of which create reads.
impl Clone for DefId[src]
fn clone(&self) -> DefId
Returns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0
Performs copy-assignment from source. Read more
impl Eq for DefId[src]
impl Debug for DefId[src]
impl Encodable for DefId[src]
fn encode<__S>(&self, __arg_0: &mut __S) -> Result<(), __S::Error> where __S: Encoder
rustc_private)