Enum rustc_typeck::hir::AssociatedItemKind
[−]
[src]
pub enum AssociatedItemKind {
Const,
Method {
has_self: bool,
},
Type,
}🔬 This is a nightly-only experimental API. (
rustc_private)Variants
Const🔬 This is a nightly-only experimental API. (
rustc_private)Method🔬 This is a nightly-only experimental API. (
rustc_private)Fields of Method
has_self: bool | 🔬 This is a nightly-only experimental API. ( rustc_private) |
Type🔬 This is a nightly-only experimental API. (
rustc_private)Trait Implementations
impl Decodable for AssociatedItemKind[src]
fn decode<__D>(__arg_0: &mut __D) -> Result<AssociatedItemKind, __D::Error> where __D: Decoder
🔬 This is a nightly-only experimental API. (
rustc_private)impl PartialEq<AssociatedItemKind> for AssociatedItemKind[src]
fn eq(&self, __arg_0: &AssociatedItemKind) -> bool
This method tests for self and other values to be equal, and is used by ==. Read more
fn ne(&self, __arg_0: &AssociatedItemKind) -> bool
This method tests for !=.
impl Hash for AssociatedItemKind[src]
fn hash<__H>(&self, __arg_0: &mut __H) where __H: Hasher
Feeds this value into the state given, updating the hasher as necessary.
fn hash_slice<H>(data: &[Self], state: &mut H) where H: Hasher1.3.0
Feeds a slice of this type into the state provided.
impl Clone for AssociatedItemKind[src]
fn clone(&self) -> AssociatedItemKind
Returns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0
Performs copy-assignment from source. Read more
impl Eq for AssociatedItemKind[src]
impl Debug for AssociatedItemKind[src]
fn fmt(&self, __arg_0: &mut Formatter) -> Result<(), Error>
Formats the value using the given formatter.
impl Encodable for AssociatedItemKind[src]
fn encode<__S>(&self, __arg_0: &mut __S) -> Result<(), __S::Error> where __S: Encoder
🔬 This is a nightly-only experimental API. (
rustc_private)