Enum rustc_typeck::hir::ForeignItem_
[−]
[src]
pub enum ForeignItem_ {
ForeignItemFn(P<FnDecl>, P<[Spanned<Symbol>]>, Generics),
ForeignItemStatic(P<Ty>, bool),
}🔬 This is a nightly-only experimental API. (
rustc_private)An item within an extern block
Variants
ForeignItemFn(P<FnDecl>, P<[Spanned<Symbol>]>, Generics)🔬 This is a nightly-only experimental API. (
rustc_private)A foreign function
ForeignItemStatic(P<Ty>, bool)🔬 This is a nightly-only experimental API. (
rustc_private)A foreign static item (static ext: u8), with optional mutability
(the boolean is true when mutable)
Methods
impl ForeignItem_[src]
fn descriptive_variant(&self) -> &str
🔬 This is a nightly-only experimental API. (
rustc_private)Trait Implementations
impl Decodable for ForeignItem_[src]
fn decode<__D>(__arg_0: &mut __D) -> Result<ForeignItem_, __D::Error> where __D: Decoder
🔬 This is a nightly-only experimental API. (
rustc_private)impl PartialEq<ForeignItem_> for ForeignItem_[src]
fn eq(&self, __arg_0: &ForeignItem_) -> bool
This method tests for self and other values to be equal, and is used by ==. Read more
fn ne(&self, __arg_0: &ForeignItem_) -> bool
This method tests for !=.
impl Hash for ForeignItem_[src]
fn hash<__H>(&self, __arg_0: &mut __H) where __H: Hasher
Feeds this value into the state given, updating the hasher as necessary.
fn hash_slice<H>(data: &[Self], state: &mut H) where H: Hasher1.3.0
Feeds a slice of this type into the state provided.
impl Clone for ForeignItem_[src]
fn clone(&self) -> ForeignItem_
Returns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0
Performs copy-assignment from source. Read more
impl Eq for ForeignItem_[src]
impl Debug for ForeignItem_[src]
fn fmt(&self, __arg_0: &mut Formatter) -> Result<(), Error>
Formats the value using the given formatter.