Enum rustc_typeck::hir::LoopIdError
[−]
[src]
pub enum LoopIdError {
OutsideLoopScope,
UnlabeledCfInWhileCondition,
UnresolvedLabel,
}🔬 This is a nightly-only experimental API. (
rustc_private)Variants
OutsideLoopScope🔬 This is a nightly-only experimental API. (
rustc_private)UnlabeledCfInWhileCondition🔬 This is a nightly-only experimental API. (
rustc_private)UnresolvedLabel🔬 This is a nightly-only experimental API. (
rustc_private)Trait Implementations
impl Decodable for LoopIdError[src]
fn decode<__D>(__arg_0: &mut __D) -> Result<LoopIdError, __D::Error> where __D: Decoder
🔬 This is a nightly-only experimental API. (
rustc_private)impl Display for LoopIdError[src]
fn fmt(&self, f: &mut Formatter) -> Result<(), Error>
🔬 This is a nightly-only experimental API. (
rustc_private)impl PartialEq<LoopIdError> for LoopIdError[src]
fn eq(&self, __arg_0: &LoopIdError) -> bool
This method tests for self and other values to be equal, and is used by ==. Read more
fn ne(&self, other: &Rhs) -> bool1.0.0
This method tests for !=.
impl Hash for LoopIdError[src]
fn hash<__H>(&self, __arg_0: &mut __H) where __H: Hasher
Feeds this value into the state given, updating the hasher as necessary.
fn hash_slice<H>(data: &[Self], state: &mut H) where H: Hasher1.3.0
Feeds a slice of this type into the state provided.
impl Clone for LoopIdError[src]
fn clone(&self) -> LoopIdError
Returns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0
Performs copy-assignment from source. Read more
impl Eq for LoopIdError[src]
impl Debug for LoopIdError[src]
fn fmt(&self, __arg_0: &mut Formatter) -> Result<(), Error>
Formats the value using the given formatter.
impl Encodable for LoopIdError[src]
fn encode<__S>(&self, __arg_0: &mut __S) -> Result<(), __S::Error> where __S: Encoder
🔬 This is a nightly-only experimental API. (
rustc_private)