Enum rustc_typeck::hir::LoopIdResult
[−]
[src]
pub enum LoopIdResult {
Ok(NodeId),
Err(LoopIdError),
}🔬 This is a nightly-only experimental API. (
rustc_private)Variants
Ok(NodeId)🔬 This is a nightly-only experimental API. (
rustc_private)Err(LoopIdError)🔬 This is a nightly-only experimental API. (
rustc_private)Trait Implementations
impl Decodable for LoopIdResult[src]
fn decode<__D>(__arg_0: &mut __D) -> Result<LoopIdResult, __D::Error> where __D: Decoder
🔬 This is a nightly-only experimental API. (
rustc_private)impl PartialEq<LoopIdResult> for LoopIdResult[src]
fn eq(&self, __arg_0: &LoopIdResult) -> bool
This method tests for self and other values to be equal, and is used by ==. Read more
fn ne(&self, __arg_0: &LoopIdResult) -> bool
This method tests for !=.
impl Hash for LoopIdResult[src]
fn hash<__H>(&self, __arg_0: &mut __H) where __H: Hasher
Feeds this value into the state given, updating the hasher as necessary.
fn hash_slice<H>(data: &[Self], state: &mut H) where H: Hasher1.3.0
Feeds a slice of this type into the state provided.
impl Clone for LoopIdResult[src]
fn clone(&self) -> LoopIdResult
Returns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0
Performs copy-assignment from source. Read more
impl From<Result<NodeId, LoopIdError>> for LoopIdResult[src]
fn from(res: Result<NodeId, LoopIdError>) -> LoopIdResult
Performs the conversion.
impl Into<Result<NodeId, LoopIdError>> for LoopIdResult[src]
fn into(self) -> Result<NodeId, LoopIdError>
🔬 This is a nightly-only experimental API. (
rustc_private)impl Eq for LoopIdResult[src]
impl Debug for LoopIdResult[src]
fn fmt(&self, __arg_0: &mut Formatter) -> Result<(), Error>
Formats the value using the given formatter.
impl Encodable for LoopIdResult[src]
fn encode<__S>(&self, __arg_0: &mut __S) -> Result<(), __S::Error> where __S: Encoder
🔬 This is a nightly-only experimental API. (
rustc_private)