Enum rustc_typeck::hir::Stmt_
[−]
[src]
pub enum Stmt_ {
StmtDecl(P<Spanned<Decl_>>, NodeId),
StmtExpr(P<Expr>, NodeId),
StmtSemi(P<Expr>, NodeId),
}🔬 This is a nightly-only experimental API. (
rustc_private)Variants
StmtDecl(P<Spanned<Decl_>>, NodeId)🔬 This is a nightly-only experimental API. (
rustc_private)Could be an item or a local (let) binding:
StmtExpr(P<Expr>, NodeId)🔬 This is a nightly-only experimental API. (
rustc_private)Expr without trailing semi-colon (must have unit type):
StmtSemi(P<Expr>, NodeId)🔬 This is a nightly-only experimental API. (
rustc_private)Expr with trailing semi-colon (may have any type):
Methods
impl Stmt_[src]
fn attrs(&self) -> &[Attribute]
🔬 This is a nightly-only experimental API. (
rustc_private)fn id(&self) -> NodeId
🔬 This is a nightly-only experimental API. (
rustc_private)Trait Implementations
impl Decodable for Stmt_[src]
fn decode<__D>(__arg_0: &mut __D) -> Result<Stmt_, __D::Error> where __D: Decoder
🔬 This is a nightly-only experimental API. (
rustc_private)impl PartialEq<Stmt_> for Stmt_[src]
fn eq(&self, __arg_0: &Stmt_) -> bool
This method tests for self and other values to be equal, and is used by ==. Read more
fn ne(&self, __arg_0: &Stmt_) -> bool
This method tests for !=.
impl Hash for Stmt_[src]
fn hash<__H>(&self, __arg_0: &mut __H) where __H: Hasher
Feeds this value into the state given, updating the hasher as necessary.
fn hash_slice<H>(data: &[Self], state: &mut H) where H: Hasher1.3.0
Feeds a slice of this type into the state provided.
impl Clone for Stmt_[src]
fn clone(&self) -> Stmt_
Returns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0
Performs copy-assignment from source. Read more