Enum rustc_typeck::hir::Unsafety
[−]
[src]
pub enum Unsafety {
Unsafe,
Normal,
}🔬 This is a nightly-only experimental API. (
rustc_private)Variants
Unsafe🔬 This is a nightly-only experimental API. (
rustc_private)Normal🔬 This is a nightly-only experimental API. (
rustc_private)Trait Implementations
impl Decodable for Unsafety[src]
fn decode<__D>(__arg_0: &mut __D) -> Result<Unsafety, __D::Error> where __D: Decoder
🔬 This is a nightly-only experimental API. (
rustc_private)impl Display for Unsafety[src]
fn fmt(&self, f: &mut Formatter) -> Result<(), Error>
🔬 This is a nightly-only experimental API. (
rustc_private)impl PartialEq<Unsafety> for Unsafety[src]
fn eq(&self, __arg_0: &Unsafety) -> bool
This method tests for self and other values to be equal, and is used by ==. Read more
fn ne(&self, other: &Rhs) -> bool1.0.0
This method tests for !=.
impl Hash for Unsafety[src]
fn hash<__H>(&self, __arg_0: &mut __H) where __H: Hasher
Feeds this value into the state given, updating the hasher as necessary.
fn hash_slice<H>(data: &[Self], state: &mut H) where H: Hasher1.3.0
Feeds a slice of this type into the state provided.
impl<'tcx> TypeFoldable<'tcx> for Unsafety[src]
fn super_fold_with<'gcx, F>(&self, &mut F) -> Unsafety where 'gcx: 'tcx, F: TypeFolder<'gcx, 'tcx>
🔬 This is a nightly-only experimental API. (
rustc_private)fn super_visit_with<F>(&self, &mut F) -> bool where F: TypeVisitor<'tcx>
🔬 This is a nightly-only experimental API. (
rustc_private)fn fold_with<'gcx, F>(&self, folder: &mut F) -> Self where 'gcx: 'tcx, F: TypeFolder<'gcx, 'tcx>
🔬 This is a nightly-only experimental API. (
rustc_private)fn visit_with<V>(&self, visitor: &mut V) -> bool where V: TypeVisitor<'tcx>
🔬 This is a nightly-only experimental API. (
rustc_private)fn has_regions_escaping_depth(&self, depth: u32) -> bool
🔬 This is a nightly-only experimental API. (
rustc_private)fn has_escaping_regions(&self) -> bool
🔬 This is a nightly-only experimental API. (
rustc_private)fn has_type_flags(&self, flags: TypeFlags) -> bool
🔬 This is a nightly-only experimental API. (
rustc_private)fn has_projection_types(&self) -> bool
🔬 This is a nightly-only experimental API. (
rustc_private)fn references_error(&self) -> bool
🔬 This is a nightly-only experimental API. (
rustc_private)fn has_param_types(&self) -> bool
🔬 This is a nightly-only experimental API. (
rustc_private)fn has_self_ty(&self) -> bool
🔬 This is a nightly-only experimental API. (
rustc_private)fn has_infer_types(&self) -> bool
🔬 This is a nightly-only experimental API. (
rustc_private)fn needs_infer(&self) -> bool
🔬 This is a nightly-only experimental API. (
rustc_private)fn needs_subst(&self) -> bool
🔬 This is a nightly-only experimental API. (
rustc_private)fn has_re_skol(&self) -> bool
🔬 This is a nightly-only experimental API. (
rustc_private)fn has_closure_types(&self) -> bool
🔬 This is a nightly-only experimental API. (
rustc_private)fn has_erasable_regions(&self) -> bool
🔬 This is a nightly-only experimental API. (
rustc_private)fn is_normalized_for_trans(&self) -> bool
🔬 This is a nightly-only experimental API. (
rustc_private)fn is_global(&self) -> bool
🔬 This is a nightly-only experimental API. (
rustc_private)Indicates whether this value references only 'global' types/lifetimes that are the same regardless of what fn we are in. This is used for caching. Errs on the side of returning false. Read more
impl<'tcx> Relate<'tcx> for Unsafety[src]
fn relate<'a, 'gcx, R>(relation: &mut R,
a: &Unsafety,
b: &Unsafety)
-> Result<Unsafety, TypeError<'tcx>> where 'gcx: 'a, 'gcx: 'tcx, 'tcx: 'a, R: TypeRelation<'a, 'gcx, 'tcx>
a: &Unsafety,
b: &Unsafety)
-> Result<Unsafety, TypeError<'tcx>> where 'gcx: 'a, 'gcx: 'tcx, 'tcx: 'a, R: TypeRelation<'a, 'gcx, 'tcx>
🔬 This is a nightly-only experimental API. (
rustc_private)impl Clone for Unsafety[src]
fn clone(&self) -> Unsafety
Returns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0
Performs copy-assignment from source. Read more
impl Eq for Unsafety[src]
impl Debug for Unsafety[src]
fn fmt(&self, __arg_0: &mut Formatter) -> Result<(), Error>
Formats the value using the given formatter.
impl Encodable for Unsafety[src]
fn encode<__S>(&self, __arg_0: &mut __S) -> Result<(), __S::Error> where __S: Encoder
🔬 This is a nightly-only experimental API. (
rustc_private)