Enum rustc_typeck::hir::Visibility
[−]
[src]
pub enum Visibility {
Public,
Crate,
Restricted {
path: P<Path>,
id: NodeId,
},
Inherited,
}🔬 This is a nightly-only experimental API. (
rustc_private)Variants
Public🔬 This is a nightly-only experimental API. (
rustc_private)Crate🔬 This is a nightly-only experimental API. (
rustc_private)Restricted🔬 This is a nightly-only experimental API. (
rustc_private)Fields of Restricted
path: P<Path> | 🔬 This is a nightly-only experimental API. ( rustc_private) |
id: NodeId | 🔬 This is a nightly-only experimental API. ( rustc_private) |
Inherited🔬 This is a nightly-only experimental API. (
rustc_private)Trait Implementations
impl Decodable for Visibility[src]
fn decode<__D>(__arg_0: &mut __D) -> Result<Visibility, __D::Error> where __D: Decoder
🔬 This is a nightly-only experimental API. (
rustc_private)impl PartialEq<Visibility> for Visibility[src]
fn eq(&self, __arg_0: &Visibility) -> bool
This method tests for self and other values to be equal, and is used by ==. Read more
fn ne(&self, __arg_0: &Visibility) -> bool
This method tests for !=.
impl Hash for Visibility[src]
fn hash<__H>(&self, __arg_0: &mut __H) where __H: Hasher
Feeds this value into the state given, updating the hasher as necessary.
fn hash_slice<H>(data: &[Self], state: &mut H) where H: Hasher1.3.0
Feeds a slice of this type into the state provided.
impl Clone for Visibility[src]
fn clone(&self) -> Visibility
Returns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0
Performs copy-assignment from source. Read more
impl Eq for Visibility[src]
impl Debug for Visibility[src]
fn fmt(&self, __arg_0: &mut Formatter) -> Result<(), Error>
Formats the value using the given formatter.