Struct rustc_typeck::hir::BareFnTy
[−]
[src]
pub struct BareFnTy {
pub unsafety: Unsafety,
pub abi: Abi,
pub lifetimes: P<[LifetimeDef]>,
pub decl: P<FnDecl>,
}🔬 This is a nightly-only experimental API. (
rustc_private)Fields
unsafety: Unsafety
🔬 This is a nightly-only experimental API. (
rustc_private)abi: Abi
🔬 This is a nightly-only experimental API. (
rustc_private)lifetimes: P<[LifetimeDef]>
🔬 This is a nightly-only experimental API. (
rustc_private)decl: P<FnDecl>
🔬 This is a nightly-only experimental API. (
rustc_private)Trait Implementations
impl Decodable for BareFnTy[src]
fn decode<__D>(__arg_0: &mut __D) -> Result<BareFnTy, __D::Error> where __D: Decoder
🔬 This is a nightly-only experimental API. (
rustc_private)impl PartialEq<BareFnTy> for BareFnTy[src]
fn eq(&self, __arg_0: &BareFnTy) -> bool
This method tests for self and other values to be equal, and is used by ==. Read more
fn ne(&self, __arg_0: &BareFnTy) -> bool
This method tests for !=.
impl Hash for BareFnTy[src]
fn hash<__H>(&self, __arg_0: &mut __H) where __H: Hasher
Feeds this value into the state given, updating the hasher as necessary.
fn hash_slice<H>(data: &[Self], state: &mut H) where H: Hasher1.3.0
Feeds a slice of this type into the state provided.
impl Clone for BareFnTy[src]
fn clone(&self) -> BareFnTy
Returns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0
Performs copy-assignment from source. Read more
impl Eq for BareFnTy[src]
impl Debug for BareFnTy[src]
fn fmt(&self, __arg_0: &mut Formatter) -> Result<(), Error>
Formats the value using the given formatter.