Struct rustc_typeck::hir::Block
[−]
[src]
pub struct Block {
pub stmts: P<[Spanned<Stmt_>]>,
pub expr: Option<P<Expr>>,
pub id: NodeId,
pub rules: BlockCheckMode,
pub span: Span,
}🔬 This is a nightly-only experimental API. (
rustc_private)Fields
stmts: P<[Spanned<Stmt_>]>
🔬 This is a nightly-only experimental API. (
rustc_private)Statements in a block
expr: Option<P<Expr>>
🔬 This is a nightly-only experimental API. (
rustc_private)An expression at the end of the block without a semicolon, if any
id: NodeId
🔬 This is a nightly-only experimental API. (
rustc_private)rules: BlockCheckMode
🔬 This is a nightly-only experimental API. (
rustc_private)Distinguishes between unsafe { ... } and { ... }
span: Span
🔬 This is a nightly-only experimental API. (
rustc_private)Trait Implementations
impl Decodable for Block[src]
fn decode<__D>(__arg_0: &mut __D) -> Result<Block, __D::Error> where __D: Decoder
🔬 This is a nightly-only experimental API. (
rustc_private)impl PartialEq<Block> for Block[src]
fn eq(&self, __arg_0: &Block) -> bool
This method tests for self and other values to be equal, and is used by ==. Read more
fn ne(&self, __arg_0: &Block) -> bool
This method tests for !=.
impl Hash for Block[src]
fn hash<__H>(&self, __arg_0: &mut __H) where __H: Hasher
Feeds this value into the state given, updating the hasher as necessary.
fn hash_slice<H>(data: &[Self], state: &mut H) where H: Hasher1.3.0
Feeds a slice of this type into the state provided.
impl Clone for Block[src]
fn clone(&self) -> Block
Returns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0
Performs copy-assignment from source. Read more
impl Eq for Block[src]
impl Debug for Block[src]
fn fmt(&self, __arg_0: &mut Formatter) -> Result<(), Error>
Formats the value using the given formatter.