Struct rustc_typeck::hir::Expr
[−]
[src]
pub struct Expr {
pub id: NodeId,
pub span: Span,
pub node: Expr_,
pub attrs: ThinVec<Attribute>,
}🔬 This is a nightly-only experimental API. (
rustc_private)An expression
Fields
id: NodeId
🔬 This is a nightly-only experimental API. (
rustc_private)span: Span
🔬 This is a nightly-only experimental API. (
rustc_private)node: Expr_
🔬 This is a nightly-only experimental API. (
rustc_private)attrs: ThinVec<Attribute>
🔬 This is a nightly-only experimental API. (
rustc_private)Trait Implementations
impl Decodable for Expr[src]
fn decode<__D>(__arg_0: &mut __D) -> Result<Expr, __D::Error> where __D: Decoder
🔬 This is a nightly-only experimental API. (
rustc_private)impl MaybeFnLike for Expr[src]
fn is_fn_like(&self) -> bool
🔬 This is a nightly-only experimental API. (
rustc_private)impl PartialEq<Expr> for Expr[src]
fn eq(&self, __arg_0: &Expr) -> bool
This method tests for self and other values to be equal, and is used by ==. Read more
fn ne(&self, __arg_0: &Expr) -> bool
This method tests for !=.
impl Hash for Expr[src]
fn hash<__H>(&self, __arg_0: &mut __H) where __H: Hasher
Feeds this value into the state given, updating the hasher as necessary.
fn hash_slice<H>(data: &[Self], state: &mut H) where H: Hasher1.3.0
Feeds a slice of this type into the state provided.
impl ast_node for Expr[src]
fn id(&self) -> NodeId
🔬 This is a nightly-only experimental API. (
rustc_private)fn span(&self) -> Span
🔬 This is a nightly-only experimental API. (
rustc_private)impl Clone for Expr[src]
fn clone(&self) -> Expr
Returns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0
Performs copy-assignment from source. Read more