Struct rustc_typeck::hir::FnDecl
[−]
[src]
pub struct FnDecl {
pub inputs: P<[P<Ty>]>,
pub output: FunctionRetTy,
pub variadic: bool,
}🔬 This is a nightly-only experimental API. (
rustc_private)Represents the header (not the body) of a function declaration
Fields
inputs: P<[P<Ty>]>
🔬 This is a nightly-only experimental API. (
rustc_private)output: FunctionRetTy
🔬 This is a nightly-only experimental API. (
rustc_private)variadic: bool
🔬 This is a nightly-only experimental API. (
rustc_private)Trait Implementations
impl Decodable for FnDecl[src]
fn decode<__D>(__arg_0: &mut __D) -> Result<FnDecl, __D::Error> where __D: Decoder
🔬 This is a nightly-only experimental API. (
rustc_private)impl PartialEq<FnDecl> for FnDecl[src]
fn eq(&self, __arg_0: &FnDecl) -> bool
This method tests for self and other values to be equal, and is used by ==. Read more
fn ne(&self, __arg_0: &FnDecl) -> bool
This method tests for !=.
impl Hash for FnDecl[src]
fn hash<__H>(&self, __arg_0: &mut __H) where __H: Hasher
Feeds this value into the state given, updating the hasher as necessary.
fn hash_slice<H>(data: &[Self], state: &mut H) where H: Hasher1.3.0
Feeds a slice of this type into the state provided.
impl Clone for FnDecl[src]
fn clone(&self) -> FnDecl
Returns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0
Performs copy-assignment from source. Read more
impl Eq for FnDecl[src]
impl Debug for FnDecl[src]
fn fmt(&self, __arg_0: &mut Formatter) -> Result<(), Error>
Formats the value using the given formatter.