Struct rustc_typeck::hir::Generics
[−]
[src]
pub struct Generics {
pub lifetimes: P<[LifetimeDef]>,
pub ty_params: P<[TyParam]>,
pub where_clause: WhereClause,
pub span: Span,
}🔬 This is a nightly-only experimental API. (
rustc_private)Represents lifetimes and type parameters attached to a declaration of a function, enum, trait, etc.
Fields
lifetimes: P<[LifetimeDef]>
🔬 This is a nightly-only experimental API. (
rustc_private)ty_params: P<[TyParam]>
🔬 This is a nightly-only experimental API. (
rustc_private)where_clause: WhereClause
🔬 This is a nightly-only experimental API. (
rustc_private)span: Span
🔬 This is a nightly-only experimental API. (
rustc_private)Methods
impl Generics[src]
fn empty() -> Generics
🔬 This is a nightly-only experimental API. (
rustc_private)fn is_lt_parameterized(&self) -> bool
🔬 This is a nightly-only experimental API. (
rustc_private)fn is_type_parameterized(&self) -> bool
🔬 This is a nightly-only experimental API. (
rustc_private)fn is_parameterized(&self) -> bool
🔬 This is a nightly-only experimental API. (
rustc_private)impl Generics[src]
fn carries_unsafe_attr(&self) -> Option<UnsafeGeneric>
🔬 This is a nightly-only experimental API. (
rustc_private)Trait Implementations
impl Decodable for Generics[src]
fn decode<__D>(__arg_0: &mut __D) -> Result<Generics, __D::Error> where __D: Decoder
🔬 This is a nightly-only experimental API. (
rustc_private)impl PartialEq<Generics> for Generics[src]
fn eq(&self, __arg_0: &Generics) -> bool
This method tests for self and other values to be equal, and is used by ==. Read more
fn ne(&self, __arg_0: &Generics) -> bool
This method tests for !=.
impl Hash for Generics[src]
fn hash<__H>(&self, __arg_0: &mut __H) where __H: Hasher
Feeds this value into the state given, updating the hasher as necessary.
fn hash_slice<H>(data: &[Self], state: &mut H) where H: Hasher1.3.0
Feeds a slice of this type into the state provided.
impl Clone for Generics[src]
fn clone(&self) -> Generics
Returns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0
Performs copy-assignment from source. Read more
impl Eq for Generics[src]
impl Debug for Generics[src]
fn fmt(&self, __arg_0: &mut Formatter) -> Result<(), Error>
Formats the value using the given formatter.