Struct rustc_typeck::hir::InlineAsm
[−]
[src]
pub struct InlineAsm {
pub asm: Symbol,
pub asm_str_style: StrStyle,
pub outputs: P<[InlineAsmOutput]>,
pub inputs: P<[Symbol]>,
pub clobbers: P<[Symbol]>,
pub volatile: bool,
pub alignstack: bool,
pub dialect: AsmDialect,
pub expn_id: ExpnId,
}🔬 This is a nightly-only experimental API. (
rustc_private)Fields
asm: Symbol
🔬 This is a nightly-only experimental API. (
rustc_private)asm_str_style: StrStyle
🔬 This is a nightly-only experimental API. (
rustc_private)outputs: P<[InlineAsmOutput]>
🔬 This is a nightly-only experimental API. (
rustc_private)inputs: P<[Symbol]>
🔬 This is a nightly-only experimental API. (
rustc_private)clobbers: P<[Symbol]>
🔬 This is a nightly-only experimental API. (
rustc_private)volatile: bool
🔬 This is a nightly-only experimental API. (
rustc_private)alignstack: bool
🔬 This is a nightly-only experimental API. (
rustc_private)dialect: AsmDialect
🔬 This is a nightly-only experimental API. (
rustc_private)expn_id: ExpnId
🔬 This is a nightly-only experimental API. (
rustc_private)Trait Implementations
impl Decodable for InlineAsm[src]
fn decode<__D>(__arg_0: &mut __D) -> Result<InlineAsm, __D::Error> where __D: Decoder
🔬 This is a nightly-only experimental API. (
rustc_private)impl PartialEq<InlineAsm> for InlineAsm[src]
fn eq(&self, __arg_0: &InlineAsm) -> bool
This method tests for self and other values to be equal, and is used by ==. Read more
fn ne(&self, __arg_0: &InlineAsm) -> bool
This method tests for !=.
impl Hash for InlineAsm[src]
fn hash<__H>(&self, __arg_0: &mut __H) where __H: Hasher
Feeds this value into the state given, updating the hasher as necessary.
fn hash_slice<H>(data: &[Self], state: &mut H) where H: Hasher1.3.0
Feeds a slice of this type into the state provided.
impl Clone for InlineAsm[src]
fn clone(&self) -> InlineAsm
Returns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0
Performs copy-assignment from source. Read more
impl Eq for InlineAsm[src]
impl Debug for InlineAsm[src]
fn fmt(&self, __arg_0: &mut Formatter) -> Result<(), Error>
Formats the value using the given formatter.