Struct rustc_typeck::hir::Item
[−]
[src]
pub struct Item {
pub name: Symbol,
pub attrs: P<[Attribute]>,
pub id: NodeId,
pub node: Item_,
pub vis: Visibility,
pub span: Span,
}🔬 This is a nightly-only experimental API. (
rustc_private)An item
The name might be a dummy name in case of anonymous items
Fields
name: Symbol
🔬 This is a nightly-only experimental API. (
rustc_private)attrs: P<[Attribute]>
🔬 This is a nightly-only experimental API. (
rustc_private)id: NodeId
🔬 This is a nightly-only experimental API. (
rustc_private)node: Item_
🔬 This is a nightly-only experimental API. (
rustc_private)vis: Visibility
🔬 This is a nightly-only experimental API. (
rustc_private)span: Span
🔬 This is a nightly-only experimental API. (
rustc_private)Trait Implementations
impl Decodable for Item[src]
fn decode<__D>(__arg_0: &mut __D) -> Result<Item, __D::Error> where __D: Decoder
🔬 This is a nightly-only experimental API. (
rustc_private)impl MaybeFnLike for Item[src]
fn is_fn_like(&self) -> bool
🔬 This is a nightly-only experimental API. (
rustc_private)impl PartialEq<Item> for Item[src]
fn eq(&self, __arg_0: &Item) -> bool
This method tests for self and other values to be equal, and is used by ==. Read more
fn ne(&self, __arg_0: &Item) -> bool
This method tests for !=.
impl Hash for Item[src]
fn hash<__H>(&self, __arg_0: &mut __H) where __H: Hasher
Feeds this value into the state given, updating the hasher as necessary.
fn hash_slice<H>(data: &[Self], state: &mut H) where H: Hasher1.3.0
Feeds a slice of this type into the state provided.
impl Clone for Item[src]
fn clone(&self) -> Item
Returns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0
Performs copy-assignment from source. Read more
impl Eq for Item[src]
impl Debug for Item[src]
fn fmt(&self, __arg_0: &mut Formatter) -> Result<(), Error>
Formats the value using the given formatter.