Struct rustc_typeck::hir::Local
[−]
[src]
pub struct Local {
pub pat: P<Pat>,
pub ty: Option<P<Ty>>,
pub init: Option<P<Expr>>,
pub id: NodeId,
pub span: Span,
pub attrs: ThinVec<Attribute>,
}🔬 This is a nightly-only experimental API. (
rustc_private)Local represents a let statement, e.g., let <pat>:<ty> = <expr>;
Fields
pat: P<Pat>
🔬 This is a nightly-only experimental API. (
rustc_private)ty: Option<P<Ty>>
🔬 This is a nightly-only experimental API. (
rustc_private)init: Option<P<Expr>>
🔬 This is a nightly-only experimental API. (
rustc_private)Initializer expression to set the value, if any
id: NodeId
🔬 This is a nightly-only experimental API. (
rustc_private)span: Span
🔬 This is a nightly-only experimental API. (
rustc_private)attrs: ThinVec<Attribute>
🔬 This is a nightly-only experimental API. (
rustc_private)Trait Implementations
impl Decodable for Local[src]
fn decode<__D>(__arg_0: &mut __D) -> Result<Local, __D::Error> where __D: Decoder
🔬 This is a nightly-only experimental API. (
rustc_private)impl PartialEq<Local> for Local[src]
fn eq(&self, __arg_0: &Local) -> bool
This method tests for self and other values to be equal, and is used by ==. Read more
fn ne(&self, __arg_0: &Local) -> bool
This method tests for !=.
impl Hash for Local[src]
fn hash<__H>(&self, __arg_0: &mut __H) where __H: Hasher
Feeds this value into the state given, updating the hasher as necessary.
fn hash_slice<H>(data: &[Self], state: &mut H) where H: Hasher1.3.0
Feeds a slice of this type into the state provided.
impl Clone for Local[src]
fn clone(&self) -> Local
Returns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0
Performs copy-assignment from source. Read more
impl Eq for Local[src]
impl Debug for Local[src]
fn fmt(&self, __arg_0: &mut Formatter) -> Result<(), Error>
Formats the value using the given formatter.