Struct rustc_typeck::hir::MacroDef
[−]
[src]
pub struct MacroDef {
pub name: Symbol,
pub attrs: P<[Attribute]>,
pub id: NodeId,
pub span: Span,
pub body: TokenStream,
}🔬 This is a nightly-only experimental API. (
rustc_private)A macro definition, in this crate or imported from another.
Not parsed directly, but created on macro import or macro_rules! expansion.
Fields
name: Symbol
🔬 This is a nightly-only experimental API. (
rustc_private)attrs: P<[Attribute]>
🔬 This is a nightly-only experimental API. (
rustc_private)id: NodeId
🔬 This is a nightly-only experimental API. (
rustc_private)span: Span
🔬 This is a nightly-only experimental API. (
rustc_private)body: TokenStream
🔬 This is a nightly-only experimental API. (
rustc_private)Trait Implementations
impl Decodable for MacroDef[src]
fn decode<__D>(__arg_0: &mut __D) -> Result<MacroDef, __D::Error> where __D: Decoder
🔬 This is a nightly-only experimental API. (
rustc_private)impl PartialEq<MacroDef> for MacroDef[src]
fn eq(&self, __arg_0: &MacroDef) -> bool
This method tests for self and other values to be equal, and is used by ==. Read more
fn ne(&self, __arg_0: &MacroDef) -> bool
This method tests for !=.
impl Hash for MacroDef[src]
fn hash<__H>(&self, __arg_0: &mut __H) where __H: Hasher
Feeds this value into the state given, updating the hasher as necessary.
fn hash_slice<H>(data: &[Self], state: &mut H) where H: Hasher1.3.0
Feeds a slice of this type into the state provided.
impl Clone for MacroDef[src]
fn clone(&self) -> MacroDef
Returns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0
Performs copy-assignment from source. Read more
impl Eq for MacroDef[src]
impl Debug for MacroDef[src]
fn fmt(&self, __arg_0: &mut Formatter) -> Result<(), Error>
Formats the value using the given formatter.