Struct rustc_typeck::hir::MethodSig
[−]
[src]
pub struct MethodSig {
pub unsafety: Unsafety,
pub constness: Constness,
pub abi: Abi,
pub decl: P<FnDecl>,
pub generics: Generics,
}🔬 This is a nightly-only experimental API. (
rustc_private)Represents a method's signature in a trait declaration or implementation.
Fields
unsafety: Unsafety
🔬 This is a nightly-only experimental API. (
rustc_private)constness: Constness
🔬 This is a nightly-only experimental API. (
rustc_private)abi: Abi
🔬 This is a nightly-only experimental API. (
rustc_private)decl: P<FnDecl>
🔬 This is a nightly-only experimental API. (
rustc_private)generics: Generics
🔬 This is a nightly-only experimental API. (
rustc_private)Trait Implementations
impl Decodable for MethodSig[src]
fn decode<__D>(__arg_0: &mut __D) -> Result<MethodSig, __D::Error> where __D: Decoder
🔬 This is a nightly-only experimental API. (
rustc_private)impl PartialEq<MethodSig> for MethodSig[src]
fn eq(&self, __arg_0: &MethodSig) -> bool
This method tests for self and other values to be equal, and is used by ==. Read more
fn ne(&self, __arg_0: &MethodSig) -> bool
This method tests for !=.
impl Hash for MethodSig[src]
fn hash<__H>(&self, __arg_0: &mut __H) where __H: Hasher
Feeds this value into the state given, updating the hasher as necessary.
fn hash_slice<H>(data: &[Self], state: &mut H) where H: Hasher1.3.0
Feeds a slice of this type into the state provided.
impl Clone for MethodSig[src]
fn clone(&self) -> MethodSig
Returns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0
Performs copy-assignment from source. Read more
impl Eq for MethodSig[src]
impl Debug for MethodSig[src]
fn fmt(&self, __arg_0: &mut Formatter) -> Result<(), Error>
Formats the value using the given formatter.