Struct rustc_typeck::hir::Mod
[−]
[src]
pub struct Mod {
pub inner: Span,
pub item_ids: P<[ItemId]>,
}🔬 This is a nightly-only experimental API. (
rustc_private)Fields
inner: Span
🔬 This is a nightly-only experimental API. (
rustc_private)A span from the first token past { to the last token until }.
For mod foo;, the inner span ranges from the first token
to the last token in the external file.
item_ids: P<[ItemId]>
🔬 This is a nightly-only experimental API. (
rustc_private)Trait Implementations
impl Decodable for Mod[src]
fn decode<__D>(__arg_0: &mut __D) -> Result<Mod, __D::Error> where __D: Decoder
🔬 This is a nightly-only experimental API. (
rustc_private)impl PartialEq<Mod> for Mod[src]
fn eq(&self, __arg_0: &Mod) -> bool
This method tests for self and other values to be equal, and is used by ==. Read more
fn ne(&self, __arg_0: &Mod) -> bool
This method tests for !=.
impl Hash for Mod[src]
fn hash<__H>(&self, __arg_0: &mut __H) where __H: Hasher
Feeds this value into the state given, updating the hasher as necessary.
fn hash_slice<H>(data: &[Self], state: &mut H) where H: Hasher1.3.0
Feeds a slice of this type into the state provided.
impl Clone for Mod[src]
fn clone(&self) -> Mod
Returns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0
Performs copy-assignment from source. Read more
impl Eq for Mod[src]
impl Debug for Mod[src]
fn fmt(&self, __arg_0: &mut Formatter) -> Result<(), Error>
Formats the value using the given formatter.