Struct rustc_typeck::hir::MutTy
[−]
[src]
pub struct MutTy {
pub ty: P<Ty>,
pub mutbl: Mutability,
}🔬 This is a nightly-only experimental API. (
rustc_private)Fields
ty: P<Ty>
🔬 This is a nightly-only experimental API. (
rustc_private)mutbl: Mutability
🔬 This is a nightly-only experimental API. (
rustc_private)Trait Implementations
impl Decodable for MutTy[src]
fn decode<__D>(__arg_0: &mut __D) -> Result<MutTy, __D::Error> where __D: Decoder
🔬 This is a nightly-only experimental API. (
rustc_private)impl PartialEq<MutTy> for MutTy[src]
fn eq(&self, __arg_0: &MutTy) -> bool
This method tests for self and other values to be equal, and is used by ==. Read more
fn ne(&self, __arg_0: &MutTy) -> bool
This method tests for !=.
impl Hash for MutTy[src]
fn hash<__H>(&self, __arg_0: &mut __H) where __H: Hasher
Feeds this value into the state given, updating the hasher as necessary.
fn hash_slice<H>(data: &[Self], state: &mut H) where H: Hasher1.3.0
Feeds a slice of this type into the state provided.
impl Clone for MutTy[src]
fn clone(&self) -> MutTy
Returns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0
Performs copy-assignment from source. Read more
impl Eq for MutTy[src]
impl Debug for MutTy[src]
fn fmt(&self, __arg_0: &mut Formatter) -> Result<(), Error>
Formats the value using the given formatter.