Struct rustc_typeck::hir::PolyTraitRef
[−]
[src]
pub struct PolyTraitRef {
pub bound_lifetimes: P<[LifetimeDef]>,
pub trait_ref: TraitRef,
pub span: Span,
}🔬 This is a nightly-only experimental API. (
rustc_private)Fields
bound_lifetimes: P<[LifetimeDef]>
🔬 This is a nightly-only experimental API. (
rustc_private)The 'a in <'a> Foo<&'a T>
trait_ref: TraitRef
🔬 This is a nightly-only experimental API. (
rustc_private)The Foo<&'a T> in <'a> Foo<&'a T>
span: Span
🔬 This is a nightly-only experimental API. (
rustc_private)Trait Implementations
impl Decodable for PolyTraitRef[src]
fn decode<__D>(__arg_0: &mut __D) -> Result<PolyTraitRef, __D::Error> where __D: Decoder
🔬 This is a nightly-only experimental API. (
rustc_private)impl PartialEq<PolyTraitRef> for PolyTraitRef[src]
fn eq(&self, __arg_0: &PolyTraitRef) -> bool
This method tests for self and other values to be equal, and is used by ==. Read more
fn ne(&self, __arg_0: &PolyTraitRef) -> bool
This method tests for !=.
impl Hash for PolyTraitRef[src]
fn hash<__H>(&self, __arg_0: &mut __H) where __H: Hasher
Feeds this value into the state given, updating the hasher as necessary.
fn hash_slice<H>(data: &[Self], state: &mut H) where H: Hasher1.3.0
Feeds a slice of this type into the state provided.
impl Clone for PolyTraitRef[src]
fn clone(&self) -> PolyTraitRef
Returns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0
Performs copy-assignment from source. Read more
impl Eq for PolyTraitRef[src]
impl Debug for PolyTraitRef[src]
fn fmt(&self, __arg_0: &mut Formatter) -> Result<(), Error>
Formats the value using the given formatter.