Struct rustc_typeck::hir::TraitItem
[−]
[src]
pub struct TraitItem {
pub id: NodeId,
pub name: Symbol,
pub attrs: P<[Attribute]>,
pub node: TraitItemKind,
pub span: Span,
}🔬 This is a nightly-only experimental API. (
rustc_private)Represents an item declaration within a trait declaration, possibly including a default implementation. A trait item is either required (meaning it doesn't have an implementation, just a signature) or provided (meaning it has a default implementation).
Fields
id: NodeId
🔬 This is a nightly-only experimental API. (
rustc_private)name: Symbol
🔬 This is a nightly-only experimental API. (
rustc_private)attrs: P<[Attribute]>
🔬 This is a nightly-only experimental API. (
rustc_private)node: TraitItemKind
🔬 This is a nightly-only experimental API. (
rustc_private)span: Span
🔬 This is a nightly-only experimental API. (
rustc_private)Trait Implementations
impl Decodable for TraitItem[src]
fn decode<__D>(__arg_0: &mut __D) -> Result<TraitItem, __D::Error> where __D: Decoder
🔬 This is a nightly-only experimental API. (
rustc_private)impl MaybeFnLike for TraitItem[src]
fn is_fn_like(&self) -> bool
🔬 This is a nightly-only experimental API. (
rustc_private)impl PartialEq<TraitItem> for TraitItem[src]
fn eq(&self, __arg_0: &TraitItem) -> bool
This method tests for self and other values to be equal, and is used by ==. Read more
fn ne(&self, __arg_0: &TraitItem) -> bool
This method tests for !=.
impl Hash for TraitItem[src]
fn hash<__H>(&self, __arg_0: &mut __H) where __H: Hasher
Feeds this value into the state given, updating the hasher as necessary.
fn hash_slice<H>(data: &[Self], state: &mut H) where H: Hasher1.3.0
Feeds a slice of this type into the state provided.
impl Clone for TraitItem[src]
fn clone(&self) -> TraitItem
Returns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0
Performs copy-assignment from source. Read more
impl Eq for TraitItem[src]
impl Debug for TraitItem[src]
fn fmt(&self, __arg_0: &mut Formatter) -> Result<(), Error>
Formats the value using the given formatter.