Struct rustc_typeck::hir::TraitItemId
[−]
[src]
pub struct TraitItemId {
pub node_id: NodeId,
}rustc_private)Fields
node_id: NodeId
rustc_private)Trait Implementations
impl Decodable for TraitItemId[src]
fn decode<__D>(__arg_0: &mut __D) -> Result<TraitItemId, __D::Error> where __D: Decoder
rustc_private)impl PartialOrd<TraitItemId> for TraitItemId[src]
fn partial_cmp(&self, __arg_0: &TraitItemId) -> Option<Ordering>
This method returns an ordering between self and other values if one exists. Read more
fn lt(&self, __arg_0: &TraitItemId) -> bool
This method tests less than (for self and other) and is used by the < operator. Read more
fn le(&self, __arg_0: &TraitItemId) -> bool
This method tests less than or equal to (for self and other) and is used by the <= operator. Read more
fn gt(&self, __arg_0: &TraitItemId) -> bool
This method tests greater than (for self and other) and is used by the > operator. Read more
fn ge(&self, __arg_0: &TraitItemId) -> bool
This method tests greater than or equal to (for self and other) and is used by the >= operator. Read more
impl PartialEq<TraitItemId> for TraitItemId[src]
fn eq(&self, __arg_0: &TraitItemId) -> bool
This method tests for self and other values to be equal, and is used by ==. Read more
fn ne(&self, __arg_0: &TraitItemId) -> bool
This method tests for !=.
impl Hash for TraitItemId[src]
fn hash<__H>(&self, __arg_0: &mut __H) where __H: Hasher
Feeds this value into the state given, updating the hasher as necessary.
fn hash_slice<H>(data: &[Self], state: &mut H) where H: Hasher1.3.0
Feeds a slice of this type into the state provided.
impl Clone for TraitItemId[src]
fn clone(&self) -> TraitItemId
Returns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0
Performs copy-assignment from source. Read more
impl Eq for TraitItemId[src]
impl Debug for TraitItemId[src]
fn fmt(&self, __arg_0: &mut Formatter) -> Result<(), Error>
Formats the value using the given formatter.
impl Encodable for TraitItemId[src]
fn encode<__S>(&self, __arg_0: &mut __S) -> Result<(), __S::Error> where __S: Encoder
rustc_private)impl Copy for TraitItemId[src]
impl Ord for TraitItemId[src]
fn cmp(&self, __arg_0: &TraitItemId) -> Ordering
This method returns an Ordering between self and other. Read more