Struct rustc_typeck::hir::TraitRef
[−]
[src]
pub struct TraitRef {
pub path: Path,
pub ref_id: NodeId,
}🔬 This is a nightly-only experimental API. (
rustc_private)TraitRef's appear in impls.
resolve maps each TraitRef's ref_id to its defining trait; that's all that the ref_id is for. Note that ref_id's value is not the NodeId of the trait being referred to but just a unique NodeId that serves as a key within the DefMap.
Fields
path: Path
🔬 This is a nightly-only experimental API. (
rustc_private)ref_id: NodeId
🔬 This is a nightly-only experimental API. (
rustc_private)Trait Implementations
impl Decodable for TraitRef[src]
fn decode<__D>(__arg_0: &mut __D) -> Result<TraitRef, __D::Error> where __D: Decoder
🔬 This is a nightly-only experimental API. (
rustc_private)impl PartialEq<TraitRef> for TraitRef[src]
fn eq(&self, __arg_0: &TraitRef) -> bool
This method tests for self and other values to be equal, and is used by ==. Read more
fn ne(&self, __arg_0: &TraitRef) -> bool
This method tests for !=.
impl Hash for TraitRef[src]
fn hash<__H>(&self, __arg_0: &mut __H) where __H: Hasher
Feeds this value into the state given, updating the hasher as necessary.
fn hash_slice<H>(data: &[Self], state: &mut H) where H: Hasher1.3.0
Feeds a slice of this type into the state provided.
impl Clone for TraitRef[src]
fn clone(&self) -> TraitRef
Returns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0
Performs copy-assignment from source. Read more
impl Eq for TraitRef[src]
impl Debug for TraitRef[src]
fn fmt(&self, __arg_0: &mut Formatter) -> Result<(), Error>
Formats the value using the given formatter.