Struct rustc_typeck::hir::TypeBinding
[−]
[src]
pub struct TypeBinding {
pub id: NodeId,
pub name: Symbol,
pub ty: P<Ty>,
pub span: Span,
}🔬 This is a nightly-only experimental API. (
rustc_private)Fields
id: NodeId
🔬 This is a nightly-only experimental API. (
rustc_private)name: Symbol
🔬 This is a nightly-only experimental API. (
rustc_private)ty: P<Ty>
🔬 This is a nightly-only experimental API. (
rustc_private)span: Span
🔬 This is a nightly-only experimental API. (
rustc_private)Trait Implementations
impl Decodable for TypeBinding[src]
fn decode<__D>(__arg_0: &mut __D) -> Result<TypeBinding, __D::Error> where __D: Decoder
🔬 This is a nightly-only experimental API. (
rustc_private)impl PartialEq<TypeBinding> for TypeBinding[src]
fn eq(&self, __arg_0: &TypeBinding) -> bool
This method tests for self and other values to be equal, and is used by ==. Read more
fn ne(&self, __arg_0: &TypeBinding) -> bool
This method tests for !=.
impl Hash for TypeBinding[src]
fn hash<__H>(&self, __arg_0: &mut __H) where __H: Hasher
Feeds this value into the state given, updating the hasher as necessary.
fn hash_slice<H>(data: &[Self], state: &mut H) where H: Hasher1.3.0
Feeds a slice of this type into the state provided.
impl Clone for TypeBinding[src]
fn clone(&self) -> TypeBinding
Returns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0
Performs copy-assignment from source. Read more
impl Eq for TypeBinding[src]
impl Debug for TypeBinding[src]
fn fmt(&self, __arg_0: &mut Formatter) -> Result<(), Error>
Formats the value using the given formatter.