Struct rustc_typeck::hir::WhereClause
[−]
[src]
pub struct WhereClause {
pub id: NodeId,
pub predicates: P<[WherePredicate]>,
}🔬 This is a nightly-only experimental API. (
rustc_private)A where clause in a definition
Fields
id: NodeId
🔬 This is a nightly-only experimental API. (
rustc_private)predicates: P<[WherePredicate]>
🔬 This is a nightly-only experimental API. (
rustc_private)Trait Implementations
impl Decodable for WhereClause[src]
fn decode<__D>(__arg_0: &mut __D) -> Result<WhereClause, __D::Error> where __D: Decoder
🔬 This is a nightly-only experimental API. (
rustc_private)impl PartialEq<WhereClause> for WhereClause[src]
fn eq(&self, __arg_0: &WhereClause) -> bool
This method tests for self and other values to be equal, and is used by ==. Read more
fn ne(&self, __arg_0: &WhereClause) -> bool
This method tests for !=.
impl Hash for WhereClause[src]
fn hash<__H>(&self, __arg_0: &mut __H) where __H: Hasher
Feeds this value into the state given, updating the hasher as necessary.
fn hash_slice<H>(data: &[Self], state: &mut H) where H: Hasher1.3.0
Feeds a slice of this type into the state provided.
impl Clone for WhereClause[src]
fn clone(&self) -> WhereClause
Returns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0
Performs copy-assignment from source. Read more
impl Eq for WhereClause[src]
impl Debug for WhereClause[src]
fn fmt(&self, __arg_0: &mut Formatter) -> Result<(), Error>
Formats the value using the given formatter.