Enum rustc_typeck::middle::cstore::NativeLibraryKind
[−]
[src]
pub enum NativeLibraryKind {
NativeStatic,
NativeStaticNobundle,
NativeFramework,
NativeUnknown,
}rustc_private)Variants
NativeStaticrustc_private)NativeStaticNobundlerustc_private)NativeFrameworkrustc_private)NativeUnknownrustc_private)Trait Implementations
impl Decodable for NativeLibraryKind[src]
fn decode<__D>(__arg_0: &mut __D) -> Result<NativeLibraryKind, __D::Error> where __D: Decoder
rustc_private)impl PartialOrd<NativeLibraryKind> for NativeLibraryKind[src]
fn partial_cmp(&self, __arg_0: &NativeLibraryKind) -> Option<Ordering>
This method returns an ordering between self and other values if one exists. Read more
fn lt(&self, other: &Rhs) -> bool1.0.0
This method tests less than (for self and other) and is used by the < operator. Read more
fn le(&self, other: &Rhs) -> bool1.0.0
This method tests less than or equal to (for self and other) and is used by the <= operator. Read more
fn gt(&self, other: &Rhs) -> bool1.0.0
This method tests greater than (for self and other) and is used by the > operator. Read more
fn ge(&self, other: &Rhs) -> bool1.0.0
This method tests greater than or equal to (for self and other) and is used by the >= operator. Read more
impl PartialEq<NativeLibraryKind> for NativeLibraryKind[src]
fn eq(&self, __arg_0: &NativeLibraryKind) -> bool
This method tests for self and other values to be equal, and is used by ==. Read more
fn ne(&self, other: &Rhs) -> bool1.0.0
This method tests for !=.
impl Hash for NativeLibraryKind[src]
fn hash<__H>(&self, __arg_0: &mut __H) where __H: Hasher
Feeds this value into the state given, updating the hasher as necessary.
fn hash_slice<H>(data: &[Self], state: &mut H) where H: Hasher1.3.0
Feeds a slice of this type into the state provided.
impl Clone for NativeLibraryKind[src]
fn clone(&self) -> NativeLibraryKind
Returns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0
Performs copy-assignment from source. Read more
impl Eq for NativeLibraryKind[src]
impl Encodable for NativeLibraryKind[src]
fn encode<__S>(&self, __arg_0: &mut __S) -> Result<(), __S::Error> where __S: Encoder
rustc_private)impl Copy for NativeLibraryKind[src]
impl Ord for NativeLibraryKind[src]
fn cmp(&self, __arg_0: &NativeLibraryKind) -> Ordering
This method returns an Ordering between self and other. Read more