Enum rustc_typeck::session::config::OptLevel
[−]
[src]
pub enum OptLevel {
No,
Less,
Default,
Aggressive,
Size,
SizeMin,
}🔬 This is a nightly-only experimental API. (
rustc_private)Variants
No🔬 This is a nightly-only experimental API. (
rustc_private)Less🔬 This is a nightly-only experimental API. (
rustc_private)Default🔬 This is a nightly-only experimental API. (
rustc_private)Aggressive🔬 This is a nightly-only experimental API. (
rustc_private)Size🔬 This is a nightly-only experimental API. (
rustc_private)SizeMin🔬 This is a nightly-only experimental API. (
rustc_private)Trait Implementations
impl PartialEq<OptLevel> for OptLevel[src]
fn eq(&self, __arg_0: &OptLevel) -> bool
This method tests for self and other values to be equal, and is used by ==. Read more
fn ne(&self, other: &Rhs) -> bool1.0.0
This method tests for !=.
impl Hash for OptLevel[src]
fn hash<__H>(&self, __arg_0: &mut __H) where __H: Hasher
Feeds this value into the state given, updating the hasher as necessary.
fn hash_slice<H>(data: &[Self], state: &mut H) where H: Hasher1.3.0
Feeds a slice of this type into the state provided.
impl Clone for OptLevel[src]
fn clone(&self) -> OptLevel
Returns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0
Performs copy-assignment from source. Read more