Enum rustc_typeck::session::search_paths::PathKind
[−]
[src]
pub enum PathKind {
Native,
Crate,
Dependency,
Framework,
ExternFlag,
All,
}rustc_private)Variants
Nativerustc_private)Craterustc_private)Dependencyrustc_private)Frameworkrustc_private)ExternFlagrustc_private)Allrustc_private)Trait Implementations
impl PartialOrd<PathKind> for PathKind[src]
fn partial_cmp(&self, __arg_0: &PathKind) -> Option<Ordering>
This method returns an ordering between self and other values if one exists. Read more
fn lt(&self, other: &Rhs) -> bool1.0.0
This method tests less than (for self and other) and is used by the < operator. Read more
fn le(&self, other: &Rhs) -> bool1.0.0
This method tests less than or equal to (for self and other) and is used by the <= operator. Read more
fn gt(&self, other: &Rhs) -> bool1.0.0
This method tests greater than (for self and other) and is used by the > operator. Read more
fn ge(&self, other: &Rhs) -> bool1.0.0
This method tests greater than or equal to (for self and other) and is used by the >= operator. Read more
impl PartialEq<PathKind> for PathKind[src]
fn eq(&self, __arg_0: &PathKind) -> bool
This method tests for self and other values to be equal, and is used by ==. Read more
fn ne(&self, other: &Rhs) -> bool1.0.0
This method tests for !=.
impl Hash for PathKind[src]
fn hash<__H>(&self, __arg_0: &mut __H) where __H: Hasher
Feeds this value into the state given, updating the hasher as necessary.
fn hash_slice<H>(data: &[Self], state: &mut H) where H: Hasher1.3.0
Feeds a slice of this type into the state provided.
impl Clone for PathKind[src]
fn clone(&self) -> PathKind
Returns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0
Performs copy-assignment from source. Read more
impl Eq for PathKind[src]
impl Debug for PathKind[src]
fn fmt(&self, __arg_0: &mut Formatter) -> Result<(), Error>
Formats the value using the given formatter.