Struct rustc_typeck::session::FieldInfo
[−]
[src]
pub struct FieldInfo {
pub name: String,
pub offset: u64,
pub size: u64,
pub align: u64,
}🔬 This is a nightly-only experimental API. (
rustc_private)Fields
name: String
🔬 This is a nightly-only experimental API. (
rustc_private)offset: u64
🔬 This is a nightly-only experimental API. (
rustc_private)size: u64
🔬 This is a nightly-only experimental API. (
rustc_private)align: u64
🔬 This is a nightly-only experimental API. (
rustc_private)Trait Implementations
impl PartialEq<FieldInfo> for FieldInfo[src]
fn eq(&self, __arg_0: &FieldInfo) -> bool
This method tests for self and other values to be equal, and is used by ==. Read more
fn ne(&self, __arg_0: &FieldInfo) -> bool
This method tests for !=.
impl Hash for FieldInfo[src]
fn hash<__H>(&self, __arg_0: &mut __H) where __H: Hasher
Feeds this value into the state given, updating the hasher as necessary.
fn hash_slice<H>(data: &[Self], state: &mut H) where H: Hasher1.3.0
Feeds a slice of this type into the state provided.
impl Clone for FieldInfo[src]
fn clone(&self) -> FieldInfo
Returns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0
Performs copy-assignment from source. Read more