Struct rustc_typeck::session::TypeSizeInfo
[−]
[src]
pub struct TypeSizeInfo {
pub kind: DataTypeKind,
pub type_description: String,
pub align: u64,
pub overall_size: u64,
pub opt_discr_size: Option<u64>,
pub variants: Vec<VariantInfo>,
}🔬 This is a nightly-only experimental API. (
rustc_private)Fields
kind: DataTypeKind
🔬 This is a nightly-only experimental API. (
rustc_private)type_description: String
🔬 This is a nightly-only experimental API. (
rustc_private)align: u64
🔬 This is a nightly-only experimental API. (
rustc_private)overall_size: u64
🔬 This is a nightly-only experimental API. (
rustc_private)opt_discr_size: Option<u64>
🔬 This is a nightly-only experimental API. (
rustc_private)variants: Vec<VariantInfo>
🔬 This is a nightly-only experimental API. (
rustc_private)Trait Implementations
impl PartialEq<TypeSizeInfo> for TypeSizeInfo[src]
fn eq(&self, __arg_0: &TypeSizeInfo) -> bool
This method tests for self and other values to be equal, and is used by ==. Read more
fn ne(&self, __arg_0: &TypeSizeInfo) -> bool
This method tests for !=.
impl Hash for TypeSizeInfo[src]
fn hash<__H>(&self, __arg_0: &mut __H) where __H: Hasher
Feeds this value into the state given, updating the hasher as necessary.
fn hash_slice<H>(data: &[Self], state: &mut H) where H: Hasher1.3.0
Feeds a slice of this type into the state provided.