Struct rustdoc::clean::Attributes
[−]
[src]
pub struct Attributes {
pub doc_strings: Vec<String>,
pub other_attrs: Vec<Attribute>,
pub span: Option<Span>,
}🔬 This is a nightly-only experimental API. (
rustdoc)Fields
doc_strings: Vec<String>
🔬 This is a nightly-only experimental API. (
rustdoc)other_attrs: Vec<Attribute>
🔬 This is a nightly-only experimental API. (
rustdoc)span: Option<Span>
🔬 This is a nightly-only experimental API. (
rustdoc)Methods
impl Attributes[src]
fn from_ast(attrs: &[Attribute]) -> Attributes
🔬 This is a nightly-only experimental API. (
rustdoc)fn doc_value<'a>(&'a self) -> Option<&'a str>
🔬 This is a nightly-only experimental API. (
rustdoc)Finds the doc attribute as a NameValue and returns the corresponding
value found.
impl Attributes[src]
fn collapse_doc_comments(&mut self)
🔬 This is a nightly-only experimental API. (
rustdoc)impl Attributes[src]
fn unindent_doc_comments(&mut self)
🔬 This is a nightly-only experimental API. (
rustdoc)Trait Implementations
impl Clone for Attributes[src]
fn clone(&self) -> Attributes
Returns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0
Performs copy-assignment from source. Read more
impl Encodable for Attributes[src]
fn encode<__S: Encoder>(&self, __arg_0: &mut __S) -> Result<(), __S::Error>
🔬 This is a nightly-only experimental API. (rustc_private)
deprecated in favor of rustc-serialize on crates.io
impl Decodable for Attributes[src]
fn decode<__D: Decoder>(__arg_0: &mut __D) -> Result<Attributes, __D::Error>
🔬 This is a nightly-only experimental API. (rustc_private)
deprecated in favor of rustc-serialize on crates.io
impl PartialEq for Attributes[src]
fn eq(&self, __arg_0: &Attributes) -> bool
This method tests for self and other values to be equal, and is used by ==. Read more
fn ne(&self, __arg_0: &Attributes) -> bool
This method tests for !=.
impl Debug for Attributes[src]
impl Default for Attributes[src]
fn default() -> Attributes
Returns the "default value" for a type. Read more
impl AttributesExt for Attributes[src]
fn lists<'a>(&'a self, name: &'a str) -> ListAttributesIter<'a>
🔬 This is a nightly-only experimental API. (
rustdoc)Finds an attribute as List and returns the list of attributes nested inside.