Struct rustdoc::clean::Static
[−]
[src]
pub struct Static {
pub type_: Type,
pub mutability: Mutability,
pub expr: String,
}🔬 This is a nightly-only experimental API. (
rustdoc)Fields
type_: Type
🔬 This is a nightly-only experimental API. (
rustdoc)mutability: Mutability
🔬 This is a nightly-only experimental API. (
rustdoc)expr: String
🔬 This is a nightly-only experimental API. (
rustdoc)It's useful to have the value of a static documented, but I have no desire to represent expressions (that'd basically be all of the AST, which is huge!). So, have a string.