Struct rustdoc::clean::VariantStruct
[−]
[src]
pub struct VariantStruct {
pub struct_type: StructType,
pub fields: Vec<Item>,
pub fields_stripped: bool,
}🔬 This is a nightly-only experimental API. (
rustdoc)This is a more limited form of the standard Struct, different in that it lacks the things most items have (name, id, parameterization). Found only as a variant in an enum.
Fields
struct_type: StructType
🔬 This is a nightly-only experimental API. (
rustdoc)fields: Vec<Item>
🔬 This is a nightly-only experimental API. (
rustdoc)fields_stripped: bool
🔬 This is a nightly-only experimental API. (
rustdoc)Trait Implementations
impl Clone for VariantStruct[src]
fn clone(&self) -> VariantStruct
Returns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0
Performs copy-assignment from source. Read more
impl Encodable for VariantStruct[src]
fn encode<__S: Encoder>(&self, __arg_0: &mut __S) -> Result<(), __S::Error>
🔬 This is a nightly-only experimental API. (rustc_private)
deprecated in favor of rustc-serialize on crates.io
impl Decodable for VariantStruct[src]
fn decode<__D: Decoder>(__arg_0: &mut __D) -> Result<VariantStruct, __D::Error>
🔬 This is a nightly-only experimental API. (rustc_private)
deprecated in favor of rustc-serialize on crates.io