Struct rustdoc::externalfiles::ExternalHtml
[−]
[src]
pub struct ExternalHtml {
pub in_header: String,
pub before_content: String,
pub after_content: String,
}🔬 This is a nightly-only experimental API. (
rustdoc)Fields
in_header: String
🔬 This is a nightly-only experimental API. (
rustdoc)Content that will be included inline in the
section of a rendered Markdown file or generated documentationbefore_content: String
🔬 This is a nightly-only experimental API. (
rustdoc)Content that will be included inline between
and the content of a rendered Markdown file or generated documentationafter_content: String
🔬 This is a nightly-only experimental API. (
rustdoc)Content that will be included inline between the content and of a rendered Markdown file or generated documentation
Methods
impl ExternalHtml[src]
fn load(in_header: &[String],
before_content: &[String],
after_content: &[String])
-> Option<ExternalHtml>
before_content: &[String],
after_content: &[String])
-> Option<ExternalHtml>
🔬 This is a nightly-only experimental API. (
rustdoc)Trait Implementations
impl Clone for ExternalHtml[src]
fn clone(&self) -> ExternalHtml
Returns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0
Performs copy-assignment from source. Read more