Enum serialize::hex::FromHexError
[−]
[src]
pub enum FromHexError {
InvalidHexCharacter(char, usize),
InvalidHexLength,
}🔬 This is a nightly-only experimental API. (rustc_private)
deprecated in favor of rustc-serialize on crates.io
Errors that can occur when decoding a hex encoded string
Variants
InvalidHexCharacter(char, usize)🔬 This is a nightly-only experimental API. (rustc_private)
deprecated in favor of rustc-serialize on crates.io
The input contained a character not part of the hex format
InvalidHexLength🔬 This is a nightly-only experimental API. (rustc_private)
deprecated in favor of rustc-serialize on crates.io
The input had an invalid length