Trait serialize::hex::ToHex
[−]
[src]
pub trait ToHex {
fn to_hex(&self) -> String;
}🔬 This is a nightly-only experimental API. (rustc_private)
deprecated in favor of rustc-serialize on crates.io
A trait for converting a value to hexadecimal encoding
Required Methods
fn to_hex(&self) -> String
🔬 This is a nightly-only experimental API. (rustc_private)
deprecated in favor of rustc-serialize on crates.io
Converts the value of self to a hex value, returning the owned
string.