Enum syntax::ast::AsmDialect
[−]
[src]
pub enum AsmDialect {
Att,
Intel,
}🔬 This is a nightly-only experimental API. (
rustc_private)Inline assembly dialect.
E.g. "intel" as in asm!("mov eax, 2" : "={eax}"(result) : : : "intel")`
Variants
Att🔬 This is a nightly-only experimental API. (
rustc_private)Intel🔬 This is a nightly-only experimental API. (
rustc_private)Trait Implementations
impl Clone for AsmDialect[src]
fn clone(&self) -> AsmDialect
Returns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0
Performs copy-assignment from source. Read more
impl PartialEq for AsmDialect[src]
fn eq(&self, __arg_0: &AsmDialect) -> bool
This method tests for self and other values to be equal, and is used by ==. Read more
fn ne(&self, other: &Rhs) -> bool1.0.0
This method tests for !=.
impl Eq for AsmDialect[src]
impl Encodable for AsmDialect[src]
fn encode<__S: Encoder>(&self, __arg_0: &mut __S) -> Result<(), __S::Error>
🔬 This is a nightly-only experimental API. (rustc_private)
deprecated in favor of rustc-serialize on crates.io
impl Decodable for AsmDialect[src]
fn decode<__D: Decoder>(__arg_0: &mut __D) -> Result<AsmDialect, __D::Error>
🔬 This is a nightly-only experimental API. (rustc_private)
deprecated in favor of rustc-serialize on crates.io
impl Hash for AsmDialect[src]
fn hash<__H: Hasher>(&self, __arg_0: &mut __H)
Feeds this value into the state given, updating the hasher as necessary.
fn hash_slice<H>(data: &[Self], state: &mut H) where H: Hasher1.3.0
Feeds a slice of this type into the state provided.