Enum syntax::ast::AttrStyle
[−]
[src]
pub enum AttrStyle {
Outer,
Inner,
}🔬 This is a nightly-only experimental API. (
rustc_private)Distinguishes between Attributes that decorate items and Attributes that are contained as statements within items. These two cases need to be distinguished for pretty-printing.
Variants
Outer🔬 This is a nightly-only experimental API. (
rustc_private)Inner🔬 This is a nightly-only experimental API. (
rustc_private)Trait Implementations
impl Clone for AttrStyle[src]
fn clone(&self) -> AttrStyle
Returns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0
Performs copy-assignment from source. Read more
impl PartialEq for AttrStyle[src]
fn eq(&self, __arg_0: &AttrStyle) -> bool
This method tests for self and other values to be equal, and is used by ==. Read more
fn ne(&self, other: &Rhs) -> bool1.0.0
This method tests for !=.
impl Eq for AttrStyle[src]
impl Encodable for AttrStyle[src]
fn encode<__S: Encoder>(&self, __arg_0: &mut __S) -> Result<(), __S::Error>
🔬 This is a nightly-only experimental API. (rustc_private)
deprecated in favor of rustc-serialize on crates.io
impl Decodable for AttrStyle[src]
fn decode<__D: Decoder>(__arg_0: &mut __D) -> Result<AttrStyle, __D::Error>
🔬 This is a nightly-only experimental API. (rustc_private)
deprecated in favor of rustc-serialize on crates.io
impl Hash for AttrStyle[src]
fn hash<__H: Hasher>(&self, __arg_0: &mut __H)
Feeds this value into the state given, updating the hasher as necessary.
fn hash_slice<H>(data: &[Self], state: &mut H) where H: Hasher1.3.0
Feeds a slice of this type into the state provided.