Enum syntax::ast::Defaultness
[−]
[src]
pub enum Defaultness {
Default,
Final,
}🔬 This is a nightly-only experimental API. (
rustc_private)Variants
Default🔬 This is a nightly-only experimental API. (
rustc_private)Final🔬 This is a nightly-only experimental API. (
rustc_private)Trait Implementations
impl Copy for Defaultness[src]
impl Clone for Defaultness[src]
fn clone(&self) -> Defaultness
Returns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0
Performs copy-assignment from source. Read more
impl PartialEq for Defaultness[src]
fn eq(&self, __arg_0: &Defaultness) -> bool
This method tests for self and other values to be equal, and is used by ==. Read more
fn ne(&self, other: &Rhs) -> bool1.0.0
This method tests for !=.
impl Eq for Defaultness[src]
impl Encodable for Defaultness[src]
fn encode<__S: Encoder>(&self, __arg_0: &mut __S) -> Result<(), __S::Error>
🔬 This is a nightly-only experimental API. (rustc_private)
deprecated in favor of rustc-serialize on crates.io
impl Decodable for Defaultness[src]
fn decode<__D: Decoder>(__arg_0: &mut __D) -> Result<Defaultness, __D::Error>
🔬 This is a nightly-only experimental API. (rustc_private)
deprecated in favor of rustc-serialize on crates.io
impl Hash for Defaultness[src]
fn hash<__H: Hasher>(&self, __arg_0: &mut __H)
Feeds this value into the state given, updating the hasher as necessary.
fn hash_slice<H>(data: &[Self], state: &mut H) where H: Hasher1.3.0
Feeds a slice of this type into the state provided.