Enum syntax::ast::ImplItemKind
[−]
[src]
pub enum ImplItemKind {
Const(P<Ty>, P<Expr>),
Method(MethodSig, P<Block>),
Type(P<Ty>),
Macro(Mac),
}🔬 This is a nightly-only experimental API. (
rustc_private)Variants
Const(P<Ty>, P<Expr>)🔬 This is a nightly-only experimental API. (
rustc_private)Method(MethodSig, P<Block>)🔬 This is a nightly-only experimental API. (
rustc_private)Type(P<Ty>)🔬 This is a nightly-only experimental API. (
rustc_private)Macro(Mac)🔬 This is a nightly-only experimental API. (
rustc_private)Trait Implementations
impl Clone for ImplItemKind[src]
fn clone(&self) -> ImplItemKind
Returns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0
Performs copy-assignment from source. Read more
impl PartialEq for ImplItemKind[src]
fn eq(&self, __arg_0: &ImplItemKind) -> bool
This method tests for self and other values to be equal, and is used by ==. Read more
fn ne(&self, __arg_0: &ImplItemKind) -> bool
This method tests for !=.
impl Eq for ImplItemKind[src]
impl Encodable for ImplItemKind[src]
fn encode<__S: Encoder>(&self, __arg_0: &mut __S) -> Result<(), __S::Error>
🔬 This is a nightly-only experimental API. (rustc_private)
deprecated in favor of rustc-serialize on crates.io
impl Decodable for ImplItemKind[src]
fn decode<__D: Decoder>(__arg_0: &mut __D) -> Result<ImplItemKind, __D::Error>
🔬 This is a nightly-only experimental API. (rustc_private)
deprecated in favor of rustc-serialize on crates.io
impl Hash for ImplItemKind[src]
fn hash<__H: Hasher>(&self, __arg_0: &mut __H)
Feeds this value into the state given, updating the hasher as necessary.
fn hash_slice<H>(data: &[Self], state: &mut H) where H: Hasher1.3.0
Feeds a slice of this type into the state provided.