Enum syntax::ast::IntTy
[−]
[src]
pub enum IntTy {
Is,
I8,
I16,
I32,
I64,
I128,
}🔬 This is a nightly-only experimental API. (
rustc_private)Variants
Is🔬 This is a nightly-only experimental API. (
rustc_private)I8🔬 This is a nightly-only experimental API. (
rustc_private)I16🔬 This is a nightly-only experimental API. (
rustc_private)I32🔬 This is a nightly-only experimental API. (
rustc_private)I64🔬 This is a nightly-only experimental API. (
rustc_private)I128🔬 This is a nightly-only experimental API. (
rustc_private)Methods
impl IntTy[src]
fn ty_to_string(&self) -> &'static str
🔬 This is a nightly-only experimental API. (
rustc_private)fn val_to_string(&self, val: i128) -> String
🔬 This is a nightly-only experimental API. (
rustc_private)fn bit_width(&self) -> Option<usize>
🔬 This is a nightly-only experimental API. (
rustc_private)Trait Implementations
impl Clone for IntTy[src]
fn clone(&self) -> IntTy
Returns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0
Performs copy-assignment from source. Read more
impl PartialEq for IntTy[src]
fn eq(&self, __arg_0: &IntTy) -> bool
This method tests for self and other values to be equal, and is used by ==. Read more
fn ne(&self, other: &Rhs) -> bool1.0.0
This method tests for !=.
impl Eq for IntTy[src]
impl Encodable for IntTy[src]
fn encode<__S: Encoder>(&self, __arg_0: &mut __S) -> Result<(), __S::Error>
🔬 This is a nightly-only experimental API. (rustc_private)
deprecated in favor of rustc-serialize on crates.io
impl Decodable for IntTy[src]
fn decode<__D: Decoder>(__arg_0: &mut __D) -> Result<IntTy, __D::Error>
🔬 This is a nightly-only experimental API. (rustc_private)
deprecated in favor of rustc-serialize on crates.io
impl Hash for IntTy[src]
fn hash<__H: Hasher>(&self, __arg_0: &mut __H)
Feeds this value into the state given, updating the hasher as necessary.
fn hash_slice<H>(data: &[Self], state: &mut H) where H: Hasher1.3.0
Feeds a slice of this type into the state provided.