Enum syntax::ast::LitKind
[−]
[src]
pub enum LitKind {
Str(Symbol, StrStyle),
ByteStr(Rc<Vec<u8>>),
Byte(u8),
Char(char),
Int(u128, LitIntType),
Float(Symbol, FloatTy),
FloatUnsuffixed(Symbol),
Bool(bool),
}rustc_private)Literal kind.
E.g. "foo", 42, 12.34 or bool
Variants
Str(Symbol, StrStyle)rustc_private)A string literal ("foo")
ByteStr(Rc<Vec<u8>>)rustc_private)A byte string (b"foo")
Byte(u8)rustc_private)A byte char (b'f')
Char(char)rustc_private)A character literal ('a')
Int(u128, LitIntType)rustc_private)An integer literal (1)
Float(Symbol, FloatTy)rustc_private)A float literal (1f64 or 1E10f64)
FloatUnsuffixed(Symbol)rustc_private)A float literal without a suffix (1.0 or 1.0E10)
Bool(bool)rustc_private)A boolean literal
Methods
impl LitKind[src]
fn is_str(&self) -> bool
rustc_private)Returns true if this literal is a string and false otherwise.
fn is_unsuffixed(&self) -> bool
rustc_private)Returns true if this literal has no suffix. Note: this will return true for literals with prefixes such as raw strings and byte strings.
fn is_suffixed(&self) -> bool
rustc_private)Returns true if this literal has a suffix.