Enum syntax::ast::MacStmtStyle
[−]
[src]
pub enum MacStmtStyle {
Semicolon,
Braces,
NoBraces,
}🔬 This is a nightly-only experimental API. (
rustc_private)Variants
Semicolon🔬 This is a nightly-only experimental API. (
rustc_private)The macro statement had a trailing semicolon, e.g. foo! { ... };
foo!(...);, foo![...];
Braces🔬 This is a nightly-only experimental API. (
rustc_private)The macro statement had braces; e.g. foo! { ... }
NoBraces🔬 This is a nightly-only experimental API. (
rustc_private)The macro statement had parentheses or brackets and no semicolon; e.g.
foo!(...). All of these will end up being converted into macro
expressions.