Enum syntax::ast::PatKind
[−]
[src]
pub enum PatKind {
Wild,
Ident(BindingMode, SpannedIdent, Option<P<Pat>>),
Struct(Path, Vec<Spanned<FieldPat>>, bool),
TupleStruct(Path, Vec<P<Pat>>, Option<usize>),
Path(Option<QSelf>, Path),
Tuple(Vec<P<Pat>>, Option<usize>),
Box(P<Pat>),
Ref(P<Pat>, Mutability),
Lit(P<Expr>),
Range(P<Expr>, P<Expr>, RangeEnd),
Slice(Vec<P<Pat>>, Option<P<Pat>>, Vec<P<Pat>>),
Mac(Mac),
}rustc_private)Variants
Wildrustc_private)Represents a wildcard pattern (_)
Ident(BindingMode, SpannedIdent, Option<P<Pat>>)rustc_private)A PatKind::Ident may either be a new bound variable (ref mut binding @ OPT_SUBPATTERN),
or a unit struct/variant pattern, or a const pattern (in the last two cases the third
field must be None). Disambiguation cannot be done with parser alone, so it happens
during name resolution.
Struct(Path, Vec<Spanned<FieldPat>>, bool)rustc_private)A struct or struct variant pattern, e.g. Variant {x, y, ..}.
The bool is true in the presence of a ...
TupleStruct(Path, Vec<P<Pat>>, Option<usize>)rustc_private)A tuple struct/variant pattern Variant(x, y, .., z).
If the .. pattern fragment is present, then Option<usize> denotes its position.
0 <= position <= subpats.len()
Path(Option<QSelf>, Path)rustc_private)A possibly qualified path pattern.
Unquailfied path patterns A::B::C can legally refer to variants, structs, constants
or associated constants. Quailfied path patterns <A>::B::C/<A as Trait>::B::C can
only legally refer to associated constants.
Tuple(Vec<P<Pat>>, Option<usize>)rustc_private)A tuple pattern (a, b).
If the .. pattern fragment is present, then Option<usize> denotes its position.
0 <= position <= subpats.len()
Box(P<Pat>)rustc_private)A box pattern
Ref(P<Pat>, Mutability)rustc_private)A reference pattern, e.g. &mut (a, b)
Lit(P<Expr>)rustc_private)A literal
Range(P<Expr>, P<Expr>, RangeEnd)rustc_private)A range pattern, e.g. 1...2 or 1..2
Slice(Vec<P<Pat>>, Option<P<Pat>>, Vec<P<Pat>>)rustc_private)[a, b, ..i, y, z] is represented as:
PatKind::Slice(box [a, b], Some(i), box [y, z])
Mac(Mac)rustc_private)A macro pattern; pre-expansion