Enum syntax::ast::TyKind
[−]
[src]
pub enum TyKind {
Slice(P<Ty>),
Array(P<Ty>, P<Expr>),
Ptr(MutTy),
Rptr(Option<Lifetime>, MutTy),
BareFn(P<BareFnTy>),
Never,
Tup(Vec<P<Ty>>),
Path(Option<QSelf>, Path),
TraitObject(TyParamBounds),
ImplTrait(TyParamBounds),
Paren(P<Ty>),
Typeof(P<Expr>),
Infer,
ImplicitSelf,
Mac(Mac),
}rustc_private)The different kinds of types recognized by the compiler
Variants
Slice(P<Ty>)rustc_private)A variable-length slice ([T])
Array(P<Ty>, P<Expr>)rustc_private)A fixed length array ([T; n])
Ptr(MutTy)rustc_private)A raw pointer (*const T or *mut T)
Rptr(Option<Lifetime>, MutTy)rustc_private)A reference (&'a T or &'a mut T)
BareFn(P<BareFnTy>)rustc_private)A bare function (e.g. fn(usize) -> bool)
Neverrustc_private)The never type (!)
Tup(Vec<P<Ty>>)rustc_private)A tuple ((A, B, C, D,...))
Path(Option<QSelf>, Path)rustc_private)A path (module::module::...::Type), optionally
"qualified", e.g. <Vec<T> as SomeTrait>::SomeType.
Type parameters are stored in the Path itself
TraitObject(TyParamBounds)rustc_private)A trait object type Bound1 + Bound2 + Bound3
where Bound is a trait or a lifetime.
ImplTrait(TyParamBounds)rustc_private)An impl Bound1 + Bound2 + Bound3 type
where Bound is a trait or a lifetime.
Paren(P<Ty>)rustc_private)No-op; kept solely so that we can pretty-print faithfully
Typeof(P<Expr>)rustc_private)Unused for now
Inferrustc_private)TyKind::Infer means the type should be inferred instead of it having been specified. This can appear anywhere in a type.
ImplicitSelfrustc_private)Inferred type of a self or &self argument in a method.
Mac(Mac)rustc_private)Trait Implementations
impl Clone for TyKind[src]
fn clone(&self) -> TyKind
Returns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0
Performs copy-assignment from source. Read more
impl PartialEq for TyKind[src]
fn eq(&self, __arg_0: &TyKind) -> bool
This method tests for self and other values to be equal, and is used by ==. Read more
fn ne(&self, __arg_0: &TyKind) -> bool
This method tests for !=.
impl Eq for TyKind[src]
impl Encodable for TyKind[src]
fn encode<__S: Encoder>(&self, __arg_0: &mut __S) -> Result<(), __S::Error>
🔬 This is a nightly-only experimental API. (rustc_private)
deprecated in favor of rustc-serialize on crates.io
impl Decodable for TyKind[src]
fn decode<__D: Decoder>(__arg_0: &mut __D) -> Result<TyKind, __D::Error>
🔬 This is a nightly-only experimental API. (rustc_private)
deprecated in favor of rustc-serialize on crates.io
impl Hash for TyKind[src]
fn hash<__H: Hasher>(&self, __arg_0: &mut __H)
Feeds this value into the state given, updating the hasher as necessary.
fn hash_slice<H>(data: &[Self], state: &mut H) where H: Hasher1.3.0
Feeds a slice of this type into the state provided.