Enum syntax::ast::UintTy
[−]
[src]
pub enum UintTy {
Us,
U8,
U16,
U32,
U64,
U128,
}🔬 This is a nightly-only experimental API. (
rustc_private)Variants
Us🔬 This is a nightly-only experimental API. (
rustc_private)U8🔬 This is a nightly-only experimental API. (
rustc_private)U16🔬 This is a nightly-only experimental API. (
rustc_private)U32🔬 This is a nightly-only experimental API. (
rustc_private)U64🔬 This is a nightly-only experimental API. (
rustc_private)U128🔬 This is a nightly-only experimental API. (
rustc_private)Methods
impl UintTy[src]
fn ty_to_string(&self) -> &'static str
🔬 This is a nightly-only experimental API. (
rustc_private)fn val_to_string(&self, val: u128) -> String
🔬 This is a nightly-only experimental API. (
rustc_private)fn bit_width(&self) -> Option<usize>
🔬 This is a nightly-only experimental API. (
rustc_private)Trait Implementations
impl Clone for UintTy[src]
fn clone(&self) -> UintTy
Returns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0
Performs copy-assignment from source. Read more
impl PartialEq for UintTy[src]
fn eq(&self, __arg_0: &UintTy) -> bool
This method tests for self and other values to be equal, and is used by ==. Read more
fn ne(&self, other: &Rhs) -> bool1.0.0
This method tests for !=.
impl Eq for UintTy[src]
impl Encodable for UintTy[src]
fn encode<__S: Encoder>(&self, __arg_0: &mut __S) -> Result<(), __S::Error>
🔬 This is a nightly-only experimental API. (rustc_private)
deprecated in favor of rustc-serialize on crates.io
impl Decodable for UintTy[src]
fn decode<__D: Decoder>(__arg_0: &mut __D) -> Result<UintTy, __D::Error>
🔬 This is a nightly-only experimental API. (rustc_private)
deprecated in favor of rustc-serialize on crates.io
impl Hash for UintTy[src]
fn hash<__H: Hasher>(&self, __arg_0: &mut __H)
Feeds this value into the state given, updating the hasher as necessary.
fn hash_slice<H>(data: &[Self], state: &mut H) where H: Hasher1.3.0
Feeds a slice of this type into the state provided.