Enum syntax::ast::UnOp
[−]
[src]
pub enum UnOp {
Deref,
Not,
Neg,
}🔬 This is a nightly-only experimental API. (
rustc_private)Variants
Deref🔬 This is a nightly-only experimental API. (
rustc_private)The * operator for dereferencing
Not🔬 This is a nightly-only experimental API. (
rustc_private)The ! operator for logical inversion
Neg🔬 This is a nightly-only experimental API. (
rustc_private)The - operator for negation
Methods
impl UnOp[src]
fn is_by_value(u: UnOp) -> bool
🔬 This is a nightly-only experimental API. (
rustc_private)Returns true if the unary operator takes its argument by value
fn to_string(op: UnOp) -> &'static str
🔬 This is a nightly-only experimental API. (
rustc_private)Trait Implementations
impl Clone for UnOp[src]
fn clone(&self) -> UnOp
Returns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0
Performs copy-assignment from source. Read more
impl PartialEq for UnOp[src]
fn eq(&self, __arg_0: &UnOp) -> bool
This method tests for self and other values to be equal, and is used by ==. Read more
fn ne(&self, other: &Rhs) -> bool1.0.0
This method tests for !=.
impl Eq for UnOp[src]
impl Encodable for UnOp[src]
fn encode<__S: Encoder>(&self, __arg_0: &mut __S) -> Result<(), __S::Error>
🔬 This is a nightly-only experimental API. (rustc_private)
deprecated in favor of rustc-serialize on crates.io
impl Decodable for UnOp[src]
fn decode<__D: Decoder>(__arg_0: &mut __D) -> Result<UnOp, __D::Error>
🔬 This is a nightly-only experimental API. (rustc_private)
deprecated in favor of rustc-serialize on crates.io
impl Hash for UnOp[src]
fn hash<__H: Hasher>(&self, __arg_0: &mut __H)
Feeds this value into the state given, updating the hasher as necessary.
fn hash_slice<H>(data: &[Self], state: &mut H) where H: Hasher1.3.0
Feeds a slice of this type into the state provided.