Struct syntax::ast::Arm
[−]
[src]
pub struct Arm {
pub attrs: Vec<Attribute>,
pub pats: Vec<P<Pat>>,
pub guard: Option<P<Expr>>,
pub body: P<Expr>,
}🔬 This is a nightly-only experimental API. (
rustc_private)An arm of a 'match'.
E.g. 0...10 => { println!("match!") } as in
match n { 0...10 => { println!("match!") }, // .. }
Fields
attrs: Vec<Attribute>
🔬 This is a nightly-only experimental API. (
rustc_private)pats: Vec<P<Pat>>
🔬 This is a nightly-only experimental API. (
rustc_private)guard: Option<P<Expr>>
🔬 This is a nightly-only experimental API. (
rustc_private)body: P<Expr>
🔬 This is a nightly-only experimental API. (
rustc_private)Trait Implementations
impl Clone for Arm[src]
fn clone(&self) -> Arm
Returns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0
Performs copy-assignment from source. Read more
impl PartialEq for Arm[src]
fn eq(&self, __arg_0: &Arm) -> bool
This method tests for self and other values to be equal, and is used by ==. Read more
fn ne(&self, __arg_0: &Arm) -> bool
This method tests for !=.
impl Eq for Arm[src]
impl Encodable for Arm[src]
fn encode<__S: Encoder>(&self, __arg_0: &mut __S) -> Result<(), __S::Error>
🔬 This is a nightly-only experimental API. (rustc_private)
deprecated in favor of rustc-serialize on crates.io
impl Decodable for Arm[src]
fn decode<__D: Decoder>(__arg_0: &mut __D) -> Result<Arm, __D::Error>
🔬 This is a nightly-only experimental API. (rustc_private)
deprecated in favor of rustc-serialize on crates.io
impl Hash for Arm[src]
fn hash<__H: Hasher>(&self, __arg_0: &mut __H)
Feeds this value into the state given, updating the hasher as necessary.
fn hash_slice<H>(data: &[Self], state: &mut H) where H: Hasher1.3.0
Feeds a slice of this type into the state provided.
impl Debug for Arm[src]
impl HasAttrs for Arm[src]
fn attrs(&self) -> &[Attribute]
🔬 This is a nightly-only experimental API. (
rustc_private)fn map_attrs<F>(self, f: F) -> Self where F: FnOnce(Vec<Attribute>) -> Vec<Attribute>
🔬 This is a nightly-only experimental API. (
rustc_private)