Struct syntax::ast::Generics
[−]
[src]
pub struct Generics {
pub lifetimes: Vec<LifetimeDef>,
pub ty_params: Vec<TyParam>,
pub where_clause: WhereClause,
pub span: Span,
}🔬 This is a nightly-only experimental API. (
rustc_private)Represents lifetimes and type parameters attached to a declaration of a function, enum, trait, etc.
Fields
lifetimes: Vec<LifetimeDef>
🔬 This is a nightly-only experimental API. (
rustc_private)ty_params: Vec<TyParam>
🔬 This is a nightly-only experimental API. (
rustc_private)where_clause: WhereClause
🔬 This is a nightly-only experimental API. (
rustc_private)span: Span
🔬 This is a nightly-only experimental API. (
rustc_private)Methods
impl Generics[src]
fn is_lt_parameterized(&self) -> bool
🔬 This is a nightly-only experimental API. (
rustc_private)fn is_type_parameterized(&self) -> bool
🔬 This is a nightly-only experimental API. (
rustc_private)fn is_parameterized(&self) -> bool
🔬 This is a nightly-only experimental API. (
rustc_private)fn span_for_name(&self, name: &str) -> Option<Span>
🔬 This is a nightly-only experimental API. (
rustc_private)Trait Implementations
impl Clone for Generics[src]
fn clone(&self) -> Generics
Returns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0
Performs copy-assignment from source. Read more
impl PartialEq for Generics[src]
fn eq(&self, __arg_0: &Generics) -> bool
This method tests for self and other values to be equal, and is used by ==. Read more
fn ne(&self, __arg_0: &Generics) -> bool
This method tests for !=.
impl Eq for Generics[src]
impl Encodable for Generics[src]
fn encode<__S: Encoder>(&self, __arg_0: &mut __S) -> Result<(), __S::Error>
🔬 This is a nightly-only experimental API. (rustc_private)
deprecated in favor of rustc-serialize on crates.io
impl Decodable for Generics[src]
fn decode<__D: Decoder>(__arg_0: &mut __D) -> Result<Generics, __D::Error>
🔬 This is a nightly-only experimental API. (rustc_private)
deprecated in favor of rustc-serialize on crates.io
impl Hash for Generics[src]
fn hash<__H: Hasher>(&self, __arg_0: &mut __H)
Feeds this value into the state given, updating the hasher as necessary.
fn hash_slice<H>(data: &[Self], state: &mut H) where H: Hasher1.3.0
Feeds a slice of this type into the state provided.