Struct syntax::ast::InlineAsm
[−]
[src]
pub struct InlineAsm {
pub asm: Symbol,
pub asm_str_style: StrStyle,
pub outputs: Vec<InlineAsmOutput>,
pub inputs: Vec<(Symbol, P<Expr>)>,
pub clobbers: Vec<Symbol>,
pub volatile: bool,
pub alignstack: bool,
pub dialect: AsmDialect,
pub expn_id: ExpnId,
}🔬 This is a nightly-only experimental API. (
rustc_private)Inline assembly.
E.g. asm!("NOP");
Fields
asm: Symbol
🔬 This is a nightly-only experimental API. (
rustc_private)asm_str_style: StrStyle
🔬 This is a nightly-only experimental API. (
rustc_private)outputs: Vec<InlineAsmOutput>
🔬 This is a nightly-only experimental API. (
rustc_private)inputs: Vec<(Symbol, P<Expr>)>
🔬 This is a nightly-only experimental API. (
rustc_private)clobbers: Vec<Symbol>
🔬 This is a nightly-only experimental API. (
rustc_private)volatile: bool
🔬 This is a nightly-only experimental API. (
rustc_private)alignstack: bool
🔬 This is a nightly-only experimental API. (
rustc_private)dialect: AsmDialect
🔬 This is a nightly-only experimental API. (
rustc_private)expn_id: ExpnId
🔬 This is a nightly-only experimental API. (
rustc_private)Trait Implementations
impl Clone for InlineAsm[src]
fn clone(&self) -> InlineAsm
Returns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0
Performs copy-assignment from source. Read more
impl PartialEq for InlineAsm[src]
fn eq(&self, __arg_0: &InlineAsm) -> bool
This method tests for self and other values to be equal, and is used by ==. Read more
fn ne(&self, __arg_0: &InlineAsm) -> bool
This method tests for !=.
impl Eq for InlineAsm[src]
impl Encodable for InlineAsm[src]
fn encode<__S: Encoder>(&self, __arg_0: &mut __S) -> Result<(), __S::Error>
🔬 This is a nightly-only experimental API. (rustc_private)
deprecated in favor of rustc-serialize on crates.io
impl Decodable for InlineAsm[src]
fn decode<__D: Decoder>(__arg_0: &mut __D) -> Result<InlineAsm, __D::Error>
🔬 This is a nightly-only experimental API. (rustc_private)
deprecated in favor of rustc-serialize on crates.io
impl Hash for InlineAsm[src]
fn hash<__H: Hasher>(&self, __arg_0: &mut __H)
Feeds this value into the state given, updating the hasher as necessary.
fn hash_slice<H>(data: &[Self], state: &mut H) where H: Hasher1.3.0
Feeds a slice of this type into the state provided.