Struct syntax::ast::Mac_
[−]
[src]
pub struct Mac_ {
pub path: Path,
pub tts: ThinTokenStream,
}🔬 This is a nightly-only experimental API. (
rustc_private)Represents a macro invocation. The Path indicates which macro is being invoked, and the vector of token-trees contains the source of the macro invocation.
NB: the additional ident for a macro_rules-style macro is actually stored in the enclosing item. Oog.
Fields
path: Path
🔬 This is a nightly-only experimental API. (
rustc_private)tts: ThinTokenStream
🔬 This is a nightly-only experimental API. (
rustc_private)Methods
impl Mac_[src]
fn stream(&self) -> TokenStream
🔬 This is a nightly-only experimental API. (
rustc_private)Trait Implementations
impl Clone for Mac_[src]
fn clone(&self) -> Mac_
Returns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0
Performs copy-assignment from source. Read more
impl PartialEq for Mac_[src]
fn eq(&self, __arg_0: &Mac_) -> bool
This method tests for self and other values to be equal, and is used by ==. Read more
fn ne(&self, __arg_0: &Mac_) -> bool
This method tests for !=.
impl Eq for Mac_[src]
impl Encodable for Mac_[src]
fn encode<__S: Encoder>(&self, __arg_0: &mut __S) -> Result<(), __S::Error>
🔬 This is a nightly-only experimental API. (rustc_private)
deprecated in favor of rustc-serialize on crates.io
impl Decodable for Mac_[src]
fn decode<__D: Decoder>(__arg_0: &mut __D) -> Result<Mac_, __D::Error>
🔬 This is a nightly-only experimental API. (rustc_private)
deprecated in favor of rustc-serialize on crates.io
impl Hash for Mac_[src]
fn hash<__H: Hasher>(&self, __arg_0: &mut __H)
Feeds this value into the state given, updating the hasher as necessary.
fn hash_slice<H>(data: &[Self], state: &mut H) where H: Hasher1.3.0
Feeds a slice of this type into the state provided.