Struct syntax::ast::Mod
[−]
[src]
pub struct Mod {
pub inner: Span,
pub items: Vec<P<Item>>,
}🔬 This is a nightly-only experimental API. (
rustc_private)Module declaration.
E.g. mod foo; or mod foo { .. }
Fields
inner: Span
🔬 This is a nightly-only experimental API. (
rustc_private)A span from the first token past { to the last token until }.
For mod foo;, the inner span ranges from the first token
to the last token in the external file.
items: Vec<P<Item>>
🔬 This is a nightly-only experimental API. (
rustc_private)Trait Implementations
impl Clone for Mod[src]
fn clone(&self) -> Mod
Returns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0
Performs copy-assignment from source. Read more
impl PartialEq for Mod[src]
fn eq(&self, __arg_0: &Mod) -> bool
This method tests for self and other values to be equal, and is used by ==. Read more
fn ne(&self, __arg_0: &Mod) -> bool
This method tests for !=.
impl Eq for Mod[src]
impl Encodable for Mod[src]
fn encode<__S: Encoder>(&self, __arg_0: &mut __S) -> Result<(), __S::Error>
🔬 This is a nightly-only experimental API. (rustc_private)
deprecated in favor of rustc-serialize on crates.io
impl Decodable for Mod[src]
fn decode<__D: Decoder>(__arg_0: &mut __D) -> Result<Mod, __D::Error>
🔬 This is a nightly-only experimental API. (rustc_private)
deprecated in favor of rustc-serialize on crates.io
impl Hash for Mod[src]
fn hash<__H: Hasher>(&self, __arg_0: &mut __H)
Feeds this value into the state given, updating the hasher as necessary.
fn hash_slice<H>(data: &[Self], state: &mut H) where H: Hasher1.3.0
Feeds a slice of this type into the state provided.