Struct syntax::ast::StructField
[−]
[src]
pub struct StructField {
pub span: Span,
pub ident: Option<Ident>,
pub vis: Visibility,
pub id: NodeId,
pub ty: P<Ty>,
pub attrs: Vec<Attribute>,
}🔬 This is a nightly-only experimental API. (
rustc_private)Field of a struct.
E.g. bar: usize as in struct Foo { bar: usize }
Fields
span: Span
🔬 This is a nightly-only experimental API. (
rustc_private)ident: Option<Ident>
🔬 This is a nightly-only experimental API. (
rustc_private)vis: Visibility
🔬 This is a nightly-only experimental API. (
rustc_private)id: NodeId
🔬 This is a nightly-only experimental API. (
rustc_private)ty: P<Ty>
🔬 This is a nightly-only experimental API. (
rustc_private)attrs: Vec<Attribute>
🔬 This is a nightly-only experimental API. (
rustc_private)Trait Implementations
impl Clone for StructField[src]
fn clone(&self) -> StructField
Returns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0
Performs copy-assignment from source. Read more
impl PartialEq for StructField[src]
fn eq(&self, __arg_0: &StructField) -> bool
This method tests for self and other values to be equal, and is used by ==. Read more
fn ne(&self, __arg_0: &StructField) -> bool
This method tests for !=.
impl Eq for StructField[src]
impl Encodable for StructField[src]
fn encode<__S: Encoder>(&self, __arg_0: &mut __S) -> Result<(), __S::Error>
🔬 This is a nightly-only experimental API. (rustc_private)
deprecated in favor of rustc-serialize on crates.io
impl Decodable for StructField[src]
fn decode<__D: Decoder>(__arg_0: &mut __D) -> Result<StructField, __D::Error>
🔬 This is a nightly-only experimental API. (rustc_private)
deprecated in favor of rustc-serialize on crates.io
impl Hash for StructField[src]
fn hash<__H: Hasher>(&self, __arg_0: &mut __H)
Feeds this value into the state given, updating the hasher as necessary.
fn hash_slice<H>(data: &[Self], state: &mut H) where H: Hasher1.3.0
Feeds a slice of this type into the state provided.