Struct syntax::ast::Ty
[−]
[src]
pub struct Ty {
pub id: NodeId,
pub node: TyKind,
pub span: Span,
}🔬 This is a nightly-only experimental API. (
rustc_private)Fields
id: NodeId
🔬 This is a nightly-only experimental API. (
rustc_private)node: TyKind
🔬 This is a nightly-only experimental API. (
rustc_private)span: Span
🔬 This is a nightly-only experimental API. (
rustc_private)Trait Implementations
impl Clone for Ty[src]
fn clone(&self) -> Ty
Returns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0
Performs copy-assignment from source. Read more
impl PartialEq for Ty[src]
fn eq(&self, __arg_0: &Ty) -> bool
This method tests for self and other values to be equal, and is used by ==. Read more
fn ne(&self, __arg_0: &Ty) -> bool
This method tests for !=.
impl Eq for Ty[src]
impl Encodable for Ty[src]
fn encode<__S: Encoder>(&self, __arg_0: &mut __S) -> Result<(), __S::Error>
🔬 This is a nightly-only experimental API. (rustc_private)
deprecated in favor of rustc-serialize on crates.io
impl Decodable for Ty[src]
fn decode<__D: Decoder>(__arg_0: &mut __D) -> Result<Ty, __D::Error>
🔬 This is a nightly-only experimental API. (rustc_private)
deprecated in favor of rustc-serialize on crates.io
impl Hash for Ty[src]
fn hash<__H: Hasher>(&self, __arg_0: &mut __H)
Feeds this value into the state given, updating the hasher as necessary.
fn hash_slice<H>(data: &[Self], state: &mut H) where H: Hasher1.3.0
Feeds a slice of this type into the state provided.