Struct syntax::ast::WhereRegionPredicate
[−]
[src]
pub struct WhereRegionPredicate {
pub span: Span,
pub lifetime: Lifetime,
pub bounds: Vec<Lifetime>,
}🔬 This is a nightly-only experimental API. (
rustc_private)A lifetime predicate.
E.g. 'a: 'b+'c
Fields
span: Span
🔬 This is a nightly-only experimental API. (
rustc_private)lifetime: Lifetime
🔬 This is a nightly-only experimental API. (
rustc_private)bounds: Vec<Lifetime>
🔬 This is a nightly-only experimental API. (
rustc_private)Trait Implementations
impl Clone for WhereRegionPredicate[src]
fn clone(&self) -> WhereRegionPredicate
Returns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0
Performs copy-assignment from source. Read more
impl PartialEq for WhereRegionPredicate[src]
fn eq(&self, __arg_0: &WhereRegionPredicate) -> bool
This method tests for self and other values to be equal, and is used by ==. Read more
fn ne(&self, __arg_0: &WhereRegionPredicate) -> bool
This method tests for !=.
impl Eq for WhereRegionPredicate[src]
impl Encodable for WhereRegionPredicate[src]
fn encode<__S: Encoder>(&self, __arg_0: &mut __S) -> Result<(), __S::Error>
🔬 This is a nightly-only experimental API. (rustc_private)
deprecated in favor of rustc-serialize on crates.io
impl Decodable for WhereRegionPredicate[src]
fn decode<__D: Decoder>(__arg_0: &mut __D)
-> Result<WhereRegionPredicate, __D::Error>
-> Result<WhereRegionPredicate, __D::Error>
🔬 This is a nightly-only experimental API. (rustc_private)
deprecated in favor of rustc-serialize on crates.io
impl Hash for WhereRegionPredicate[src]
fn hash<__H: Hasher>(&self, __arg_0: &mut __H)
Feeds this value into the state given, updating the hasher as necessary.
fn hash_slice<H>(data: &[Self], state: &mut H) where H: Hasher1.3.0
Feeds a slice of this type into the state provided.