Struct syntax::attr::Deprecation
[−]
[src]
pub struct Deprecation {
pub since: Option<Symbol>,
pub note: Option<Symbol>,
}rustc_private)Fields
since: Option<Symbol>
rustc_private)note: Option<Symbol>
rustc_private)Trait Implementations
impl Encodable for Deprecation[src]
fn encode<__S: Encoder>(&self, __arg_0: &mut __S) -> Result<(), __S::Error>
🔬 This is a nightly-only experimental API. (rustc_private)
deprecated in favor of rustc-serialize on crates.io
impl Decodable for Deprecation[src]
fn decode<__D: Decoder>(__arg_0: &mut __D) -> Result<Deprecation, __D::Error>
🔬 This is a nightly-only experimental API. (rustc_private)
deprecated in favor of rustc-serialize on crates.io
impl PartialEq for Deprecation[src]
fn eq(&self, __arg_0: &Deprecation) -> bool
This method tests for self and other values to be equal, and is used by ==. Read more
fn ne(&self, __arg_0: &Deprecation) -> bool
This method tests for !=.
impl PartialOrd for Deprecation[src]
fn partial_cmp(&self, __arg_0: &Deprecation) -> Option<Ordering>
This method returns an ordering between self and other values if one exists. Read more
fn lt(&self, __arg_0: &Deprecation) -> bool
This method tests less than (for self and other) and is used by the < operator. Read more
fn le(&self, __arg_0: &Deprecation) -> bool
This method tests less than or equal to (for self and other) and is used by the <= operator. Read more
fn gt(&self, __arg_0: &Deprecation) -> bool
This method tests greater than (for self and other) and is used by the > operator. Read more
fn ge(&self, __arg_0: &Deprecation) -> bool
This method tests greater than or equal to (for self and other) and is used by the >= operator. Read more
impl Clone for Deprecation[src]
fn clone(&self) -> Deprecation
Returns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0
Performs copy-assignment from source. Read more
impl Debug for Deprecation[src]
impl Eq for Deprecation[src]
impl Hash for Deprecation[src]
fn hash<__H: Hasher>(&self, __arg_0: &mut __H)
Feeds this value into the state given, updating the hasher as necessary.
fn hash_slice<H>(data: &[Self], state: &mut H) where H: Hasher1.3.0
Feeds a slice of this type into the state provided.