Struct syntax::attr::Stability
[−]
[src]
pub struct Stability {
pub level: StabilityLevel,
pub feature: Symbol,
pub rustc_depr: Option<RustcDeprecation>,
}🔬 This is a nightly-only experimental API. (
rustc_private)Represents the #[stable], #[unstable] and #[rustc_deprecated] attributes.
Fields
level: StabilityLevel
🔬 This is a nightly-only experimental API. (
rustc_private)feature: Symbol
🔬 This is a nightly-only experimental API. (
rustc_private)rustc_depr: Option<RustcDeprecation>
🔬 This is a nightly-only experimental API. (
rustc_private)Trait Implementations
impl Encodable for Stability[src]
fn encode<__S: Encoder>(&self, __arg_0: &mut __S) -> Result<(), __S::Error>
🔬 This is a nightly-only experimental API. (rustc_private)
deprecated in favor of rustc-serialize on crates.io
impl Decodable for Stability[src]
fn decode<__D: Decoder>(__arg_0: &mut __D) -> Result<Stability, __D::Error>
🔬 This is a nightly-only experimental API. (rustc_private)
deprecated in favor of rustc-serialize on crates.io
impl Clone for Stability[src]
fn clone(&self) -> Stability
Returns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0
Performs copy-assignment from source. Read more
impl Debug for Stability[src]
impl PartialEq for Stability[src]
fn eq(&self, __arg_0: &Stability) -> bool
This method tests for self and other values to be equal, and is used by ==. Read more
fn ne(&self, __arg_0: &Stability) -> bool
This method tests for !=.
impl Eq for Stability[src]
impl Hash for Stability[src]
fn hash<__H: Hasher>(&self, __arg_0: &mut __H)
Feeds this value into the state given, updating the hasher as necessary.
fn hash_slice<H>(data: &[Self], state: &mut H) where H: Hasher1.3.0
Feeds a slice of this type into the state provided.