Struct syntax::codemap::Spanned
[−]
[src]
pub struct Spanned<T> {
pub node: T,
pub span: Span,
}🔬 This is a nightly-only experimental API. (
rustc_private)Fields
node: T
🔬 This is a nightly-only experimental API. (
rustc_private)span: Span
🔬 This is a nightly-only experimental API. (
rustc_private)Trait Implementations
impl<T: HasAttrs> HasAttrs for Spanned<T>[src]
fn attrs(&self) -> &[Attribute]
🔬 This is a nightly-only experimental API. (
rustc_private)fn map_attrs<F: FnOnce(Vec<Attribute>) -> Vec<Attribute>>(self, f: F) -> Self
🔬 This is a nightly-only experimental API. (
rustc_private)impl<T: Clone> Clone for Spanned<T>[src]
fn clone(&self) -> Spanned<T>
Returns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0
Performs copy-assignment from source. Read more
impl<T: PartialEq> PartialEq for Spanned<T>[src]
fn eq(&self, __arg_0: &Spanned<T>) -> bool
This method tests for self and other values to be equal, and is used by ==. Read more
fn ne(&self, __arg_0: &Spanned<T>) -> bool
This method tests for !=.
impl<T: Eq> Eq for Spanned<T>[src]
impl<T: Encodable> Encodable for Spanned<T>[src]
fn encode<__ST: Encoder>(&self, __arg_0: &mut __ST) -> Result<(), __ST::Error>
🔬 This is a nightly-only experimental API. (rustc_private)
deprecated in favor of rustc-serialize on crates.io
impl<T: Decodable> Decodable for Spanned<T>[src]
fn decode<__DT: Decoder>(__arg_0: &mut __DT) -> Result<Spanned<T>, __DT::Error>
🔬 This is a nightly-only experimental API. (rustc_private)
deprecated in favor of rustc-serialize on crates.io
impl<T: Hash> Hash for Spanned<T>[src]
fn hash<__HT: Hasher>(&self, __arg_0: &mut __HT)
Feeds this value into the state given, updating the hasher as necessary.
fn hash_slice<H>(data: &[Self], state: &mut H) where H: Hasher1.3.0
Feeds a slice of this type into the state provided.