Enum syntax::feature_gate::AttributeGate
[−]
[src]
pub enum AttributeGate {
Gated(Stability, &'static str, &'static str, fn(_: &Features) -> bool),
Ungated,
}🔬 This is a nightly-only experimental API. (
rustc_private)Variants
Gated(Stability, &'static str, &'static str, fn(_: &Features) -> bool)🔬 This is a nightly-only experimental API. (
rustc_private)Is gated by a given feature gate, reason and function to check if enabled
Ungated🔬 This is a nightly-only experimental API. (
rustc_private)Ungated attribute, can be used on all release channels