Enum syntax::parse::parser::PathStyle
[−]
[src]
pub enum PathStyle {
Mod,
Type,
Expr,
}🔬 This is a nightly-only experimental API. (
rustc_private)How to parse a path. There are three different kinds of paths, all of which are parsed somewhat differently.
Variants
Mod🔬 This is a nightly-only experimental API. (
rustc_private)A path with no type parameters, e.g. foo::bar::Baz, used in imports or visibilities.
Type🔬 This is a nightly-only experimental API. (
rustc_private)A path with a lifetime and type parameters, with no double colons
before the type parameters; e.g. foo::bar<'a>::Baz<T>, used in types.
Paths using this style can be passed into macros expecting path nonterminals.
Expr🔬 This is a nightly-only experimental API. (
rustc_private)A path with a lifetime and type parameters with double colons before
the type parameters; e.g. foo::bar::<'a>::Baz::<T>, used in expressions or patterns.