Struct syntax::symbol::Symbol
[−]
[src]
pub struct Symbol(_);
rustc_private)A symbol is an interned or gensymed string.
Methods
impl Symbol[src]
fn intern(string: &str) -> Self
rustc_private)Maps a string to its interned representation.
fn gensym(string: &str) -> Self
rustc_private)gensym's a new usize, using the current interner.
fn as_str(self) -> InternedString
rustc_private)fn as_u32(self) -> u32
rustc_private)Trait Implementations
impl Clone for Symbol[src]
fn clone(&self) -> Symbol
Returns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0
Performs copy-assignment from source. Read more
impl Copy for Symbol[src]
impl PartialEq for Symbol[src]
fn eq(&self, __arg_0: &Symbol) -> bool
This method tests for self and other values to be equal, and is used by ==. Read more
fn ne(&self, __arg_0: &Symbol) -> bool
This method tests for !=.
impl Eq for Symbol[src]
impl PartialOrd for Symbol[src]
fn partial_cmp(&self, __arg_0: &Symbol) -> Option<Ordering>
This method returns an ordering between self and other values if one exists. Read more
fn lt(&self, __arg_0: &Symbol) -> bool
This method tests less than (for self and other) and is used by the < operator. Read more
fn le(&self, __arg_0: &Symbol) -> bool
This method tests less than or equal to (for self and other) and is used by the <= operator. Read more
fn gt(&self, __arg_0: &Symbol) -> bool
This method tests greater than (for self and other) and is used by the > operator. Read more
fn ge(&self, __arg_0: &Symbol) -> bool
This method tests greater than or equal to (for self and other) and is used by the >= operator. Read more
impl Ord for Symbol[src]
fn cmp(&self, __arg_0: &Symbol) -> Ordering
This method returns an Ordering between self and other. Read more
impl Hash for Symbol[src]
fn hash<__H: Hasher>(&self, __arg_0: &mut __H)
Feeds this value into the state given, updating the hasher as necessary.
fn hash_slice<H>(data: &[Self], state: &mut H) where H: Hasher1.3.0
Feeds a slice of this type into the state provided.
impl !Send for Symbol[src]
impl Debug for Symbol[src]
impl Display for Symbol[src]
impl Encodable for Symbol[src]
fn encode<S: Encoder>(&self, s: &mut S) -> Result<(), S::Error>
🔬 This is a nightly-only experimental API. (rustc_private)
deprecated in favor of rustc-serialize on crates.io
impl Decodable for Symbol[src]
fn decode<D: Decoder>(d: &mut D) -> Result<Symbol, D::Error>
🔬 This is a nightly-only experimental API. (rustc_private)
deprecated in favor of rustc-serialize on crates.io