Struct syntax::tokenstream::TokenStream
[−]
[src]
pub struct TokenStream { /* fields omitted */ }rustc_private)Token Streams
A TokenStream is an abstract sequence of tokens, organized into TokenTrees.
The goal is for procedural macros to work with TokenStreams and TokenTrees
instead of a representation of the abstract syntax tree.
Today's TokenTrees can still contain AST via Token::Interpolated for back-compat.
Methods
impl TokenStream[src]
fn empty() -> TokenStream
rustc_private)fn is_empty(&self) -> bool
rustc_private)fn concat(streams: Vec<TokenStream>) -> TokenStream
rustc_private)fn trees(&self) -> Cursor
rustc_private)fn into_trees(self) -> Cursor
rustc_private)fn eq_unspanned(&self, other: &TokenStream) -> bool
rustc_private)Compares two TokenStreams, checking equality without regarding span information.